Class: Ansible::Ruby::Modules::Aci_aaa_user

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb

Overview

Manage AAA users on Cisco ACI fabrics.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#aaa_password ⇒ String?

Returns The password of the locally-authenticated user.

Returns:

  • (String, nil) —

    The password of the locally-authenticated user.



12
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 12

attribute :aaa_password

#aaa_password_lifetime ⇒ Integer?

Returns The lifetime of the locally-authenticated user password.

Returns:

  • (Integer, nil) —

    The lifetime of the locally-authenticated user password.



16
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 16

attribute :aaa_password_lifetime

#aaa_password_update_required ⇒ Symbol?

Returns Whether this account needs password update.

Returns:

  • (Symbol, nil) —

    Whether this account needs password update.



20
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 20

attribute :aaa_password_update_required

#aaa_user ⇒ String?

Returns The name of the locally-authenticated user user to add.

Returns:

  • (String, nil) —

    The name of the locally-authenticated user user to add.



24
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 24

attribute :aaa_user

#clear_password_history ⇒ Symbol?

Returns Whether to clear the password history of a locally-authenticated user.

Returns:

  • (Symbol, nil) —

    Whether to clear the password history of a locally-authenticated user.



28
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 28

attribute :clear_password_history

#description ⇒ Object?

Returns Description for the AAA user.

Returns:

  • (Object, nil) —

    Description for the AAA user.



32
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 32

attribute :description

#email ⇒ String?

Returns The email address of the locally-authenticated user.

Returns:

  • (String, nil) —

    The email address of the locally-authenticated user.



35
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 35

attribute :email

#enabled ⇒ Symbol?

Returns The status of the locally-authenticated user account.

Returns:

  • (Symbol, nil) —

    The status of the locally-authenticated user account.



39
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 39

attribute :enabled

#expiration ⇒ String?

Returns The expiration date of the locally-authenticated user account.

Returns:

  • (String, nil) —

    The expiration date of the locally-authenticated user account.



43
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 43

attribute :expiration

#expires ⇒ Symbol?

Returns Whether to enable an expiration date for the locally-authenticated user account.

Returns:

  • (Symbol, nil) —

    Whether to enable an expiration date for the locally-authenticated user account.



47
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 47

attribute :expires

#first_name ⇒ String?

Returns The first name of the locally-authenticated user.

Returns:

  • (String, nil) —

    The first name of the locally-authenticated user.



51
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 51

attribute :first_name

#last_name ⇒ String?

Returns The last name of the locally-authenticated user.

Returns:

  • (String, nil) —

    The last name of the locally-authenticated user.



55
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 55

attribute :last_name

#phone ⇒ String?

Returns The phone number of the locally-authenticated user.

Returns:

  • (String, nil) —

    The phone number of the locally-authenticated user.



59
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 59

attribute :phone

#state ⇒ :absent, ...

Returns Use C(present) or C(absent) for adding or removing.,Use C(query) for listing an object or multiple objects.

Returns:

  • (:absent, :present, :query, nil) —

    Use C(present) or C(absent) for adding or removing.,Use C(query) for listing an object or multiple objects.



63
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_aaa_user.rb', line 63

attribute :state