Class: Ansible::Ruby::Modules::Aci_epg_to_domain

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb

Overview

Bind EPGs to Physical and Virtual Domains on Cisco ACI fabrics.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#allow_useg ⇒ :encap, ...

Returns Allows micro-segmentation.,The APIC defaults to C(encap) when unset during creation.

Returns:

  • (:encap, :useg, nil) —

    Allows micro-segmentation.,The APIC defaults to C(encap) when unset during creation.



12
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 12

attribute :allow_useg

#ap ⇒ String?

Returns Name of an existing application network profile, that will contain the EPGs.

Returns:

  • (String, nil) —

    Name of an existing application network profile, that will contain the EPGs.



16
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 16

attribute :ap

#deploy_immediacy ⇒ :immediate, ...

Returns Determines when the policy is pushed to hardware Policy CAM.,The APIC defaults to C(lazy) when unset during creation.

Returns:

  • (:immediate, :lazy, nil) —

    Determines when the policy is pushed to hardware Policy CAM.,The APIC defaults to C(lazy) when unset during creation.



20
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 20

attribute :deploy_immediacy

#domain ⇒ String?

Returns Name of the physical or virtual domain being associated with the EPG.

Returns:

  • (String, nil) —

    Name of the physical or virtual domain being associated with the EPG.



24
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 24

attribute :domain

#domain_type ⇒ :phys, ...

Returns Determines if the Domain is physical (phys) or virtual (vmm).

Returns:

  • (:phys, :vmm, nil) —

    Determines if the Domain is physical (phys) or virtual (vmm).



28
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 28

attribute :domain_type

#encap ⇒ Integer?

Returns The VLAN encapsulation for the EPG when binding a VMM Domain with static encap_mode.,This acts as the secondary encap when using useg.,Accepted values range between C(1) and C(4096).

Returns:

  • (Integer, nil) —

    The VLAN encapsulation for the EPG when binding a VMM Domain with static encap_mode.,This acts as the secondary encap when using useg.,Accepted values range between C(1) and C(4096).



32
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 32

attribute :encap

#encap_mode ⇒ :auto, ...

Returns The ecapsulataion method to be used.,The APIC defaults to C(auto) when unset during creation.

Returns:

  • (:auto, :vlan, :vxlan, nil) —

    The ecapsulataion method to be used.,The APIC defaults to C(auto) when unset during creation.



36
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 36

attribute :encap_mode

#epg ⇒ String?

Returns Name of the end point group.

Returns:

  • (String, nil) —

    Name of the end point group.



40
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 40

attribute :epg

#netflow ⇒ Symbol?

Returns Determines if netflow should be enabled.,The APIC defaults to C(no) when unset during creation.

Returns:

  • (Symbol, nil) —

    Determines if netflow should be enabled.,The APIC defaults to C(no) when unset during creation.



44
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 44

attribute :netflow

#primary_encap ⇒ Integer?

Returns Determines the primary VLAN ID when using useg.,Accepted values range between C(1) and C(4096).

Returns:

  • (Integer, nil) —

    Determines the primary VLAN ID when using useg.,Accepted values range between C(1) and C(4096).



48
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 48

attribute :primary_encap

#resolution_immediacy ⇒ :immediate, ...

Returns Determines when the policies should be resolved and available.,The APIC defaults to C(lazy) when unset during creation.

Returns:

  • (:immediate, :lazy, :"pre-provision", nil) —

    Determines when the policies should be resolved and available.,The APIC defaults to C(lazy) when unset during creation.



52
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 52

attribute :resolution_immediacy

#state ⇒ :absent, ...

Returns Use C(present) or C(absent) for adding or removing.,Use C(query) for listing an object or multiple objects.

Returns:

  • (:absent, :present, :query, nil) —

    Use C(present) or C(absent) for adding or removing.,Use C(query) for listing an object or multiple objects.



56
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 56

attribute :state

#tenant ⇒ String?

Returns Name of an existing tenant.

Returns:

  • (String, nil) —

    Name of an existing tenant.



60
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 60

attribute :tenant

#vm_provider ⇒ :cloudfoundry, ...

Returns The VM platform for VMM Domains.,Support for Kubernetes was added in ACI v3.0.,Support for CloudFoundry, OpenShift and Red Hat was added in ACI v3.1.

Returns:

  • (:cloudfoundry, :kubernetes, :microsoft, :openshift, :openstack, :redhat, :vmware, nil) —

    The VM platform for VMM Domains.,Support for Kubernetes was added in ACI v3.0.,Support for CloudFoundry, OpenShift and Red Hat was added in ACI v3.1.



64
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_epg_to_domain.rb', line 64

attribute :vm_provider