Class: Ansible::Ruby::Modules::Aci_tenant_ep_retention_policy

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb

Overview

Manage End Point (EP) retention protocol policies on Cisco ACI fabrics.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#bounce_age ⇒ Integer?

Returns Bounce entry aging interval in seconds.,Accepted values range between C(150) and C(65535); 0 is used for infinite.,The APIC defaults to C(630) when unset during creation.

Returns:

  • (Integer, nil) —

    Bounce entry aging interval in seconds.,Accepted values range between C(150) and C(65535); 0 is used for infinite.,The APIC defaults to C(630) when unset during creation.



20
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 20

attribute :bounce_age

#bounce_trigger ⇒ :coop, ...

Returns Determines if the bounce entries are installed by RARP Flood or COOP Protocol.,The APIC defaults to C(coop) when unset during creation.

Returns:

  • (:coop, :flood, nil) —

    Determines if the bounce entries are installed by RARP Flood or COOP Protocol.,The APIC defaults to C(coop) when unset during creation.



24
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 24

attribute :bounce_trigger

#description ⇒ String?

Returns Description for the End point rentention policy.

Returns:

  • (String, nil) —

    Description for the End point rentention policy.



44
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 44

attribute :description

#epr_policy ⇒ String?

Returns The name of the end point retention policy.

Returns:

  • (String, nil) —

    The name of the end point retention policy.



16
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 16

attribute :epr_policy

#hold_interval ⇒ Integer?

Returns Hold interval in seconds.,Accepted values range between C(5) and C(65535).,The APIC defaults to C(300) when unset during creation.

Returns:

  • (Integer, nil) —

    Hold interval in seconds.,Accepted values range between C(5) and C(65535).,The APIC defaults to C(300) when unset during creation.



28
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 28

attribute :hold_interval

#local_ep_interval ⇒ Integer?

Returns Local end point aging interval in seconds.,Accepted values range between C(120) and C(65535); 0 is used for infinite.,The APIC defaults to C(900) when unset during creation.

Returns:

  • (Integer, nil) —

    Local end point aging interval in seconds.,Accepted values range between C(120) and C(65535); 0 is used for infinite.,The APIC defaults to C(900) when unset during creation.



32
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 32

attribute :local_ep_interval

#move_frequency ⇒ Integer?

Returns Move frequency per second.,Accepted values range between C(0) and C(65535); 0 is used for none.,The APIC defaults to C(256) when unset during creation.

Returns:

  • (Integer, nil) —

    Move frequency per second.,Accepted values range between C(0) and C(65535); 0 is used for none.,The APIC defaults to C(256) when unset during creation.



40
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 40

attribute :move_frequency

#remote_ep_interval ⇒ Integer?

Returns Remote end point aging interval in seconds.,Accepted values range between C(120) and C(65535); 0 is used for infinite.,The APIC defaults to C(300) when unset during creation.

Returns:

  • (Integer, nil) —

    Remote end point aging interval in seconds.,Accepted values range between C(120) and C(65535); 0 is used for infinite.,The APIC defaults to C(300) when unset during creation.



36
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 36

attribute :remote_ep_interval

#state ⇒ :absent, ...

Returns Use C(present) or C(absent) for adding or removing.,Use C(query) for listing an object or multiple objects.

Returns:

  • (:absent, :present, :query, nil) —

    Use C(present) or C(absent) for adding or removing.,Use C(query) for listing an object or multiple objects.



48
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 48

attribute :state

#tenant ⇒ String?

Returns The name of an existing tenant.

Returns:

  • (String, nil) —

    The name of an existing tenant.



12
# File 'lib/ansible/ruby/modules/generated/network/aci/aci_tenant_ep_retention_policy.rb', line 12

attribute :tenant