Class: Ansible::Ruby::Modules::Atomic_container

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/atomic/atomic_container.rb

Overview

Manage the containers on the atomic host platform Allows to manage the lifecycle of a container on the atomic host platform

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#backend ⇒ :docker, :ostree

Returns Define the backend to use for the container.

Returns:

  • (:docker, :ostree) —

    Define the backend to use for the container



13
# File 'lib/ansible/ruby/modules/generated/cloud/atomic/atomic_container.rb', line 13

attribute :backend

#image ⇒ String

Returns The image to use to install the container.

Returns:

  • (String) —

    The image to use to install the container



21
# File 'lib/ansible/ruby/modules/generated/cloud/atomic/atomic_container.rb', line 21

attribute :image

#mode ⇒ :user, :system

Returns Define if it is an user or a system container.

Returns:

  • (:user, :system) —

    Define if it is an user or a system container



32
# File 'lib/ansible/ruby/modules/generated/cloud/atomic/atomic_container.rb', line 32

attribute :mode

#name ⇒ String

Returns Name of the container.

Returns:

  • (String) —

    Name of the container



17
# File 'lib/ansible/ruby/modules/generated/cloud/atomic/atomic_container.rb', line 17

attribute :name

#rootfs ⇒ Object?

Returns Define the rootfs of the image.

Returns:

  • (Object, nil) —

    Define the rootfs of the image



25
# File 'lib/ansible/ruby/modules/generated/cloud/atomic/atomic_container.rb', line 25

attribute :rootfs

#state ⇒ :latest, ...

Returns State of the container.

Returns:

  • (:latest, :present, :absent, :rollback) —

    State of the container



28
# File 'lib/ansible/ruby/modules/generated/cloud/atomic/atomic_container.rb', line 28

attribute :state

#values ⇒ Array<String>, ...

Returns Values for the installation of the container. This option is permitted only with mode 'user' or 'system'. The values specified here will be used at installation time as --set arguments for atomic install.

Returns:

  • (Array<String>, String, nil) —

    Values for the installation of the container. This option is permitted only with mode 'user' or 'system'. The values specified here will be used at installation time as --set arguments for atomic install.



36
# File 'lib/ansible/ruby/modules/generated/cloud/atomic/atomic_container.rb', line 36

attribute :values