Class: Ansible::Ruby::Modules::Avi_alertsyslogconfig

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb

Overview

This module is used to configure AlertSyslogConfig object more examples at U(https://github.com/avinetworks/devops)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#avi_api_patch_op ⇒ :add, ...

Returns Patch operation to use when using avi_api_update_method as patch.

Returns:

  • (:add, :replace, :delete, nil) —

    Patch operation to use when using avi_api_update_method as patch.



21
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb', line 21

attribute :avi_api_patch_op

#avi_api_update_method ⇒ :put, ...

Returns Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.

Returns:

  • (:put, :patch, nil) —

    Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.



17
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb', line 17

attribute :avi_api_update_method

#description ⇒ Object?

Returns User defined description for alert syslog config.

Returns:

  • (Object, nil) —

    User defined description for alert syslog config.



25
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb', line 25

attribute :description

#name ⇒ String

Returns A user-friendly name of the syslog notification.

Returns:

  • (String) —

    A user-friendly name of the syslog notification.



28
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb', line 28

attribute :name

#state ⇒ :absent, ...

Returns The state that should be applied on the entity.

Returns:

  • (:absent, :present, nil) —

    The state that should be applied on the entity.



13
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb', line 13

attribute :state

#syslog_servers ⇒ Array<Hash>, ...

Returns The list of syslog servers.

Returns:

  • (Array<Hash>, Hash, nil) —

    The list of syslog servers.



32
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb', line 32

attribute :syslog_servers

#tenant_ref ⇒ String?

Returns It is a reference to an object of type tenant.

Returns:

  • (String, nil) —

    It is a reference to an object of type tenant.



36
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb', line 36

attribute :tenant_ref

#url ⇒ Object?

Returns Avi controller URL of the object.

Returns:

  • (Object, nil) —

    Avi controller URL of the object.



40
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb', line 40

attribute :url

#uuid ⇒ Object?

Returns Unique object identifier of the object.

Returns:

  • (Object, nil) —

    Unique object identifier of the object.



43
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_alertsyslogconfig.rb', line 43

attribute :uuid