Class: Ansible::Ruby::Modules::Avi_backup

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb

Overview

This module is used to configure Backup object more examples at U(https://github.com/avinetworks/devops)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#avi_api_patch_op ⇒ :add, ...

Returns Patch operation to use when using avi_api_update_method as patch.

Returns:

  • (:add, :replace, :delete, nil) —

    Patch operation to use when using avi_api_update_method as patch.



21
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 21

attribute :avi_api_patch_op

#avi_api_update_method ⇒ :put, ...

Returns Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.

Returns:

  • (:put, :patch, nil) —

    Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.



17
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 17

attribute :avi_api_update_method

#backup_config_ref ⇒ Object?

Returns Backupconfiguration information.,It is a reference to an object of type backupconfiguration.

Returns:

  • (Object, nil) —

    Backupconfiguration information.,It is a reference to an object of type backupconfiguration.



25
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 25

attribute :backup_config_ref

#file_name ⇒ Object

Returns The file name of backup.

Returns:

  • (Object) —

    The file name of backup.



28
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 28

attribute :file_name

#local_file_url ⇒ Object?

Returns Url to download the backup file.

Returns:

  • (Object, nil) —

    Url to download the backup file.



32
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 32

attribute :local_file_url

#remote_file_url ⇒ Object?

Returns Url to download the backup file.

Returns:

  • (Object, nil) —

    Url to download the backup file.



35
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 35

attribute :remote_file_url

#scheduler_ref ⇒ Object?

Returns Scheduler information.,It is a reference to an object of type scheduler.

Returns:

  • (Object, nil) —

    Scheduler information.,It is a reference to an object of type scheduler.



38
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 38

attribute :scheduler_ref

#state ⇒ :absent, ...

Returns The state that should be applied on the entity.

Returns:

  • (:absent, :present, nil) —

    The state that should be applied on the entity.



13
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 13

attribute :state

#tenant_ref ⇒ Object?

Returns It is a reference to an object of type tenant.

Returns:

  • (Object, nil) —

    It is a reference to an object of type tenant.



41
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 41

attribute :tenant_ref

#timestamp ⇒ Object?

Returns Unix timestamp of when the backup file is created.

Returns:

  • (Object, nil) —

    Unix timestamp of when the backup file is created.



44
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 44

attribute :timestamp

#url ⇒ Object?

Returns Avi controller URL of the object.

Returns:

  • (Object, nil) —

    Avi controller URL of the object.



47
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 47

attribute :url

#uuid ⇒ Object?

Returns Unique object identifier of the object.

Returns:

  • (Object, nil) —

    Unique object identifier of the object.



50
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_backup.rb', line 50

attribute :uuid