Class: Ansible::Ruby::Modules::Avi_hardwaresecuritymodulegroup

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/avi/avi_hardwaresecuritymodulegroup.rb

Overview

This module is used to configure HardwareSecurityModuleGroup object more examples at U(https://github.com/avinetworks/devops)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#avi_api_patch_op ⇒ :add, ...

Returns Patch operation to use when using avi_api_update_method as patch.

Returns:

  • (:add, :replace, :delete, nil) —

    Patch operation to use when using avi_api_update_method as patch.



21
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_hardwaresecuritymodulegroup.rb', line 21

attribute :avi_api_patch_op

#avi_api_update_method ⇒ :put, ...

Returns Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.

Returns:

  • (:put, :patch, nil) —

    Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.



17
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_hardwaresecuritymodulegroup.rb', line 17

attribute :avi_api_update_method

#hsm ⇒ Object

Returns Hardware security module configuration.

Returns:

  • (Object) —

    Hardware security module configuration.



25
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_hardwaresecuritymodulegroup.rb', line 25

attribute :hsm

#name ⇒ String

Returns Name of the hsm group configuration object.

Returns:

  • (String) —

    Name of the hsm group configuration object.



29
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_hardwaresecuritymodulegroup.rb', line 29

attribute :name

#state ⇒ :absent, ...

Returns The state that should be applied on the entity.

Returns:

  • (:absent, :present, nil) —

    The state that should be applied on the entity.



13
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_hardwaresecuritymodulegroup.rb', line 13

attribute :state

#tenant_ref ⇒ Object?

Returns It is a reference to an object of type tenant.

Returns:

  • (Object, nil) —

    It is a reference to an object of type tenant.



33
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_hardwaresecuritymodulegroup.rb', line 33

attribute :tenant_ref

#url ⇒ Object?

Returns Avi controller URL of the object.

Returns:

  • (Object, nil) —

    Avi controller URL of the object.



36
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_hardwaresecuritymodulegroup.rb', line 36

attribute :url

#uuid ⇒ Object?

Returns Uuid of the hsm group configuration object.

Returns:

  • (Object, nil) —

    Uuid of the hsm group configuration object.



39
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_hardwaresecuritymodulegroup.rb', line 39

attribute :uuid