Class: Ansible::Ruby::Modules::Avi_ipaddrgroup

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb

Overview

This module is used to configure IpAddrGroup object more examples at U(https://github.com/avinetworks/devops)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#addrs ⇒ Object?

Returns Configure ip address(es).

Returns:

  • (Object, nil) —

    Configure ip address(es).



25
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 25

attribute :addrs

#apic_epg_name ⇒ Object?

Returns Populate ip addresses from members of this cisco apic epg.

Returns:

  • (Object, nil) —

    Populate ip addresses from members of this cisco apic epg.



28
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 28

attribute :apic_epg_name

#avi_api_patch_op ⇒ :add, ...

Returns Patch operation to use when using avi_api_update_method as patch.

Returns:

  • (:add, :replace, :delete, nil) —

    Patch operation to use when using avi_api_update_method as patch.



21
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 21

attribute :avi_api_patch_op

#avi_api_update_method ⇒ :put, ...

Returns Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.

Returns:

  • (:put, :patch, nil) —

    Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.



17
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 17

attribute :avi_api_update_method

#country_codes ⇒ Object?

Returns Populate the ip address ranges from the geo database for this country.

Returns:

  • (Object, nil) —

    Populate the ip address ranges from the geo database for this country.



31
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 31

attribute :country_codes

#description ⇒ Object?

Returns User defined description for the object.

Returns:

  • (Object, nil) —

    User defined description for the object.



34
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 34

attribute :description

#ip_ports ⇒ Object?

Returns Configure (ip address, port) tuple(s).

Returns:

  • (Object, nil) —

    Configure (ip address, port) tuple(s).



37
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 37

attribute :ip_ports

#marathon_app_name ⇒ Object?

Returns Populate ip addresses from tasks of this marathon app.

Returns:

  • (Object, nil) —

    Populate ip addresses from tasks of this marathon app.



40
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 40

attribute :marathon_app_name

#marathon_service_port ⇒ Object?

Returns Task port associated with marathon service port.,If marathon app has multiple service ports, this is required.,Else, the first task port is used.

Returns:

  • (Object, nil) —

    Task port associated with marathon service port.,If marathon app has multiple service ports, this is required.,Else, the first task port is used.



43
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 43

attribute :marathon_service_port

#name ⇒ String

Returns Name of the ip address group.

Returns:

  • (String) —

    Name of the ip address group.



46
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 46

attribute :name

#prefixes ⇒ Array<Hash>, ...

Returns Configure ip address prefix(es).

Returns:

  • (Array<Hash>, Hash, nil) —

    Configure ip address prefix(es).



50
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 50

attribute :prefixes

#ranges ⇒ Object?

Returns Configure ip address range(s).

Returns:

  • (Object, nil) —

    Configure ip address range(s).



54
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 54

attribute :ranges

#state ⇒ :absent, ...

Returns The state that should be applied on the entity.

Returns:

  • (:absent, :present, nil) —

    The state that should be applied on the entity.



13
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 13

attribute :state

#tenant_ref ⇒ Object?

Returns It is a reference to an object of type tenant.

Returns:

  • (Object, nil) —

    It is a reference to an object of type tenant.



57
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 57

attribute :tenant_ref

#url ⇒ Object?

Returns Avi controller URL of the object.

Returns:

  • (Object, nil) —

    Avi controller URL of the object.



60
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 60

attribute :url

#uuid ⇒ Object?

Returns Uuid of the ip address group.

Returns:

  • (Object, nil) —

    Uuid of the ip address group.



63
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_ipaddrgroup.rb', line 63

attribute :uuid