Class: Ansible::Ruby::Modules::Avi_scheduler

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb

Overview

This module is used to configure Scheduler object more examples at U(https://github.com/avinetworks/devops)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#avi_api_patch_op ⇒ :add, ...

Returns Patch operation to use when using avi_api_update_method as patch.

Returns:

  • (:add, :replace, :delete, nil) —

    Patch operation to use when using avi_api_update_method as patch.



21
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 21

attribute :avi_api_patch_op

#avi_api_update_method ⇒ :put, ...

Returns Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.

Returns:

  • (:put, :patch, nil) —

    Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.



17
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 17

attribute :avi_api_update_method

#backup_config_ref ⇒ Object?

Returns Backup configuration to be executed by this scheduler.,It is a reference to an object of type backupconfiguration.

Returns:

  • (Object, nil) —

    Backup configuration to be executed by this scheduler.,It is a reference to an object of type backupconfiguration.



25
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 25

attribute :backup_config_ref

#enabled ⇒ Symbol?

Returns Boolean flag to set enabled.,Default value when not specified in API or module is interpreted by Avi Controller as True.

Returns:

  • (Symbol, nil) —

    Boolean flag to set enabled.,Default value when not specified in API or module is interpreted by Avi Controller as True.



28
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 28

attribute :enabled

#end_date_time ⇒ Object?

Returns Scheduler end date and time.

Returns:

  • (Object, nil) —

    Scheduler end date and time.



32
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 32

attribute :end_date_time

#frequency ⇒ Object?

Returns Frequency at which custom scheduler will run.,Allowed values are 0-60.

Returns:

  • (Object, nil) —

    Frequency at which custom scheduler will run.,Allowed values are 0-60.



35
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 35

attribute :frequency

#frequency_unit ⇒ Object?

Returns Unit at which custom scheduler will run.,Enum options - SCHEDULER_FREQUENCY_UNIT_MIN, SCHEDULER_FREQUENCY_UNIT_HOUR, SCHEDULER_FREQUENCY_UNIT_DAY, SCHEDULER_FREQUENCY_UNIT_WEEK,,SCHEDULER_FREQUENCY_UNIT_MONTH.

Returns:

  • (Object, nil) —

    Unit at which custom scheduler will run.,Enum options - SCHEDULER_FREQUENCY_UNIT_MIN, SCHEDULER_FREQUENCY_UNIT_HOUR, SCHEDULER_FREQUENCY_UNIT_DAY, SCHEDULER_FREQUENCY_UNIT_WEEK,,SCHEDULER_FREQUENCY_UNIT_MONTH.



38
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 38

attribute :frequency_unit

#name ⇒ String

Returns Name of scheduler.

Returns:

  • (String) —

    Name of scheduler.



41
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 41

attribute :name

#run_mode ⇒ Object?

Returns Scheduler run mode.,Enum options - RUN_MODE_PERIODIC, RUN_MODE_AT, RUN_MODE_NOW.

Returns:

  • (Object, nil) —

    Scheduler run mode.,Enum options - RUN_MODE_PERIODIC, RUN_MODE_AT, RUN_MODE_NOW.



45
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 45

attribute :run_mode

#run_script_ref ⇒ Object?

Returns Control script to be executed by this scheduler.,It is a reference to an object of type alertscriptconfig.

Returns:

  • (Object, nil) —

    Control script to be executed by this scheduler.,It is a reference to an object of type alertscriptconfig.



48
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 48

attribute :run_script_ref

#scheduler_action ⇒ Object?

Returns Define scheduler action.,Enum options - SCHEDULER_ACTION_RUN_A_SCRIPT, SCHEDULER_ACTION_BACKUP.,Default value when not specified in API or module is interpreted by Avi Controller as SCHEDULER_ACTION_BACKUP.

Returns:

  • (Object, nil) —

    Define scheduler action.,Enum options - SCHEDULER_ACTION_RUN_A_SCRIPT, SCHEDULER_ACTION_BACKUP.,Default value when not specified in API or module is interpreted by Avi Controller as SCHEDULER_ACTION_BACKUP.



51
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 51

attribute :scheduler_action

#start_date_time ⇒ Object?

Returns Scheduler start date and time.

Returns:

  • (Object, nil) —

    Scheduler start date and time.



54
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 54

attribute :start_date_time

#state ⇒ :absent, ...

Returns The state that should be applied on the entity.

Returns:

  • (:absent, :present, nil) —

    The state that should be applied on the entity.



13
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 13

attribute :state

#tenant_ref ⇒ Object?

Returns It is a reference to an object of type tenant.

Returns:

  • (Object, nil) —

    It is a reference to an object of type tenant.



57
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 57

attribute :tenant_ref

#url ⇒ Object?

Returns Avi controller URL of the object.

Returns:

  • (Object, nil) —

    Avi controller URL of the object.



60
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 60

attribute :url

#uuid ⇒ Object?

Returns Unique object identifier of the object.

Returns:

  • (Object, nil) —

    Unique object identifier of the object.



63
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_scheduler.rb', line 63

attribute :uuid