Class: Ansible::Ruby::Modules::Avi_webhook

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb

Overview

This module is used to configure Webhook object more examples at U(https://github.com/avinetworks/devops)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#avi_api_patch_op ⇒ :add, ...

Returns Patch operation to use when using avi_api_update_method as patch.

Returns:

  • (:add, :replace, :delete, nil) —

    Patch operation to use when using avi_api_update_method as patch.



21
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 21

attribute :avi_api_patch_op

#avi_api_update_method ⇒ :put, ...

Returns Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.

Returns:

  • (:put, :patch, nil) —

    Default method for object update is HTTP PUT.,Setting to patch will override that behavior to use HTTP PATCH.



17
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 17

attribute :avi_api_update_method

#callback_url ⇒ Object?

Returns Callback url for the webhook.,Field introduced in 17.1.1.

Returns:

  • (Object, nil) —

    Callback url for the webhook.,Field introduced in 17.1.1.



25
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 25

attribute :callback_url

#description ⇒ Object?

Returns Field introduced in 17.1.1.

Returns:

  • (Object, nil) —

    Field introduced in 17.1.1.



28
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 28

attribute :description

#name ⇒ String

Returns The name of the webhook profile.,Field introduced in 17.1.1.

Returns:

  • (String) —

    The name of the webhook profile.,Field introduced in 17.1.1.



31
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 31

attribute :name

#state ⇒ :absent, ...

Returns The state that should be applied on the entity.

Returns:

  • (:absent, :present, nil) —

    The state that should be applied on the entity.



13
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 13

attribute :state

#tenant_ref ⇒ Object?

Returns It is a reference to an object of type tenant.,Field introduced in 17.1.1.

Returns:

  • (Object, nil) —

    It is a reference to an object of type tenant.,Field introduced in 17.1.1.



35
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 35

attribute :tenant_ref

#url ⇒ Object?

Returns Avi controller URL of the object.

Returns:

  • (Object, nil) —

    Avi controller URL of the object.



38
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 38

attribute :url

#uuid ⇒ Object?

Returns Uuid of the webhook profile.,Field introduced in 17.1.1.

Returns:

  • (Object, nil) —

    Uuid of the webhook profile.,Field introduced in 17.1.1.



41
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 41

attribute :uuid

#verification_token ⇒ Object?

Returns Verification token sent back with the callback asquery parameters.,Field introduced in 17.1.1.

Returns:

  • (Object, nil) —

    Verification token sent back with the callback asquery parameters.,Field introduced in 17.1.1.



44
# File 'lib/ansible/ruby/modules/generated/network/avi/avi_webhook.rb', line 44

attribute :verification_token