Class: Ansible::Ruby::Modules::Aws_ses_identity_policy

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/amazon/aws_ses_identity_policy.rb

Overview

This module allows the user to manage sending authorization policies associated with an SES identity (email or domain). SES authorization sending policies can be used to control what actors are able to send email on behalf of the validated identity and what conditions must be met by the sent emails.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#identityString



13
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/aws_ses_identity_policy.rb', line 13

attribute :identity

#policyString?



21
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/aws_ses_identity_policy.rb', line 21

attribute :policy

#policy_nameString



17
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/aws_ses_identity_policy.rb', line 17

attribute :policy_name

#state:present, ...



25
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/aws_ses_identity_policy.rb', line 25

attribute :state