Class: Ansible::Ruby::Modules::Azure_rm_appgateway

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb

Overview

Create, update and delete instance of Application Gateway.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#authentication_certificates ⇒ Object?

Returns Authentication certificates of the application gateway resource.

Returns:

  • (Object, nil) —

    Authentication certificates of the application gateway resource.



34
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 34

attribute :authentication_certificates

#backend_address_pools ⇒ Array<Hash>, ...

Returns List of backend address pool of the application gateway resource.

Returns:

  • (Array<Hash>, Hash, nil) —

    List of backend address pool of the application gateway resource.



48
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 48

attribute :backend_address_pools

#backend_http_settings_collection ⇒ Array<Hash>, ...

Returns Backend http settings of the application gateway resource.

Returns:

  • (Array<Hash>, Hash, nil) —

    Backend http settings of the application gateway resource.



52
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 52

attribute :backend_http_settings_collection

#frontend_ip_configurations ⇒ Array<Hash>, ...

Returns Frontend IP addresses of the application gateway resource.

Returns:

  • (Array<Hash>, Hash, nil) —

    Frontend IP addresses of the application gateway resource.



40
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 40

attribute :frontend_ip_configurations

#frontend_ports ⇒ Array<Hash>, ...

Returns List of frontend ports of the application gateway resource.

Returns:

  • (Array<Hash>, Hash, nil) —

    List of frontend ports of the application gateway resource.



44
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 44

attribute :frontend_ports

#gateway_ip_configurations ⇒ Array<Hash>, ...

Returns List of subnets used by the application gateway.

Returns:

  • (Array<Hash>, Hash, nil) —

    List of subnets used by the application gateway.



30
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 30

attribute :gateway_ip_configurations

#http_listeners ⇒ Array<Hash>, ...

Returns List of HTTP listeners of the application gateway resource.

Returns:

  • (Array<Hash>, Hash, nil) —

    List of HTTP listeners of the application gateway resource.



56
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 56

attribute :http_listeners

#location ⇒ Object?

Returns Resource location. If not set, location from the resource group will be used as default.

Returns:

  • (Object, nil) —

    Resource location. If not set, location from the resource group will be used as default.



20
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 20

attribute :location

#name ⇒ String

Returns The name of the application gateway.

Returns:

  • (String) —

    The name of the application gateway.



16
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 16

attribute :name

#request_routing_rules ⇒ Array<Hash>, ...

Returns List of request routing rules of the application gateway resource.

Returns:

  • (Array<Hash>, Hash, nil) —

    List of request routing rules of the application gateway resource.



60
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 60

attribute :request_routing_rules

#resource_group ⇒ String

Returns The name of the resource group.

Returns:

  • (String) —

    The name of the resource group.



12
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 12

attribute :resource_group

#sku ⇒ Hash?

Returns SKU of the application gateway resource.

Returns:

  • (Hash, nil) —

    SKU of the application gateway resource.



23
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 23

attribute :sku

#ssl_certificates ⇒ Object?

Returns SSL certificates of the application gateway resource.

Returns:

  • (Object, nil) —

    SSL certificates of the application gateway resource.



37
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 37

attribute :ssl_certificates

#ssl_policy ⇒ Object?

Returns SSL policy of the application gateway resource.

Returns:

  • (Object, nil) —

    SSL policy of the application gateway resource.



27
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 27

attribute :ssl_policy

#state ⇒ :absent, ...

Returns Assert the state of the Public IP. Use 'present' to create or update a and 'absent' to delete.

Returns:

  • (:absent, :present, nil) —

    Assert the state of the Public IP. Use 'present' to create or update a and 'absent' to delete.



64
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 64

attribute :state