Class: Ansible::Ruby::Modules::Bigip_service_policy

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/f5/bigip_service_policy.rb

Overview

Service policies allow you to configure timers and port misuse rules, if enabled, on a per rule or per context basis.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#description ⇒ Object?

Returns Description of the service policy.

Returns:

  • (Object, nil) —

    Description of the service policy.



16
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_service_policy.rb', line 16

attribute :description

#name ⇒ String

Returns Name of the service policy.

Returns:

  • (String) —

    Name of the service policy.



12
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_service_policy.rb', line 12

attribute :name

#partition ⇒ String?

Returns Device partition to manage resources on.

Returns:

  • (String, nil) —

    Device partition to manage resources on.



31
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_service_policy.rb', line 31

attribute :partition

#port_misuse_policy ⇒ String?

Returns The port misuse policy to attach to the service policy.,Requires that C(afm) be provisioned to use. If C(afm) is not provisioned, this parameter will be ignored.

Returns:

  • (String, nil) —

    The port misuse policy to attach to the service policy.,Requires that C(afm) be provisioned to use. If C(afm) is not provisioned, this parameter will be ignored.



23
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_service_policy.rb', line 23

attribute :port_misuse_policy

#state ⇒ :present, ...

Returns Whether the resource should exist or not.

Returns:

  • (:present, :absent, nil) —

    Whether the resource should exist or not.



27
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_service_policy.rb', line 27

attribute :state

#timer_policy ⇒ String?

Returns The timer policy to attach to the service policy.

Returns:

  • (String, nil) —

    The timer policy to attach to the service policy.



19
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_service_policy.rb', line 19

attribute :timer_policy