Class: Ansible::Ruby::Modules::Bigip_smtp
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Bigip_smtp
- Defined in:
- lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb
Overview
Allows configuring of the BIG-IP to send mail via an SMTP server by configuring the parameters of an SMTP server.
Instance Method Summary collapse
-
#authentication ⇒ Symbol?
Credentials can be set on an SMTP server’s configuration even if that authentication is not used (think staging configs or emergency changes).
-
#encryption ⇒ :none, ...
Specifies whether the SMTP server requires an encrypted connection in order to send mail.
-
#from_address ⇒ String?
Email address that the email is being sent from.
-
#local_host_name ⇒ String?
Host name used in SMTP headers in the format of a fully qualified domain name.
-
#name ⇒ String
Specifies the name of the SMTP server configuration.
-
#partition ⇒ String?
Device partition to manage resources on.
-
#smtp_server ⇒ String?
SMTP server host name in the format of a fully qualified domain name.,This value is required when create a new SMTP configuration.
-
#smtp_server_password ⇒ String?
Password that the SMTP server requires when validating a user.
-
#smtp_server_port ⇒ Object?
Specifies the SMTP port number.,When creating a new SMTP configuration, the default is C(25) when C(encryption) is C(none) or C(tls).
-
#smtp_server_username ⇒ String?
User name that the SMTP server requires when validating a user.
-
#state ⇒ :present, ...
When C(present), ensures that the SMTP configuration exists.,When C(absent), ensures that the SMTP configuration does not exist.
-
#update_password ⇒ :always, ...
Passwords are stored encrypted, so the module cannot know if the supplied C(smtp_server_password) is the same or different than the existing password.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#authentication ⇒ Symbol?
39 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 39 attribute :authentication |
#encryption ⇒ :none, ...
35 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 35 attribute :encryption |
#from_address ⇒ String?
31 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 31 attribute :from_address |
#local_host_name ⇒ String?
27 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 27 attribute :local_host_name |
#name ⇒ String
12 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 12 attribute :name |
#partition ⇒ String?
16 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 16 attribute :partition |
#smtp_server ⇒ String?
20 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 20 attribute :smtp_server |
#smtp_server_password ⇒ String?
47 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 47 attribute :smtp_server_password |
#smtp_server_port ⇒ Object?
24 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 24 attribute :smtp_server_port |
#smtp_server_username ⇒ String?
43 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 43 attribute :smtp_server_username |
#state ⇒ :present, ...
51 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 51 attribute :state |
#update_password ⇒ :always, ...
55 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_smtp.rb', line 55 attribute :update_password |