Class: Ansible::Ruby::Modules::Bigip_ucs
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Bigip_ucs
- Defined in:
- lib/ansible/ruby/modules/generated/network/f5/bigip_ucs.rb
Overview
Manage upload, installation and removal of UCS files.
Instance Method Summary collapse
-
#force ⇒ Symbol?
If C(yes) will upload the file every time and replace the file on the device.
-
#include_chassis_level_config ⇒ Symbol?
During restore of the UCS file, include chassis level configuration that is shared among boot volume sets.
-
#no_license ⇒ Symbol?
Performs a full restore of the UCS file and all the files it contains, with the exception of the license file.
-
#no_platform_check ⇒ Symbol?
Bypasses the platform check and allows a UCS that was created using a different platform to be installed.
-
#passphrase ⇒ Symbol?
Specifies the passphrase that is necessary to load the specified UCS file.
-
#reset_trust ⇒ Symbol?
When specified, the device and trust domain certs and keys are not loaded from the UCS.
-
#state ⇒ :absent, ...
When C(installed), ensures that the UCS is uploaded and installed, on the system.
-
#ucs ⇒ String?
The path to the UCS file to install.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#force ⇒ Symbol?
20 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_ucs.rb', line 20 attribute :force |
#include_chassis_level_config ⇒ Symbol?
12 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_ucs.rb', line 12 attribute :include_chassis_level_config |
#no_license ⇒ Symbol?
24 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_ucs.rb', line 24 attribute :no_license |
#no_platform_check ⇒ Symbol?
28 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_ucs.rb', line 28 attribute :no_platform_check |
#passphrase ⇒ Symbol?
32 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_ucs.rb', line 32 attribute :passphrase |
#reset_trust ⇒ Symbol?
36 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_ucs.rb', line 36 attribute :reset_trust |
#state ⇒ :absent, ...
40 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_ucs.rb', line 40 attribute :state |
#ucs ⇒ String?
16 |
# File 'lib/ansible/ruby/modules/generated/network/f5/bigip_ucs.rb', line 16 attribute :ucs |