Class: Ansible::Ruby::Modules::Certificate_complete_chain

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/crypto/certificate_complete_chain.rb

Overview

This module completes a given chain of certificates in PEM format by finding intermediate certificates from a given set of certificates, until it finds a root certificate in another given set of certificates. This can for example be used to find the root certificate for a certificate chain returned by M(acme_certificate). Note that this module does I(not) check for validity of the chains. It only checks that issuer and subject match, and that the signature is correct. It ignores validity dates and key usage completely. If you need to verify that a generated chain is valid, please use C(openssl verify …).

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#input_chainString



14
# File 'lib/ansible/ruby/modules/generated/crypto/certificate_complete_chain.rb', line 14

attribute :input_chain

#intermediate_certificatesArray<String>, ...



22
# File 'lib/ansible/ruby/modules/generated/crypto/certificate_complete_chain.rb', line 22

attribute :intermediate_certificates

#root_certificatesArray<String>, String



18
# File 'lib/ansible/ruby/modules/generated/crypto/certificate_complete_chain.rb', line 18

attribute :root_certificates