Class: Ansible::Ruby::Modules::Clc_firewall_policy

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb

Overview

Create or delete or update firewall polices on Centurylink Cloud

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#destination ⇒ Object?

Returns The list of destination addresses for traffic on the terminating firewall. This is required when state is 'present'.

Returns:

  • (Object, nil) —

    The list of destination addresses for traffic on the terminating firewall. This is required when state is 'present'



23
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 23

attribute :destination

#destination_account_alias ⇒ Object?

Returns CLC alias for the destination account.

Returns:

  • (Object, nil) —

    CLC alias for the destination account



37
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 37

attribute :destination_account_alias

#enabled ⇒ Boolean?

Returns Whether the firewall policy is enabled or disabled.

Returns:

  • (Boolean, nil) —

    Whether the firewall policy is enabled or disabled



44
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 44

attribute :enabled

#firewall_policy_id ⇒ Object?

Returns Id of the firewall policy. This is required to update or delete an existing firewall policy.

Returns:

  • (Object, nil) —

    Id of the firewall policy. This is required to update or delete an existing firewall policy



30
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 30

attribute :firewall_policy_id

#location ⇒ Object

Returns Target datacenter for the firewall policy.

Returns:

  • (Object) —

    Target datacenter for the firewall policy



12
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 12

attribute :location

#ports ⇒ :any, ...

Returns The list of ports associated with the policy. TCP and UDP can take in single ports or port ranges.

Returns:

  • (:any, :icmp, :"TCP/123", :"UDP/123", :"TCP/123-456", :"UDP/123-456", nil) —

    The list of ports associated with the policy. TCP and UDP can take in single ports or port ranges.



26
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 26

attribute :ports

#source ⇒ Object?

Returns The list of source addresses for traffic on the originating firewall. This is required when state is 'present'.

Returns:

  • (Object, nil) —

    The list of source addresses for traffic on the originating firewall. This is required when state is 'present'



20
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 20

attribute :source

#source_account_alias ⇒ Object

Returns CLC alias for the source account.

Returns:

  • (Object) —

    CLC alias for the source account



33
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 33

attribute :source_account_alias

#state ⇒ :present, ...

Returns Whether to create or delete the firewall policy.

Returns:

  • (:present, :absent, nil) —

    Whether to create or delete the firewall policy



16
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 16

attribute :state

#wait ⇒ :yes, ...

Returns Whether to wait for the provisioning tasks to finish before returning.

Returns:

  • (:yes, :no, nil) —

    Whether to wait for the provisioning tasks to finish before returning.



40
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_firewall_policy.rb', line 40

attribute :wait