Class: Ansible::Ruby::Modules::Clc_server

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb

Overview

An Ansible module to Create, Delete, Start and Stop servers in CenturyLink Cloud.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#add_public_ip ⇒ :yes, ...

Returns Whether to add a public ip to the server.

Returns:

  • (:yes, :no, nil) —

    Whether to add a public ip to the server



15
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 15

attribute :add_public_ip

#additional_disks ⇒ Object?

Returns The list of additional disks for the server.

Returns:

  • (Object, nil) —

    The list of additional disks for the server



12
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 12

attribute :additional_disks

#alert_policy_id ⇒ Object?

Returns The alert policy to assign to the server. This is mutually exclusive with 'alert_policy_name'.

Returns:

  • (Object, nil) —

    The alert policy to assign to the server. This is mutually exclusive with 'alert_policy_name'.



28
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 28

attribute :alert_policy_id

#alert_policy_name ⇒ Object?

Returns The alert policy to assign to the server. This is mutually exclusive with 'alert_policy_id'.

Returns:

  • (Object, nil) —

    The alert policy to assign to the server. This is mutually exclusive with 'alert_policy_id'.



31
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 31

attribute :alert_policy_name

#alias ⇒ Object?

Returns The account alias to provision the servers under.

Returns:

  • (Object, nil) —

    The account alias to provision the servers under.



19
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 19

attribute :alias

#anti_affinity_policy_id ⇒ Object?

Returns The anti-affinity policy to assign to the server. This is mutually exclusive with 'anti_affinity_policy_name'.

Returns:

  • (Object, nil) —

    The anti-affinity policy to assign to the server. This is mutually exclusive with 'anti_affinity_policy_name'.



22
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 22

attribute :anti_affinity_policy_id

#anti_affinity_policy_name ⇒ Object?

Returns The anti-affinity policy to assign to the server. This is mutually exclusive with 'anti_affinity_policy_id'.

Returns:

  • (Object, nil) —

    The anti-affinity policy to assign to the server. This is mutually exclusive with 'anti_affinity_policy_id'.



25
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 25

attribute :anti_affinity_policy_name

#configuration_id ⇒ Object?

Returns Only required for bare metal servers. Specifies the identifier for the specific configuration type of bare metal server to deploy.

Returns:

  • (Object, nil) —

    Only required for bare metal servers. Specifies the identifier for the specific configuration type of bare metal server to deploy.



128
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 128

attribute :configuration_id

#count ⇒ Integer?

Returns The number of servers to build (mutually exclusive with exact_count).

Returns:

  • (Integer, nil) —

    The number of servers to build (mutually exclusive with exact_count)



34
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 34

attribute :count

#count_group ⇒ String?

Returns Required when exact_count is specified. The Server Group use to determine how many severs to deploy.

Returns:

  • (String, nil) —

    Required when exact_count is specified. The Server Group use to determine how many severs to deploy.



38
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 38

attribute :count_group

#cpu ⇒ Integer?

Returns How many CPUs to provision on the server.

Returns:

  • (Integer, nil) —

    How many CPUs to provision on the server



42
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 42

attribute :cpu

#cpu_autoscale_policy_id ⇒ Object?

Returns The autoscale policy to assign to the server.

Returns:

  • (Object, nil) —

    The autoscale policy to assign to the server.



46
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 46

attribute :cpu_autoscale_policy_id

#custom_fields ⇒ Object?

Returns The list of custom fields to set on the server.

Returns:

  • (Object, nil) —

    The list of custom fields to set on the server.



49
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 49

attribute :custom_fields

#description ⇒ Object?

Returns The description to set for the server.

Returns:

  • (Object, nil) —

    The description to set for the server.



52
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 52

attribute :description

#exact_count ⇒ Integer?

Returns Run in idempotent mode. Will insure that this exact number of servers are running in the provided group, creating and deleting them to reach that count. Requires count_group to be set.

Returns:

  • (Integer, nil) —

    Run in idempotent mode. Will insure that this exact number of servers are running in the provided group, creating and deleting them to reach that count. Requires count_group to be set.



55
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 55

attribute :exact_count

#group ⇒ String?

Returns The Server Group to create servers under.

Returns:

  • (String, nil) —

    The Server Group to create servers under.



59
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 59

attribute :group

#ip_address ⇒ Object?

Returns The IP Address for the server. One is assigned if not provided.

Returns:

  • (Object, nil) —

    The IP Address for the server. One is assigned if not provided.



63
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 63

attribute :ip_address

#location ⇒ Object?

Returns The Datacenter to create servers in.

Returns:

  • (Object, nil) —

    The Datacenter to create servers in.



66
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 66

attribute :location

#managed_os ⇒ :yes, ...

Returns Whether to create the server as 'Managed' or not.

Returns:

  • (:yes, :no, nil) —

    Whether to create the server as 'Managed' or not.



69
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 69

attribute :managed_os

#memory ⇒ Integer?

Returns Memory in GB.

Returns:

  • (Integer, nil) —

    Memory in GB.



73
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 73

attribute :memory

#name ⇒ String?

Returns A 1 to 6 character identifier to use for the server. This is required when state is 'present'.

Returns:

  • (String, nil) —

    A 1 to 6 character identifier to use for the server. This is required when state is 'present'



77
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 77

attribute :name

#network_id ⇒ Object?

Returns The network UUID on which to create servers.

Returns:

  • (Object, nil) —

    The network UUID on which to create servers.



81
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 81

attribute :network_id

#os_type ⇒ :redHat6_64Bit, ...

Returns Only required for bare metal servers. Specifies the OS to provision with the bare metal server.

Returns:

  • (:redHat6_64Bit, :centOS6_64Bit, :windows2012R2Standard_64Bit, :ubuntu14_64Bit, nil) —

    Only required for bare metal servers. Specifies the OS to provision with the bare metal server.



131
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 131

attribute :os_type

#packages ⇒ Object?

Returns The list of blue print packages to run on the server after its created.

Returns:

  • (Object, nil) —

    The list of blue print packages to run on the server after its created.



84
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 84

attribute :packages

#password ⇒ Object?

Returns Password for the administrator / root user.

Returns:

  • (Object, nil) —

    Password for the administrator / root user



87
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 87

attribute :password

#primary_dns ⇒ Object?

Returns Primary DNS used by the server.

Returns:

  • (Object, nil) —

    Primary DNS used by the server.



90
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 90

attribute :primary_dns

#public_ip_ports ⇒ Object?

Returns A list of ports to allow on the firewall to the servers public ip, if add_public_ip is set to True.

Returns:

  • (Object, nil) —

    A list of ports to allow on the firewall to the servers public ip, if add_public_ip is set to True.



97
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 97

attribute :public_ip_ports

#public_ip_protocol ⇒ :TCP, ...

Returns The protocol to use for the public ip if add_public_ip is set to True.

Returns:

  • (:TCP, :UDP, :ICMP, nil) —

    The protocol to use for the public ip if add_public_ip is set to True.



93
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 93

attribute :public_ip_protocol

#secondary_dns ⇒ Object?

Returns Secondary DNS used by the server.

Returns:

  • (Object, nil) —

    Secondary DNS used by the server.



100
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 100

attribute :secondary_dns

#server_ids ⇒ Object?

Returns Required for started, stopped, and absent states. A list of server Ids to insure are started, stopped, or absent.

Returns:

  • (Object, nil) —

    Required for started, stopped, and absent states. A list of server Ids to insure are started, stopped, or absent.



103
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 103

attribute :server_ids

#source_server_password ⇒ Object?

Returns The password for the source server if a clone is specified.

Returns:

  • (Object, nil) —

    The password for the source server if a clone is specified.



106
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 106

attribute :source_server_password

#state ⇒ :present, ...

Returns The state to insure that the provided resources are in.

Returns:

  • (:present, :absent, :started, :stopped, nil) —

    The state to insure that the provided resources are in.



109
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 109

attribute :state

#storage_type ⇒ :standard, ...

Returns The type of storage to attach to the server.

Returns:

  • (:standard, :hyperscale, nil) —

    The type of storage to attach to the server.



113
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 113

attribute :storage_type

#template ⇒ String?

Returns The template to use for server creation. Will search for a template if a partial string is provided. This is required when state is 'present'.

Returns:

  • (String, nil) —

    The template to use for server creation. Will search for a template if a partial string is provided. This is required when state is 'present'



117
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 117

attribute :template

#ttl ⇒ Object?

Returns The time to live for the server in seconds. The server will be deleted when this time expires.

Returns:

  • (Object, nil) —

    The time to live for the server in seconds. The server will be deleted when this time expires.



121
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 121

attribute :ttl

#type ⇒ :standard, ...

Returns The type of server to create.

Returns:

  • (:standard, :hyperscale, :bareMetal, nil) —

    The type of server to create.



124
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 124

attribute :type

#wait ⇒ :yes, ...

Returns Whether to wait for the provisioning tasks to finish before returning.

Returns:

  • (:yes, :no, nil) —

    Whether to wait for the provisioning tasks to finish before returning.



135
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 135

attribute :wait