Class: Ansible::Ruby::Modules::Cloudscale_floating_ip

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_floating_ip.rb

Overview

Create, assign and delete floating IPs on the cloudscale.ch IaaS service. All operations are performed using the cloudscale.ch public API v1. For details consult the full API documentation: U(https://www.cloudscale.ch/en/api/v1). A valid API token is required for all operations. You can create as many tokens as you like using the cloudscale.ch control panel at U(https://control.cloudscale.ch).

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#api_timeout ⇒ Integer?

Returns Timeout in seconds for calls to the cloudscale.ch API.

Returns:

  • (Integer, nil) —

    Timeout in seconds for calls to the cloudscale.ch API.



43
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_floating_ip.rb', line 43

attribute :api_timeout

#api_token ⇒ String?

Returns cloudscale.ch API token.,This can also be passed in the CLOUDSCALE_API_TOKEN environment variable.

Returns:

  • (String, nil) —

    cloudscale.ch API token.,This can also be passed in the CLOUDSCALE_API_TOKEN environment variable.



39
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_floating_ip.rb', line 39

attribute :api_token

#ip ⇒ String?

Returns Floating IP address to change.,Required to assign the IP to a different server or if I(state) is absent.

Returns:

  • (String, nil) —

    Floating IP address to change.,Required to assign the IP to a different server or if I(state) is absent.



19
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_floating_ip.rb', line 19

attribute :ip

#ip_version ⇒ 4, ...

Returns IP protocol version of the floating IP.

Returns:

  • (4, 6, nil) —

    IP protocol version of the floating IP.



23
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_floating_ip.rb', line 23

attribute :ip_version

#prefix_length ⇒ 56?

Returns Only valid if I(ip_version) is 6.,Prefix length for the IPv6 network. Currently only a prefix of /56 can be requested. If no I(prefix_length) is present, a single address is created.

Returns:

  • (56, nil) —

    Only valid if I(ip_version) is 6.,Prefix length for the IPv6 network. Currently only a prefix of /56 can be requested. If no I(prefix_length) is present, a single address is created.



31
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_floating_ip.rb', line 31

attribute :prefix_length

#reverse_ptr ⇒ String?

Returns Reverse PTR entry for this address.,You cannot set a reverse PTR entry for IPv6 floating networks. Reverse PTR entries are only allowed for single addresses.

Returns:

  • (String, nil) —

    Reverse PTR entry for this address.,You cannot set a reverse PTR entry for IPv6 floating networks. Reverse PTR entries are only allowed for single addresses.



35
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_floating_ip.rb', line 35

attribute :reverse_ptr

#server ⇒ String?

Returns UUID of the server assigned to this floating IP.,Required unless I(state) is absent.

Returns:

  • (String, nil) —

    UUID of the server assigned to this floating IP.,Required unless I(state) is absent.



27
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_floating_ip.rb', line 27

attribute :server

#state ⇒ :present, ...

Returns State of the floating IP.

Returns:

  • (:present, :absent, nil) —

    State of the floating IP.



15
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_floating_ip.rb', line 15

attribute :state