Class: Ansible::Ruby::Modules::Cloudscale_server

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb

Overview

Create, start, stop and delete servers on the cloudscale.ch IaaS service. All operations are performed using the cloudscale.ch public API v1. For details consult the full API documentation: U(https://www.cloudscale.ch/en/api/v1). A valid API token is required for all operations. You can create as many tokens as you like using the cloudscale.ch control panel at U(https://control.cloudscale.ch).

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#anti_affinity_with ⇒ String?

Returns UUID of another server to create an anti-affinity group with.

Returns:

  • (String, nil) —

    UUID of another server to create an anti-affinity group with.



59
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 59

attribute :anti_affinity_with

#api_timeout ⇒ Integer?

Returns Timeout in seconds for calls to the cloudscale.ch API.

Returns:

  • (Integer, nil) —

    Timeout in seconds for calls to the cloudscale.ch API.



70
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 70

attribute :api_timeout

#api_token ⇒ String?

Returns cloudscale.ch API token.,This can also be passed in the CLOUDSCALE_API_TOKEN environment variable.

Returns:

  • (String, nil) —

    cloudscale.ch API token.,This can also be passed in the CLOUDSCALE_API_TOKEN environment variable.



66
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 66

attribute :api_token

#bulk_volume_size_gb ⇒ Integer?

Returns Size of the bulk storage volume in GB.,No bulk storage volume if not set.

Returns:

  • (Integer, nil) —

    Size of the bulk storage volume in GB.,No bulk storage volume if not set.



39
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 39

attribute :bulk_volume_size_gb

#flavor ⇒ String?

Returns Flavor of the server.

Returns:

  • (String, nil) —

    Flavor of the server.



27
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 27

attribute :flavor

#image ⇒ String?

Returns Image used to create the server.

Returns:

  • (String, nil) —

    Image used to create the server.



31
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 31

attribute :image

#name ⇒ String?

Returns Name of the Server.,Either C(name) or C(uuid) are required. These options are mutually exclusive.

Returns:

  • (String, nil) —

    Name of the Server.,Either C(name) or C(uuid) are required. These options are mutually exclusive.



19
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 19

attribute :name

#ssh_keys ⇒ String?

Returns List of SSH public keys.,Use the full content of your .pub file here.

Returns:

  • (String, nil) —

    List of SSH public keys.,Use the full content of your .pub file here.



43
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 43

attribute :ssh_keys

#state ⇒ :running, ...

Returns State of the server.

Returns:

  • (:running, :stopped, :absent, nil) —

    State of the server



15
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 15

attribute :state

#use_ipv6 ⇒ Boolean?

Returns Enable IPv6 on the public network interface.

Returns:

  • (Boolean, nil) —

    Enable IPv6 on the public network interface.



55
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 55

attribute :use_ipv6

#use_private_network ⇒ Boolean?

Returns Attach a private network interface to the server.

Returns:

  • (Boolean, nil) —

    Attach a private network interface to the server.



51
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 51

attribute :use_private_network

#use_public_network ⇒ Boolean?

Returns Attach a public network interface to the server.

Returns:

  • (Boolean, nil) —

    Attach a public network interface to the server.



47
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 47

attribute :use_public_network

#user_data ⇒ Object?

Returns Cloud-init configuration (cloud-config) data to use for the server.

Returns:

  • (Object, nil) —

    Cloud-init configuration (cloud-config) data to use for the server.



63
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 63

attribute :user_data

#uuid ⇒ String?

Returns UUID of the server.,Either C(name) or C(uuid) are required. These options are mutually exclusive.

Returns:

  • (String, nil) —

    UUID of the server.,Either C(name) or C(uuid) are required. These options are mutually exclusive.



23
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 23

attribute :uuid

#volume_size_gb ⇒ Integer?

Returns Size of the root volume in GB.

Returns:

  • (Integer, nil) —

    Size of the root volume in GB.



35
# File 'lib/ansible/ruby/modules/generated/cloud/cloudscale/cloudscale_server.rb', line 35

attribute :volume_size_gb