Class: Ansible::Ruby::Modules::Cnos_conditional_command
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Cnos_conditional_command
- Defined in:
- lib/ansible/ruby/modules/generated/network/cnos/cnos_conditional_command.rb
Overview
This module allows you to modify the running configuration of a switch. It provides a way to execute a single CNOS command on a network device by evaluating the current running configuration and executing the command only if the specific settings have not been already configured. The CNOS command is passed as an argument of the method. This module functions the same as the cnos_command module. The only exception is that following inventory variable can be specified ["condition =
Instance Method Summary collapse
-
#clicommand ⇒ Object
This specifies the CLI command as an attribute to this method.
-
#condition ⇒ Object
If you specify condition=false in the inventory file against any device, the command execution is skipped for that device.
-
#flag ⇒ Object
If a task needs to be executed, you have to set the flag the same as it is specified in the inventory for that device.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#clicommand ⇒ Object
Returns This specifies the CLI command as an attribute to this method. The command is passed using double quotes. The variables can be placed directly on to the CLI commands or can be invoked from the vars directory.
12 |
# File 'lib/ansible/ruby/modules/generated/network/cnos/cnos_conditional_command.rb', line 12 attribute :clicommand |
#condition ⇒ Object
Returns If you specify condition=false in the inventory file against any device, the command execution is skipped for that device.
16 |
# File 'lib/ansible/ruby/modules/generated/network/cnos/cnos_conditional_command.rb', line 16 attribute :condition |
#flag ⇒ Object
Returns If a task needs to be executed, you have to set the flag the same as it is specified in the inventory for that device.
20 |
# File 'lib/ansible/ruby/modules/generated/network/cnos/cnos_conditional_command.rb', line 20 attribute :flag |