Class: Ansible::Ruby::Modules::Cnos_facts

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/cnos/cnos_facts.rb

Overview

Collects a base set of device facts from a remote Lenovo device running on CNOS. This module prepends all of the base network fact keys with C(ansible_net_). The facts module will always collect a base set of facts from the device and can enable or disable collection of additional facts.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#auth_pass ⇒ Object?



16
# File 'lib/ansible/ruby/modules/generated/network/cnos/cnos_facts.rb', line 16

attribute :auth_pass

#authorize ⇒ :yes, ...



12
# File 'lib/ansible/ruby/modules/generated/network/cnos/cnos_facts.rb', line 12

attribute :authorize

#gather_subset ⇒ String?



22
# File 'lib/ansible/ruby/modules/generated/network/cnos/cnos_facts.rb', line 22

attribute :gather_subset

#provider ⇒ Object?



19
# File 'lib/ansible/ruby/modules/generated/network/cnos/cnos_facts.rb', line 19

attribute :provider