Class: Ansible::Ruby::Modules::Cs_host

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb

Overview

Create, update and remove hosts.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#allocation_state ⇒ :enabled, ...

Returns Allocation state of the host.

Returns:

  • (:enabled, :disabled, nil) —

    Allocation state of the host.



37
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 37

attribute :allocation_state

#cluster ⇒ String?

Returns Name of the cluster.

Returns:

  • (String, nil) —

    Name of the cluster.



29
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 29

attribute :cluster

#host_tags ⇒ Array<String>, ...

Returns Tags of the host.

Returns:

  • (Array<String>, String, nil) —

    Tags of the host.



41
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 41

attribute :host_tags

#hypervisor ⇒ :KVM, ...

Returns Name of the cluster.,Required if C(state=present) and host does not yet exist.

Returns:

  • (:KVM, :VMware, :BareMetal, :XenServer, :LXC, :HyperV, :UCS, :OVM, :Simulator, nil) —

    Name of the cluster.,Required if C(state=present) and host does not yet exist.



33
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 33

attribute :hypervisor

#name ⇒ String

Returns Name of the host.

Returns:

  • (String) —

    Name of the host.



12
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 12

attribute :name

#password ⇒ Object?

Returns Password for the host.,Required if C(state=present) and host does not yet exist.

Returns:

  • (Object, nil) —

    Password for the host.,Required if C(state=present) and host does not yet exist.



22
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 22

attribute :password

#pod ⇒ String?

Returns Name of the pod.,Required if C(state=present) and host does not yet exist.

Returns:

  • (String, nil) —

    Name of the pod.,Required if C(state=present) and host does not yet exist.



25
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 25

attribute :pod

#state ⇒ :present, ...

Returns State of the host.

Returns:

  • (:present, :absent, nil) —

    State of the host.



45
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 45

attribute :state

#url ⇒ Object?

Returns Url of the host used to create a host.,If not provided, C(http://) and param C(name) is used as url.,Only considered if C(state=present) and host does not yet exist.

Returns:

  • (Object, nil) —

    Url of the host used to create a host.,If not provided, C(http://) and param C(name) is used as url.,Only considered if C(state=present) and host does not yet exist.



16
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 16

attribute :url

#username ⇒ Object?

Returns Username for the host.,Required if C(state=present) and host does not yet exist.

Returns:

  • (Object, nil) —

    Username for the host.,Required if C(state=present) and host does not yet exist.



19
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 19

attribute :username

#zone ⇒ String?

Returns Name of the zone in which the host should be deployed.,If not set, default zone is used.

Returns:

  • (String, nil) —

    Name of the zone in which the host should be deployed.,If not set, default zone is used.



49
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_host.rb', line 49

attribute :zone