Class: Ansible::Ruby::Modules::Cs_network_acl_rule

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb

Overview

Add, update and remove network ACL rules.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#account ⇒ Object?

Returns Account the VPC is related to.

Returns:

  • (Object, nil) —

    Account the VPC is related to.



63
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 63

attribute :account

#action_policy ⇒ :allow, ...

Returns Action policy of the rule.

Returns:

  • (:allow, :deny, nil) —

    Action policy of the rule.



53
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 53

attribute :action_policy

#cidr ⇒ String?

Returns CIDR of the rule.

Returns:

  • (String, nil) —

    CIDR of the rule.



16
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 16

attribute :cidr

#domain ⇒ Object?

Returns Domain the VPC is related to.

Returns:

  • (Object, nil) —

    Domain the VPC is related to.



60
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 60

attribute :domain

#end_port ⇒ Integer?

Returns End port for this rule.,Considered if C(protocol=tcp) or C(protocol=udp).,If not specified, equal C(start_port).

Returns:

  • (Integer, nil) —

    End port for this rule.,Considered if C(protocol=tcp) or C(protocol=udp).,If not specified, equal C(start_port).



35
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 35

attribute :end_port

#icmp_code ⇒ Object?

Returns Error code for this icmp message.,Considered if C(protocol=icmp).

Returns:

  • (Object, nil) —

    Error code for this icmp message.,Considered if C(protocol=icmp).



42
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 42

attribute :icmp_code

#icmp_type ⇒ Object?

Returns Type of the icmp message being sent.,Considered if C(protocol=icmp).

Returns:

  • (Object, nil) —

    Type of the icmp message being sent.,Considered if C(protocol=icmp).



39
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 39

attribute :icmp_type

#network_acl ⇒ String

Returns Name of the network ACL.

Returns:

  • (String) —

    Name of the network ACL.



12
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 12

attribute :network_acl

#poll_async ⇒ :yes, ...

Returns Poll async jobs until job has finished.

Returns:

  • (:yes, :no, nil) —

    Poll async jobs until job has finished.



76
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 76

attribute :poll_async

#project ⇒ Object?

Returns Name of the project the VPC is related to.

Returns:

  • (Object, nil) —

    Name of the project the VPC is related to.



66
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 66

attribute :project

#protocol ⇒ :tcp, ...

Returns Protocol of the rule.

Returns:

  • (:tcp, :udp, :icmp, :all, :by_number, nil) —

    Protocol of the rule



24
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 24

attribute :protocol

#protocol_number ⇒ Object?

Returns Protocol number from 1 to 256 required if C(protocol=by_number).

Returns:

  • (Object, nil) —

    Protocol number from 1 to 256 required if C(protocol=by_number).



28
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 28

attribute :protocol_number

#rule_position ⇒ Integer

Returns CIDR of the rule.

Returns:

  • (Integer) —

    CIDR of the rule.



20
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 20

attribute :rule_position

#start_port ⇒ Integer?

Returns Start port for this rule.,Considered if C(protocol=tcp) or C(protocol=udp).

Returns:

  • (Integer, nil) —

    Start port for this rule.,Considered if C(protocol=tcp) or C(protocol=udp).



31
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 31

attribute :start_port

#state ⇒ :present, ...

Returns State of the network ACL rule.

Returns:

  • (:present, :absent, nil) —

    State of the network ACL rule.



72
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 72

attribute :state

#tags ⇒ Object?

Returns List of tags. Tags are a list of dictionaries having keys C(key) and C(value).,If you want to delete all tags, set a empty list e.g. C(tags: []).

Returns:

  • (Object, nil) —

    List of tags. Tags are a list of dictionaries having keys C(key) and C(value).,If you want to delete all tags, set a empty list e.g. C(tags: []).



57
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 57

attribute :tags

#traffic_type ⇒ :ingress, ...

Returns Traffic type of the rule.

Returns:

  • (:ingress, :egress, nil) —

    Traffic type of the rule.



49
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 49

attribute :traffic_type

#vpc ⇒ String

Returns VPC the network ACL is related to.

Returns:

  • (String) —

    VPC the network ACL is related to.



45
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 45

attribute :vpc

#zone ⇒ Object?

Returns Name of the zone the VPC related to.,If not set, default zone is used.

Returns:

  • (Object, nil) —

    Name of the zone the VPC related to.,If not set, default zone is used.



69
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_network_acl_rule.rb', line 69

attribute :zone