Class: Ansible::Ruby::Modules::Cs_router

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_router.rb

Overview

Start, restart, stop and destroy routers. C(state=present) is not able to create routers, use M(cs_network) instead.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#account ⇒ Object?

Returns Account the router is related to.

Returns:

  • (Object, nil) —

    Account the router is related to.



24
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_router.rb', line 24

attribute :account

#domain ⇒ Object?

Returns Domain the router is related to.

Returns:

  • (Object, nil) —

    Domain the router is related to.



21
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_router.rb', line 21

attribute :domain

#name ⇒ String

Returns Name of the router.

Returns:

  • (String) —

    Name of the router.



13
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_router.rb', line 13

attribute :name

#poll_async ⇒ Boolean?

Returns Poll async jobs until job has finished.

Returns:

  • (Boolean, nil) —

    Poll async jobs until job has finished.



37
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_router.rb', line 37

attribute :poll_async

#project ⇒ Object?

Returns Name of the project the router is related to.

Returns:

  • (Object, nil) —

    Name of the project the router is related to.



27
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_router.rb', line 27

attribute :project

#service_offering ⇒ String?

Returns Name or id of the service offering of the router.

Returns:

  • (String, nil) —

    Name or id of the service offering of the router.



17
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_router.rb', line 17

attribute :service_offering

#state ⇒ :present, ...

Returns State of the router.

Returns:

  • (:present, :absent, :started, :stopped, :restarted, nil) —

    State of the router.



33
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_router.rb', line 33

attribute :state

#zone ⇒ Object?

Returns Name of the zone the router is deployed in.,If not set, all zones are used.

Returns:

  • (Object, nil) —

    Name of the zone the router is deployed in.,If not set, all zones are used.



30
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_router.rb', line 30

attribute :zone