Class: Ansible::Ruby::Modules::Cs_securitygroup

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_securitygroup.rb

Overview

Create and remove security groups.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#account ⇒ Object?

Returns Account the security group is related to.

Returns:

  • (Object, nil) —

    Account the security group is related to.



27
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_securitygroup.rb', line 27

attribute :account

#description ⇒ String?

Returns Description of the security group.

Returns:

  • (String, nil) —

    Description of the security group.



16
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_securitygroup.rb', line 16

attribute :description

#domain ⇒ Object?

Returns Domain the security group is related to.

Returns:

  • (Object, nil) —

    Domain the security group is related to.



24
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_securitygroup.rb', line 24

attribute :domain

#name ⇒ String

Returns Name of the security group.

Returns:

  • (String) —

    Name of the security group.



12
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_securitygroup.rb', line 12

attribute :name

#project ⇒ Object?

Returns Name of the project the security group to be created in.

Returns:

  • (Object, nil) —

    Name of the project the security group to be created in.



30
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_securitygroup.rb', line 30

attribute :project

#state ⇒ :present, ...

Returns State of the security group.

Returns:

  • (:present, :absent, nil) —

    State of the security group.



20
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_securitygroup.rb', line 20

attribute :state