Class: Ansible::Ruby::Modules::Cs_staticnat

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb

Overview

Create, update and remove static NATs.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#account ⇒ Object?

Returns Account the static NAT is related to.

Returns:

  • (Object, nil) —

    Account the static NAT is related to.



37
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 37

attribute :account

#domain ⇒ Object?

Returns Domain the static NAT is related to.

Returns:

  • (Object, nil) —

    Domain the static NAT is related to.



34
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 34

attribute :domain

#ip_address ⇒ String

Returns Public IP address the static NAT is assigned to.

Returns:

  • (String) —

    Public IP address the static NAT is assigned to.



12
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 12

attribute :ip_address

#network ⇒ Object?

Returns Network the IP address is related to.

Returns:

  • (Object, nil) —

    Network the IP address is related to.



24
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 24

attribute :network

#poll_async ⇒ :yes, ...

Returns Poll async jobs until job has finished.

Returns:

  • (:yes, :no, nil) —

    Poll async jobs until job has finished.



46
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 46

attribute :poll_async

#project ⇒ Object?

Returns Name of the project the static NAT is related to.

Returns:

  • (Object, nil) —

    Name of the project the static NAT is related to.



40
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 40

attribute :project

#state ⇒ :present, ...

Returns State of the static NAT.

Returns:

  • (:present, :absent, nil) —

    State of the static NAT.



30
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 30

attribute :state

#vm ⇒ String?

Returns Name of virtual machine which we make the static NAT for.,Required if C(state=present).

Returns:

  • (String, nil) —

    Name of virtual machine which we make the static NAT for.,Required if C(state=present).



16
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 16

attribute :vm

#vm_guest_ip ⇒ :yes, ...

Returns VM guest NIC secondary IP address for the static NAT.

Returns:

  • (:yes, :no, nil) —

    VM guest NIC secondary IP address for the static NAT.



20
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 20

attribute :vm_guest_ip

#vpc ⇒ Object?

Returns VPC the network related to.

Returns:

  • (Object, nil) —

    VPC the network related to.



27
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 27

attribute :vpc

#zone ⇒ Object?

Returns Name of the zone in which the virtual machine is in.,If not set, default zone is used.

Returns:

  • (Object, nil) —

    Name of the zone in which the virtual machine is in.,If not set, default zone is used.



43
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_staticnat.rb', line 43

attribute :zone