Class: Ansible::Ruby::Modules::Cs_template
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Cs_template
- Defined in:
- lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb
Overview
Register templates from an URL. Create templates from a ROOT volume of a stopped VM or its snapshot. Update (since version 2.7), extract and delete templates.
Instance Method Summary collapse
-
#account ⇒ Object?
Account the template, snapshot or VM is related to.
-
#bits ⇒ 32, ...
32 or 64 bits support.
-
#checksum ⇒ Object?
The MD5 checksum value of this template.,If set, we search by checksum instead of name.
-
#cross_zones ⇒ Symbol?
Whether the template should be synced or removed across zones.,Only used if C(state) is present or absent.
-
#details ⇒ Object?
Template details in key/value pairs.
-
#display_text ⇒ String?
Display text of the template.
-
#domain ⇒ Object?
Domain the template, snapshot or VM is related to.
-
#format ⇒ :QCOW2, ...
The format for the template.,Only considered if I(state=present).
-
#hypervisor ⇒ :KVM, ...
Name the hypervisor to be used for creating the new template.,Relevant when using I(state=present).
-
#is_dynamically_scalable ⇒ Symbol?
Register the template having XS/VMWare tools installed in order to support dynamic scaling of VM CPU/memory.,Only used if C(state) is present.
-
#is_extractable ⇒ Symbol?
Allows the template or its derivatives to be extractable.
-
#is_featured ⇒ Symbol?
Register the template to be featured.,Only used if C(state) is present.
-
#is_public ⇒ Symbol?
Register the template to be publicly available to all users.,Only used if C(state) is present.
-
#is_ready ⇒ Symbol?
Note: this flag was not implemented and therefore marked as deprecated.,Deprecated, will be removed in version 2.11.
-
#is_routing ⇒ Symbol?
Sets the template type to routing, i.e.
-
#mode ⇒ :http_download, ...
Mode for the template extraction.,Only used if I(state=extracted).
-
#name ⇒ String
Name of the template.
-
#os_type ⇒ String?
OS type that best represents the OS of this template.
-
#password_enabled ⇒ Symbol?
Enable template password reset support.
-
#poll_async ⇒ Boolean?
Poll async jobs until job has finished.
-
#project ⇒ Object?
Name of the project the template to be registered in.
-
#requires_hvm ⇒ Symbol?
Whether the template requires HVM or not.,Only considered while creating the template.
-
#snapshot ⇒ String?
Name of the snapshot, created from the VM ROOT volume, the template will be created from.,C(vm) is required together with this argument.
-
#sshkey_enabled ⇒ Symbol?
True if the template supports the sshkey upload feature.,Only considered if C(url) is used (API limitation).
-
#state ⇒ :present, ...
State of the template.
-
#tags ⇒ Object?
List of tags.
-
#template_filter ⇒ :all, ...
Name of the filter used to search for the template.,The filter C(all) was added in 2.7.
-
#template_find_options ⇒ :display_text, ...
Options to find a template uniquely.,More than one allowed.
-
#template_tag ⇒ Object?
The tag for this template.
-
#url ⇒ String?
URL of where the template is hosted on I(state=present).,URL to which the template would be extracted on I(state=extracted).,Mutually exclusive with C(vm).
-
#vm ⇒ String?
VM name the template will be created from its volume or alternatively from a snapshot.,VM must be in stopped state if created from its volume.,Mutually exclusive with C(url).
-
#zone ⇒ String?
Name of the zone you wish the template to be registered or deleted from.,If not specified, first found zone will be used.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#account ⇒ Object?
64 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 64 attribute :account |
#bits ⇒ 32, ...
116 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 116 attribute :bits |
#checksum ⇒ Object?
34 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 34 attribute :checksum |
#cross_zones ⇒ Symbol?
53 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 53 attribute :cross_zones |
#details ⇒ Object?
113 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 113 attribute :details |
#display_text ⇒ String?
120 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 120 attribute :display_text |
#domain ⇒ Object?
61 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 61 attribute :domain |
#format ⇒ :QCOW2, ...
105 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 105 attribute :format |
#hypervisor ⇒ :KVM, ...
82 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 82 attribute :hypervisor |
#is_dynamically_scalable ⇒ Symbol?
49 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 49 attribute :is_dynamically_scalable |
#is_extractable ⇒ Symbol?
109 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 109 attribute :is_extractable |
#is_featured ⇒ Symbol?
45 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 45 attribute :is_featured |
#is_public ⇒ Symbol?
41 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 41 attribute :is_public |
#is_ready ⇒ Symbol?
37 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 37 attribute :is_ready |
#is_routing ⇒ Symbol?
101 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 101 attribute :is_routing |
#mode ⇒ :http_download, ...
57 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 57 attribute :mode |
#name ⇒ String
14 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 14 attribute :name |
#os_type ⇒ String?
30 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 30 attribute :os_type |
#password_enabled ⇒ Symbol?
90 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 90 attribute :password_enabled |
#poll_async ⇒ Boolean?
128 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 128 attribute :poll_async |
#project ⇒ Object?
67 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 67 attribute :project |
#requires_hvm ⇒ Symbol?
86 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 86 attribute :requires_hvm |
#snapshot ⇒ String?
26 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 26 attribute :snapshot |
#sshkey_enabled ⇒ Symbol?
97 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 97 attribute :sshkey_enabled |
#state ⇒ :present, ...
124 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 124 attribute :state |
#tags ⇒ Object?
132 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 132 attribute :tags |
#template_filter ⇒ :all, ...
74 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 74 attribute :template_filter |
#template_find_options ⇒ :display_text, ...
78 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 78 attribute :template_find_options |
#template_tag ⇒ Object?
94 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 94 attribute :template_tag |
#url ⇒ String?
18 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 18 attribute :url |
#vm ⇒ String?
22 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 22 attribute :vm |
#zone ⇒ String?
70 |
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_template.rb', line 70 attribute :zone |