Class: Ansible::Ruby::Modules::Cs_volume

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb

Overview

Create, destroy, attach, detach volumes.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#account ⇒ Object?

Returns Account the volume is related to.

Returns:

  • (Object, nil) —

    Account the volume is related to.



16
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 16

attribute :account

#custom_id ⇒ Object?

Returns Custom id to the resource.,Allowed to Root Admins only.

Returns:

  • (Object, nil) —

    Custom id to the resource.,Allowed to Root Admins only.



19
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 19

attribute :custom_id

#disk_offering ⇒ String?

Returns Name of the disk offering to be used.,Required one of C(disk_offering), C(snapshot) if volume is not already C(state=present).

Returns:

  • (String, nil) —

    Name of the disk offering to be used.,Required one of C(disk_offering), C(snapshot) if volume is not already C(state=present).



22
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 22

attribute :disk_offering

#display_volume ⇒ Boolean?

Returns Whether to display the volume to the end user or not.,Allowed to Root Admins only.

Returns:

  • (Boolean, nil) —

    Whether to display the volume to the end user or not.,Allowed to Root Admins only.



26
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 26

attribute :display_volume

#domain ⇒ Object?

Returns Name of the domain the volume to be deployed in.

Returns:

  • (Object, nil) —

    Name of the domain the volume to be deployed in.



30
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 30

attribute :domain

#force ⇒ Boolean?

Returns Force removal of volume even it is attached to a VM.,Considered on C(state=absnet) only.

Returns:

  • (Boolean, nil) —

    Force removal of volume even it is attached to a VM.,Considered on C(state=absnet) only.



50
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 50

attribute :force

#max_iops ⇒ Object?

Returns Max iops.

Returns:

  • (Object, nil) —

    Max iops



33
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 33

attribute :max_iops

#min_iops ⇒ Object?

Returns Min iops.

Returns:

  • (Object, nil) —

    Min iops



36
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 36

attribute :min_iops

#name ⇒ String

Returns Name of the volume.,C(name) can only contain ASCII letters.

Returns:

  • (String) —

    Name of the volume.,C(name) can only contain ASCII letters.



12
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 12

attribute :name

#poll_async ⇒ Boolean?

Returns Poll async jobs until job has finished.

Returns:

  • (Boolean, nil) —

    Poll async jobs until job has finished.



70
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 70

attribute :poll_async

#project ⇒ String?

Returns Name of the project the volume to be deployed in.

Returns:

  • (String, nil) —

    Name of the project the volume to be deployed in.



39
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 39

attribute :project

#shrink_ok ⇒ Boolean?

Returns Whether to allow to shrink the volume.

Returns:

  • (Boolean, nil) —

    Whether to allow to shrink the volume.



54
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 54

attribute :shrink_ok

#size ⇒ Integer?

Returns Size of disk in GB.

Returns:

  • (Integer, nil) —

    Size of disk in GB



43
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 43

attribute :size

#snapshot ⇒ Object?

Returns The snapshot name for the disk volume.,Required one of C(disk_offering), C(snapshot) if volume is not already C(state=present).

Returns:

  • (Object, nil) —

    The snapshot name for the disk volume.,Required one of C(disk_offering), C(snapshot) if volume is not already C(state=present).



47
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 47

attribute :snapshot

#state ⇒ :present, ...

Returns State of the volume.

Returns:

  • (:present, :absent, :attached, :detached, nil) —

    State of the volume.



66
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 66

attribute :state

#tags ⇒ Object?

Returns List of tags. Tags are a list of dictionaries having keys C(key) and C(value).,To delete all tags, set a empty list e.g. C(tags: []).

Returns:

  • (Object, nil) —

    List of tags. Tags are a list of dictionaries having keys C(key) and C(value).,To delete all tags, set a empty list e.g. C(tags: []).



74
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 74

attribute :tags

#vm ⇒ String?

Returns Name of the virtual machine to attach the volume to.

Returns:

  • (String, nil) —

    Name of the virtual machine to attach the volume to.



58
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 58

attribute :vm

#zone ⇒ String?

Returns Name of the zone in which the volume should be deployed.,If not set, default zone is used.

Returns:

  • (String, nil) —

    Name of the zone in which the volume should be deployed.,If not set, default zone is used.



62
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_volume.rb', line 62

attribute :zone