Class: Ansible::Ruby::Modules::Cs_vpc_offering

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_vpc_offering.rb

Overview

Create, update, enable, disable and remove CloudStack VPC offerings.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#display_text ⇒ String?

Returns Display text of the vpc offerings.

Returns:

  • (String, nil) —

    Display text of the vpc offerings



20
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_vpc_offering.rb', line 20

attribute :display_text

#name ⇒ String

Returns The name of the vpc offering.

Returns:

  • (String) —

    The name of the vpc offering



12
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_vpc_offering.rb', line 12

attribute :name

#poll_async ⇒ Boolean?

Returns Poll async jobs until job has finished.

Returns:

  • (Boolean, nil) —

    Poll async jobs until job has finished.



38
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_vpc_offering.rb', line 38

attribute :poll_async

#service_capabilities ⇒ Object?

Returns Desired service capabilities as part of vpc offering.

Returns:

  • (Object, nil) —

    Desired service capabilities as part of vpc offering.



24
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_vpc_offering.rb', line 24

attribute :service_capabilities

#service_offering ⇒ Object?

Returns The name or ID of the service offering for the VPC router appliance.

Returns:

  • (Object, nil) —

    The name or ID of the service offering for the VPC router appliance.



27
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_vpc_offering.rb', line 27

attribute :service_offering

#service_providers ⇒ Array<Hash>, ...

Returns provider to service mapping. If not specified, the provider for the service will be mapped to the default provider on the physical network.

Returns:

  • (Array<Hash>, Hash, nil) —

    provider to service mapping. If not specified, the provider for the service will be mapped to the default provider on the physical network



34
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_vpc_offering.rb', line 34

attribute :service_providers

#state ⇒ :enabled, ...

Returns State of the vpc offering.

Returns:

  • (:enabled, :present, :disabled, :absent, nil) —

    State of the vpc offering.



16
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_vpc_offering.rb', line 16

attribute :state

#supported_services ⇒ Array<String>, ...

Returns Services supported by the vpc offering.

Returns:

  • (Array<String>, String, nil) —

    Services supported by the vpc offering



30
# File 'lib/ansible/ruby/modules/generated/cloud/cloudstack/cs_vpc_offering.rb', line 30

attribute :supported_services