Class: Ansible::Ruby::Modules::Cv_server_provision
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Cv_server_provision
- Defined in:
- lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb
Overview
This module allows a server team to provision server network ports for new servers without having to access Arista CVP or asking the network team to do it for them. Provide the information for connecting to CVP, switch rack, port the new server is connected to, optional vlan, and an action and the module will apply the configuration to the switch port via CVP. Actions are add (applies template config to port), remove (defaults the interface config) and show (returns the current port config).
Instance Method Summary collapse
-
#action ⇒ :show, ...
The action for the module to take.
-
#auto_run ⇒ :yes, ...
Flag that determines whether or not the module will execute the CVP task spawned as a result of changes to a switch configlet.
-
#host ⇒ String
The hostname or IP address of the CVP node being connected to.
-
#password ⇒ String
The password of the user that will be used to connect to CVP for API calls.
-
#port ⇒ Object?
The port number to use when making API calls to the CVP node.
-
#port_vlan ⇒ Integer?
The vlan that should be applied to the port for this server.
-
#protocol ⇒ :https, ...
The protocol to use when making API calls to CVP.
-
#server_name ⇒ String
The hostname or identifier for the server that is having it’s switch port provisioned.
-
#switch_name ⇒ String
The hostname of the switch is being configured for the server being provisioned.
-
#switch_port ⇒ Integer
The physical port number on the switch that the new server is connected to.
-
#template ⇒ String
A path to a Jinja formatted template file that contains the configuration block that will be applied to the specified switch port.
-
#username ⇒ String
The user that will be used to connect to CVP for making API calls.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#action ⇒ :show, ...
51 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 51 attribute :action |
#auto_run ⇒ :yes, ...
55 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 55 attribute :auto_run |
#host ⇒ String
12 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 12 attribute :host |
#password ⇒ String
27 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 27 attribute :password |
#port ⇒ Object?
16 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 16 attribute :port |
#port_vlan ⇒ Integer?
43 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 43 attribute :port_vlan |
#protocol ⇒ :https, ...
19 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 19 attribute :protocol |
#server_name ⇒ String
31 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 31 attribute :server_name |
#switch_name ⇒ String
35 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 35 attribute :switch_name |
#switch_port ⇒ Integer
39 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 39 attribute :switch_port |
#template ⇒ String
47 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 47 attribute :template |
#username ⇒ String
23 |
# File 'lib/ansible/ruby/modules/generated/network/cloudvision/cv_server_provision.rb', line 23 attribute :username |