Class: Ansible::Ruby::Modules::Datadog_event

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb

Overview

Allows to post events to Datadog (www.datadoghq.com) service. Uses http://docs.datadoghq.com/api/#events API.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#aggregation_key ⇒ Object?

Returns An arbitrary string to use for aggregation.

Returns:

  • (Object, nil) —

    An arbitrary string to use for aggregation.



49
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 49

attribute :aggregation_key

#alert_type ⇒ :error, ...

Returns Type of alert.

Returns:

  • (:error, :warning, :info, :success, nil) —

    Type of alert.



45
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 45

attribute :alert_type

#api_key ⇒ String

Returns Your DataDog API key.

Returns:

  • (String) —

    Your DataDog API key.



13
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 13

attribute :api_key

#app_key ⇒ String

Returns Your DataDog app key.

Returns:

  • (String) —

    Your DataDog app key.



17
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 17

attribute :app_key

#date_happened ⇒ String?

Returns POSIX timestamp of the event.,Default value is now.

Returns:

  • (String, nil) —

    POSIX timestamp of the event.,Default value is now.



29
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 29

attribute :date_happened

#host ⇒ String?

Returns Host name to associate with the event.

Returns:

  • (String, nil) —

    Host name to associate with the event.



37
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 37

attribute :host

#priority ⇒ :normal, ...

Returns The priority of the event.

Returns:

  • (:normal, :low, nil) —

    The priority of the event.



33
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 33

attribute :priority

#tags ⇒ Array<String>, ...

Returns Comma separated list of tags to apply to the event.

Returns:

  • (Array<String>, String, nil) —

    Comma separated list of tags to apply to the event.



41
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 41

attribute :tags

#text ⇒ String

Returns The body of the event.

Returns:

  • (String) —

    The body of the event.



25
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 25

attribute :text

#title ⇒ String

Returns The event title.

Returns:

  • (String) —

    The event title.



21
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 21

attribute :title

#validate_certs ⇒ :yes, ...

Returns If C(no), SSL certificates will not be validated. This should only be used on personally controlled sites using self-signed certificates.

Returns:

  • (:yes, :no, nil) —

    If C(no), SSL certificates will not be validated. This should only be used on personally controlled sites using self-signed certificates.



52
# File 'lib/ansible/ruby/modules/generated/monitoring/datadog_event.rb', line 52

attribute :validate_certs