Class: Ansible::Ruby::Modules::Django_manage
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Django_manage
- Defined in:
- lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb
Overview
Manages a Django application using the I(manage.py) application frontend to I(django-admin). With the I(virtualenv) parameter, all management commands will be executed by the given I(virtualenv) installation.
Instance Method Summary collapse
-
#app_path ⇒ String
The path to the root of the Django application where B(manage.py) lives.
-
#apps ⇒ String?
A list of space-delimited apps to target.
-
#cache_table ⇒ Object?
The name of the table used for database-backed caching.
-
#clear ⇒ Symbol?
Clear the existing files before trying to copy or link the original file.,Used only with the ‘collectstatic’ command.
-
#command ⇒ :cleanup, ...
The name of the Django management command to run.
-
#database ⇒ Object?
The database to target.
-
#failfast ⇒ :yes, ...
Fail the command immediately if a test fails.
-
#fixtures ⇒ String?
A space-delimited list of fixture file names to load in the database.
-
#link ⇒ Object?
Will create links to the files instead of copying them, you can only use this parameter with ‘collectstatic’ command.
-
#merge ⇒ Object?
Will run out-of-order or missing migrations as they are not rollback migrations, you can only use this parameter with ‘migrate’ command.
-
#pythonpath ⇒ String?
A directory to add to the Python path.
-
#settings ⇒ String?
The Python path to the application’s settings module, such as ‘myapp.settings’.
-
#skip ⇒ Object?
Will skip over out-of-order missing migrations, you can only use this parameter with I(migrate).
-
#virtualenv ⇒ String?
An optional path to a I(virtualenv) installation to use while running the manage application.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#app_path ⇒ String
16 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 16 attribute :app_path |
#apps ⇒ String?
32 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 32 attribute :apps |
#cache_table ⇒ Object?
36 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 36 attribute :cache_table |
#clear ⇒ Symbol?
39 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 39 attribute :clear |
#command ⇒ :cleanup, ...
12 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 12 attribute :command |
#database ⇒ Object?
43 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 43 attribute :database |
#failfast ⇒ :yes, ...
46 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 46 attribute :failfast |
#fixtures ⇒ String?
50 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 50 attribute :fixtures |
#link ⇒ Object?
60 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 60 attribute :link |
#merge ⇒ Object?
57 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 57 attribute :merge |
#pythonpath ⇒ String?
24 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 24 attribute :pythonpath |
#settings ⇒ String?
20 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 20 attribute :settings |
#skip ⇒ Object?
54 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 54 attribute :skip |
#virtualenv ⇒ String?
28 |
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/django_manage.rb', line 28 attribute :virtualenv |