Class: Ansible::Ruby::Modules::Dnsmadeeasy

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb

Overview

Manages DNS records via the v2 REST API of the DNS Made Easy service. It handles records only; there is no manipulation of domains or monitor/account support yet. See: U(https://www.dnsmadeeasy.com/integration/restapi/)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#account_key ⇒ String

Returns Account API Key.

Returns:

  • (String) —

    Account API Key.



13
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 13

attribute :account_key

#account_secret ⇒ String

Returns Account Secret Key.

Returns:

  • (String) —

    Account Secret Key.



17
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 17

attribute :account_secret

#autoFailover ⇒ :yes, ...

Returns If true, fallback to the primary IP address is manual after a failover.,If false, fallback to the primary IP address is automatic after a failover.

Returns:

  • (:yes, :no, nil) —

    If true, fallback to the primary IP address is manual after a failover.,If false, fallback to the primary IP address is automatic after a failover.



97
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 97

attribute :autoFailover

#contactList ⇒ String

Returns Name or id of the contact list that the monitor will notify.,The default C('') means the Account Owner.

Returns:

  • (String) —

    Name or id of the contact list that the monitor will notify.,The default C('') means the Account Owner.



77
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 77

attribute :contactList

#domain ⇒ String

Returns Domain to work with. Can be the domain name (e.g. "mydomain.com") or the numeric ID of the domain in DNS Made Easy (e.g. "839989") for faster resolution.

Returns:

  • (String) —

    Domain to work with. Can be the domain name (e.g. "mydomain.com") or the numeric ID of the domain in DNS Made Easy (e.g. "839989") for faster resolution



21
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 21

attribute :domain

#failover ⇒ :yes, ...

Returns If C(yes), add or change the failover. This is applicable only for A records.

Returns:

  • (:yes, :no, nil) —

    If C(yes), add or change the failover. This is applicable only for A records.



93
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 93

attribute :failover

#httpFile ⇒ String?

Returns The file at the Fqdn that the monitor queries for HTTP or HTTPS.

Returns:

  • (String, nil) —

    The file at the Fqdn that the monitor queries for HTTP or HTTPS.



85
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 85

attribute :httpFile

#httpFqdn ⇒ String?

Returns The fully qualified domain name used by the monitor.

Returns:

  • (String, nil) —

    The fully qualified domain name used by the monitor.



81
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 81

attribute :httpFqdn

#httpQueryString ⇒ String?

Returns The string in the httpFile that the monitor queries for HTTP or HTTPS.

Returns:

  • (String, nil) —

    The string in the httpFile that the monitor queries for HTTP or HTTPS.



89
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 89

attribute :httpQueryString

#ip1 ⇒ String?

Returns Primary IP address for the failover.,Required if adding or changing the monitor or failover.

Returns:

  • (String, nil) —

    Primary IP address for the failover.,Required if adding or changing the monitor or failover.



101
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 101

attribute :ip1

#ip2 ⇒ String?

Returns Secondary IP address for the failover.,Required if adding or changing the failover.

Returns:

  • (String, nil) —

    Secondary IP address for the failover.,Required if adding or changing the failover.



105
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 105

attribute :ip2

#ip3 ⇒ String?

Returns Tertiary IP address for the failover.

Returns:

  • (String, nil) —

    Tertiary IP address for the failover.



109
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 109

attribute :ip3

#ip4 ⇒ String?

Returns Quaternary IP address for the failover.

Returns:

  • (String, nil) —

    Quaternary IP address for the failover.



113
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 113

attribute :ip4

#ip5 ⇒ String?

Returns Quinary IP address for the failover.

Returns:

  • (String, nil) —

    Quinary IP address for the failover.



117
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 117

attribute :ip5

#maxEmails ⇒ Integer

Returns Number of emails sent to the contact list by the monitor.

Returns:

  • (Integer) —

    Number of emails sent to the contact list by the monitor.



61
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 61

attribute :maxEmails

#monitor ⇒ :yes, ...

Returns If C(yes), add or change the monitor. This is applicable only for A records.

Returns:

  • (:yes, :no, nil) —

    If C(yes), add or change the monitor. This is applicable only for A records.



53
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 53

attribute :monitor

#port ⇒ Integer

Returns Port used by the monitor.

Returns:

  • (Integer) —

    Port used by the monitor.



69
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 69

attribute :port

#protocol ⇒ :TCP, ...

Returns Protocol used by the monitor.

Returns:

  • (:TCP, :UDP, :HTTP, :DNS, :SMTP, :HTTPS) —

    Protocol used by the monitor.



65
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 65

attribute :protocol

#record_name ⇒ String?

Returns Record name to get/create/delete/update. If record_name is not specified; all records for the domain will be returned in "result" regardless of the state argument.

Returns:

  • (String, nil) —

    Record name to get/create/delete/update. If record_name is not specified; all records for the domain will be returned in "result" regardless of the state argument.



29
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 29

attribute :record_name

#record_ttl ⇒ Integer?

Returns record's "Time to live". Number of seconds the record remains cached in DNS servers.

Returns:

  • (Integer, nil) —

    record's "Time to live". Number of seconds the record remains cached in DNS servers.



41
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 41

attribute :record_ttl

#record_type ⇒ :A, ...

Returns Record type.

Returns:

  • (:A, :AAAA, :CNAME, :ANAME, :HTTPRED, :MX, :NS, :PTR, :SRV, :TXT, nil) —

    Record type.



33
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 33

attribute :record_type

#record_value ⇒ String?

Returns Record value. HTTPRED: , MX: , NS: , PTR: , SRV: , TXT: "\r\n,If record_value is not specified; no changes will be made and the record will be returned in 'result' (in other words, this module can be used to fetch a record's current id, type, and ttl)\r\n.

Returns:

  • (String, nil) —

    Record value. HTTPRED: , MX: , NS: , PTR: , SRV: , TXT: "\r\n,If record_value is not specified; no changes will be made and the record will be returned in 'result' (in other words, this module can be used to fetch a record's current id, type, and ttl)\r\n



37
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 37

attribute :record_value

#sandbox ⇒ :yes, ...

Returns Decides if the sandbox API should be used. Otherwise (default) the production API of DNS Made Easy is used.

Returns:

  • (:yes, :no, nil) —

    Decides if the sandbox API should be used. Otherwise (default) the production API of DNS Made Easy is used.



25
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 25

attribute :sandbox

#sensitivity ⇒ :Low, ...

Returns Number of checks the monitor performs before a failover occurs where Low = 8, Medium = 5,and High = 3.

Returns:

  • (:Low, :Medium, :High) —

    Number of checks the monitor performs before a failover occurs where Low = 8, Medium = 5,and High = 3.



73
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 73

attribute :sensitivity

#state ⇒ :present, :absent

Returns whether the record should exist or not.

Returns:

  • (:present, :absent) —

    whether the record should exist or not



45
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 45

attribute :state

#systemDescription ⇒ String

Returns Description used by the monitor.

Returns:

  • (String) —

    Description used by the monitor.



57
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 57

attribute :systemDescription

#validate_certs ⇒ :yes, ...

Returns If C(no), SSL certificates will not be validated. This should only be used on personally controlled sites using self-signed certificates.

Returns:

  • (:yes, :no, nil) —

    If C(no), SSL certificates will not be validated. This should only be used on personally controlled sites using self-signed certificates.



49
# File 'lib/ansible/ruby/modules/generated/net_tools/dnsmadeeasy.rb', line 49

attribute :validate_certs