Class: Ansible::Ruby::Modules::Ec2_group
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Ec2_group
- Includes:
- Helpers::Aws
- Defined in:
- lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb,
lib/ansible/ruby/modules/custom/cloud/core/amazon/ec2_group.rb
Overview
maintains ec2 security groups. This module has a dependency on python-boto >= 2.5
Instance Method Summary collapse
-
#description ⇒ String?
Description of the security group.
-
#group_id ⇒ String?
Id of group to delete (works only with absent).,One of and only one of I(name) or I(group_id) is required.
-
#name ⇒ String?
Name of the security group.,One of and only one of I(name) or I(group_id) is required.,Required if I(state=present).
-
#purge_rules ⇒ String?
Purge existing rules on security group that are not found in rules.
-
#purge_rules_egress ⇒ String?
Purge existing rules_egress on security group that are not found in rules_egress.
-
#purge_tags ⇒ Boolean?
If yes, existing tags will be purged from the resource to match exactly what is defined by I(tags) parameter.
-
#rules ⇒ Array<Hash>, ...
List of firewall inbound rules to enforce in this group (see example).
-
#rules_egress ⇒ Array<Hash>, ...
List of firewall outbound rules to enforce in this group (see example).
-
#state ⇒ :present, ...
Create or delete a security group.
-
#tags ⇒ Object?
A dictionary of one or more tags to assign to the security group.
-
#vpc_id ⇒ String, ...
ID of the VPC to create the group in.
Methods included from Helpers::Aws
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#description ⇒ String?
20 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 20 attribute :description |
#group_id ⇒ String?
16 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 16 attribute :group_id |
#name ⇒ String?
12 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 12 attribute :name |
#purge_rules ⇒ String?
40 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 40 attribute :purge_rules |
#purge_rules_egress ⇒ String?
44 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 44 attribute :purge_rules_egress |
#purge_tags ⇒ Boolean?
51 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 51 attribute :purge_tags |
#rules ⇒ Array<Hash>, ...
28 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 28 attribute :rules |
#rules_egress ⇒ Array<Hash>, ...
32 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 32 attribute :rules_egress |
#state ⇒ :present, ...
36 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 36 attribute :state |
#tags ⇒ Object?
48 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 48 attribute :tags |
#vpc_id ⇒ String, ...
24 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_group.rb', line 24 attribute :vpc_id |