Class: Ansible::Ruby::Modules::Ec2_key

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/amazon/ec2_key.rb

Overview

create or delete an ec2 key pair.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#force ⇒ Boolean?

Returns Force overwrite of already existing key pair if key has changed.

Returns:

  • (Boolean, nil) —

    Force overwrite of already existing key pair if key has changed.



20
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_key.rb', line 20

attribute :force

#key_material ⇒ String?

Returns Public key material.

Returns:

  • (String, nil) —

    Public key material.



16
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_key.rb', line 16

attribute :key_material

#name ⇒ String

Returns Name of the key pair.

Returns:

  • (String) —

    Name of the key pair.



12
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_key.rb', line 12

attribute :name

#state ⇒ :present, ...

Returns create or delete keypair.

Returns:

  • (:present, :absent, nil) —

    create or delete keypair



24
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_key.rb', line 24

attribute :state

#wait ⇒ Boolean?

Returns Wait for the specified action to complete before returning. This option has no effect since version 2.5.

Returns:

  • (Boolean, nil) —

    Wait for the specified action to complete before returning. This option has no effect since version 2.5.



28
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_key.rb', line 28

attribute :wait

#wait_timeout ⇒ Integer?

Returns How long before wait gives up, in seconds. This option has no effect since version 2.5.

Returns:

  • (Integer, nil) —

    How long before wait gives up, in seconds. This option has no effect since version 2.5.



32
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_key.rb', line 32

attribute :wait_timeout