Class: Ansible::Ruby::Modules::Ec2_lc_find

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/amazon/ec2_lc_find.rb

Overview

Returns list of matching Launch Configurations for a given name, along with other useful information Results can be sorted and sliced It depends on boto Based on the work by Tom Bamford (github.com/tombamford)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#limitInteger?



27
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_lc_find.rb', line 27

attribute :limit

#name_regexString



19
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_lc_find.rb', line 19

attribute :name_regex

#regionObject



15
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_lc_find.rb', line 15

attribute :region

#sort_order:ascending, ...



23
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_lc_find.rb', line 23

attribute :sort_order