Class: Ansible::Ruby::Modules::Ec2_metric_alarm

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb

Overview

Can create or delete AWS metric alarms. Metrics you wish to alarm on must already exist.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#alarm_actions ⇒ Array<String>, ...

Returns A list of the names action(s) taken when the alarm is in the 'alarm' status.

Returns:

  • (Array<String>, String, nil) —

    A list of the names action(s) taken when the alarm is in the 'alarm' status



61
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 61

attribute :alarm_actions

#comparison ⇒ :<=, :<, :>, :>=?

Returns Determines how the threshold value is compared.

Returns:

  • (:<=, :<, :>, :>=, nil) —

    Determines how the threshold value is compared



33
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 33

attribute :comparison

#description ⇒ String?

Returns A longer description of the alarm.

Returns:

  • (String, nil) —

    A longer description of the alarm



53
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 53

attribute :description

#dimensions ⇒ Hash?

Returns Describes to what the alarm is applied.

Returns:

  • (Hash, nil) —

    Describes to what the alarm is applied



57
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 57

attribute :dimensions

#evaluation_periods ⇒ Integer?

Returns The number of times in which the metric is evaluated before final calculation.

Returns:

  • (Integer, nil) —

    The number of times in which the metric is evaluated before final calculation



45
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 45

attribute :evaluation_periods

#insufficient_data_actions ⇒ Object?

Returns A list of the names of action(s) to take when the alarm is in the 'insufficient_data' status.

Returns:

  • (Object, nil) —

    A list of the names of action(s) to take when the alarm is in the 'insufficient_data' status



65
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 65

attribute :insufficient_data_actions

#metric ⇒ String?

Returns Name of the monitored metric (e.g. CPUUtilization),Metric must already exist.

Returns:

  • (String, nil) —

    Name of the monitored metric (e.g. CPUUtilization),Metric must already exist



21
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 21

attribute :metric

#name ⇒ String

Returns Unique name for the alarm.

Returns:

  • (String) —

    Unique name for the alarm



17
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 17

attribute :name

#namespace ⇒ String?

Returns Name of the appropriate namespace ('AWS/EC2', 'System/Linux', etc.), which determines the category it will appear under in cloudwatch.

Returns:

  • (String, nil) —

    Name of the appropriate namespace ('AWS/EC2', 'System/Linux', etc.), which determines the category it will appear under in cloudwatch



25
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 25

attribute :namespace

#ok_actions ⇒ Object?

Returns A list of the names of action(s) to take when the alarm is in the 'ok' status.

Returns:

  • (Object, nil) —

    A list of the names of action(s) to take when the alarm is in the 'ok' status



68
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 68

attribute :ok_actions

#period ⇒ Integer?

Returns The time (in seconds) between metric evaluations.

Returns:

  • (Integer, nil) —

    The time (in seconds) between metric evaluations



41
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 41

attribute :period

#state ⇒ :present, :absent

Returns register or deregister the alarm.

Returns:

  • (:present, :absent) —

    register or deregister the alarm



13
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 13

attribute :state

#statistic ⇒ :SampleCount, ...

Returns Operation applied to the metric,Works in conjunction with period and evaluation_periods to determine the comparison value.

Returns:

  • (:SampleCount, :Average, :Sum, :Minimum, :Maximum, nil) —

    Operation applied to the metric,Works in conjunction with period and evaluation_periods to determine the comparison value



29
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 29

attribute :statistic

#threshold ⇒ Float?

Returns Sets the min/max bound for triggering the alarm.

Returns:

  • (Float, nil) —

    Sets the min/max bound for triggering the alarm



37
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 37

attribute :threshold

#unit ⇒ :Seconds, ...

Returns The threshold's unit of measurement.

Returns:

  • (:Seconds, :Microseconds, :Milliseconds, :Bytes, :Kilobytes, :Megabytes, :Gigabytes, :Terabytes, :Bits, :Kilobits, :Megabits, :Gigabits, :Terabits, :Percent, :Count, :"Bytes/Second", :"Kilobytes/Second", :"Megabytes/Second", :"Gigabytes/Second", :"Terabytes/Second", :"Bits/Second", :"Kilobits/Second", :"Megabits/Second", :"Gigabits/Second", :"Terabits/Second", :"Count/Second", :None, nil) —

    The threshold's unit of measurement



49
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ec2_metric_alarm.rb', line 49

attribute :unit