Class: Ansible::Ruby::Modules::Ecs_cluster

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/amazon/ecs_cluster.rb

Overview

Creates or terminates ecs clusters.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#delay ⇒ Integer?

Returns Number of seconds to wait.

Returns:

  • (Integer, nil) —

    Number of seconds to wait



20
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_cluster.rb', line 20

attribute :delay

#name ⇒ String

Returns The cluster name.

Returns:

  • (String) —

    The cluster name



16
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_cluster.rb', line 16

attribute :name

#repeat ⇒ Integer?

Returns The number of times to wait for the cluster to have an instance.

Returns:

  • (Integer, nil) —

    The number of times to wait for the cluster to have an instance



24
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_cluster.rb', line 24

attribute :repeat

#state ⇒ :present, ...

Returns The desired state of the cluster.

Returns:

  • (:present, :absent, :has_instances) —

    The desired state of the cluster



12
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_cluster.rb', line 12

attribute :state