Class: Ansible::Ruby::Modules::Ecs_ecr

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/amazon/ecs_ecr.rb

Overview

Manage Elastic Container Registry repositories

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#delete_policy ⇒ Boolean?

Returns if yes, remove the policy from the repository.

Returns:

  • (Boolean, nil) —

    if yes, remove the policy from the repository



28
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_ecr.rb', line 28

attribute :delete_policy

#force_set_policy ⇒ Boolean?

Returns if no, prevents setting a policy that would prevent you from setting another policy in the future.

Returns:

  • (Boolean, nil) —

    if no, prevents setting a policy that would prevent you from setting another policy in the future.



24
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_ecr.rb', line 24

attribute :force_set_policy

#name ⇒ String

Returns the name of the repository.

Returns:

  • (String) —

    the name of the repository



12
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_ecr.rb', line 12

attribute :name

#policy ⇒ Hash, ...

Returns JSON or dict that represents the new policy.

Returns:

  • (Hash, String, nil) —

    JSON or dict that represents the new policy



20
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_ecr.rb', line 20

attribute :policy

#registry_id ⇒ String?

Returns AWS account id associated with the registry.,If not specified, the default registry is assumed.

Returns:

  • (String, nil) —

    AWS account id associated with the registry.,If not specified, the default registry is assumed.



16
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_ecr.rb', line 16

attribute :registry_id

#state ⇒ :present, ...

Returns create or destroy the repository.

Returns:

  • (:present, :absent, nil) —

    create or destroy the repository



32
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/ecs_ecr.rb', line 32

attribute :state