Class: Ansible::Ruby::Modules::Exo_dns_record

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/net_tools/exoscale/exo_dns_record.rb

Overview

Create, update and delete records.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#content ⇒ String?

Returns Content of the record.,Required if C(state=present) or C(multiple=yes).

Returns:

  • (String, nil) —

    Content of the record.,Required if C(state=present) or C(multiple=yes).



24
# File 'lib/ansible/ruby/modules/generated/net_tools/exoscale/exo_dns_record.rb', line 24

attribute :content

#domain ⇒ String

Returns Domain the record is related to.

Returns:

  • (String) —

    Domain the record is related to.



16
# File 'lib/ansible/ruby/modules/generated/net_tools/exoscale/exo_dns_record.rb', line 16

attribute :domain

#multiple ⇒ Symbol?

Returns Whether there are more than one records with similar C(name) and C(record_type).,Only allowed for a few record types, e.g. C(record_type=A), C(record_type=NS) or C(record_type=MX).,C(content) will not be updated, instead it is used as a key to find existing records.

Returns:

  • (Symbol, nil) —

    Whether there are more than one records with similar C(name) and C(record_type).,Only allowed for a few record types, e.g. C(record_type=A), C(record_type=NS) or C(record_type=MX).,C(content) will not be updated, instead it is used as a key to find existing records.



36
# File 'lib/ansible/ruby/modules/generated/net_tools/exoscale/exo_dns_record.rb', line 36

attribute :multiple

#name ⇒ String?

Returns Name of the record.

Returns:

  • (String, nil) —

    Name of the record.



12
# File 'lib/ansible/ruby/modules/generated/net_tools/exoscale/exo_dns_record.rb', line 12

attribute :name

#prio ⇒ Integer?

Returns Priority of the record.

Returns:

  • (Integer, nil) —

    Priority of the record.



32
# File 'lib/ansible/ruby/modules/generated/net_tools/exoscale/exo_dns_record.rb', line 32

attribute :prio

#record_type ⇒ :A, ...

Returns Type of the record.

Returns:

  • (:A, :ALIAS, :CNAME, :MX, :SPF, :URL, :TXT, :NS, :SRV, :NAPTR, :PTR, :AAAA, :SSHFP, :HINFO, :POOL, nil) —

    Type of the record.



20
# File 'lib/ansible/ruby/modules/generated/net_tools/exoscale/exo_dns_record.rb', line 20

attribute :record_type

#state ⇒ :present, ...

Returns State of the record.

Returns:

  • (:present, :absent, nil) —

    State of the record.



40
# File 'lib/ansible/ruby/modules/generated/net_tools/exoscale/exo_dns_record.rb', line 40

attribute :state

#ttl ⇒ Integer?

Returns TTL of the record in seconds.

Returns:

  • (Integer, nil) —

    TTL of the record in seconds.



28
# File 'lib/ansible/ruby/modules/generated/net_tools/exoscale/exo_dns_record.rb', line 28

attribute :ttl