Class: Ansible::Ruby::Modules::Flatpak
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Flatpak
- Defined in:
- lib/ansible/ruby/modules/generated/packaging/os/flatpak.rb
Overview
Allows users to add or remove flatpaks. See the M(flatpak_remote) module for managing flatpak remotes.
Instance Method Summary collapse
-
#executable ⇒ String?
The path to the C(flatpak) executable to use.,By default, this module looks for the C(flatpak) executable on the path.
-
#method ⇒ :system, ...
The installation method to use.,Defines if the I(flatpak) is supposed to be installed globally for the whole C(system) or only for the current C(user).
-
#name ⇒ String
The name of the flatpak to manage.,When used with I(state=present), I(name) can be specified as an C(http(s)) URL to a C(flatpakref) file or the unique reverse DNS name that identifies a flatpak.,When suppying a reverse DNS name, you can use the I(remote) option to specify on what remote to look for the flatpak.
-
#remote ⇒ String?
The flatpak remote (repository) to install the flatpak from.,By default, C(flathub) is assumed, but you do need to add the flathub flatpak_remote before you can use this.,See the M(flatpak_remote) module for managing flatpak remotes.
-
#state ⇒ :absent, ...
Indicates the desired package state.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#executable ⇒ String?
13 |
# File 'lib/ansible/ruby/modules/generated/packaging/os/flatpak.rb', line 13 attribute :executable |
#method ⇒ :system, ...
17 |
# File 'lib/ansible/ruby/modules/generated/packaging/os/flatpak.rb', line 17 attribute :method |
#name ⇒ String
21 |
# File 'lib/ansible/ruby/modules/generated/packaging/os/flatpak.rb', line 21 attribute :name |
#remote ⇒ String?
25 |
# File 'lib/ansible/ruby/modules/generated/packaging/os/flatpak.rb', line 25 attribute :remote |
#state ⇒ :absent, ...
29 |
# File 'lib/ansible/ruby/modules/generated/packaging/os/flatpak.rb', line 29 attribute :state |