Class: Ansible::Ruby::Modules::Flowadm

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb

Overview

Create/modify/remove networking bandwidth and associated resources for a type of traffic on a particular link.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#dsfield ⇒ String?

Returns - Identifies the 8-bit differentiated services field (as defined in RFC 2474). The optional dsfield_mask is used to state the bits of interest in the differentiated services field when comparing with the dsfield value. Both values must be in hexadecimal.\r\n.

Returns:

  • (String, nil) —
    • Identifies the 8-bit differentiated services field (as defined in RFC 2474). The optional dsfield_mask is used to state the bits of interest in the differentiated services field when comparing with the dsfield value. Both values must be in hexadecimal.\r\n


34
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 34

attribute :dsfield

Returns Specifiies a link to configure flow on.

Returns:

  • (String, nil) —

    Specifiies a link to configure flow on.



16
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 16

attribute :link

#local_ip ⇒ Object?

Returns Identifies a network flow by the local IP address.

Returns:

  • (Object, nil) —

    Identifies a network flow by the local IP address.



20
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 20

attribute :local_ip

#local_port ⇒ Integer?

Returns Identifies a service specified by the local port.

Returns:

  • (Integer, nil) —

    Identifies a service specified by the local port.



30
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 30

attribute :local_port

#maxbw ⇒ String?

Returns - Sets the full duplex bandwidth for the flow. The bandwidth is specified as an integer with one of the scale suffixes(K, M, or G for Kbps, Mbps, and Gbps). If no units are specified, the input value will be read as Mbps.\r\n.

Returns:

  • (String, nil) —
    • Sets the full duplex bandwidth for the flow. The bandwidth is specified as an integer with one of the scale suffixes(K, M, or G for Kbps, Mbps, and Gbps). If no units are specified, the input value will be read as Mbps.\r\n


38
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 38

attribute :maxbw

#name ⇒ String

Returns - A flow is defined as a set of attributes based on Layer 3 and Layer 4 headers, which can be used to identify a protocol, service, or a zone.\r\n.

Returns:

  • (String) —
    • A flow is defined as a set of attributes based on Layer 3 and Layer 4 headers, which can be used to identify a protocol, service, or a zone.\r\n


12
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 12

attribute :name

#priority ⇒ :low, ...

Returns Sets the relative priority for the flow.

Returns:

  • (:low, :medium, :high, nil) —

    Sets the relative priority for the flow.



42
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 42

attribute :priority

#remote_ip ⇒ Object?

Returns Identifies a network flow by the remote IP address.

Returns:

  • (Object, nil) —

    Identifies a network flow by the remote IP address.



23
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 23

attribute :remote_ip

#state ⇒ :absent, ...

Returns Create/delete/enable/disable an IP address on the network interface.

Returns:

  • (:absent, :present, :resetted, nil) —

    Create/delete/enable/disable an IP address on the network interface.



50
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 50

attribute :state

#temporary ⇒ Symbol?

Returns Specifies that the configured flow is temporary. Temporary flows do not persist across reboots.

Returns:

  • (Symbol, nil) —

    Specifies that the configured flow is temporary. Temporary flows do not persist across reboots.



46
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 46

attribute :temporary

#transport ⇒ String?

Returns - Specifies a Layer 4 protocol to be used. It is typically used in combination with I(local_port) to identify the service that needs special attention.\r\n.

Returns:

  • (String, nil) —
    • Specifies a Layer 4 protocol to be used. It is typically used in combination with I(local_port) to identify the service that needs special attention.\r\n


26
# File 'lib/ansible/ruby/modules/generated/network/illumos/flowadm.rb', line 26

attribute :transport