Class: Ansible::Ruby::Modules::Foreman

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/remote_management/foreman/foreman.rb

Overview

Allows the management of Foreman resources inside your Foreman server.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#entity ⇒ String

Returns The Foreman resource that the action will be performed on (e.g. organization, host).

Returns:

  • (String) —

    The Foreman resource that the action will be performed on (e.g. organization, host).



24
# File 'lib/ansible/ruby/modules/generated/remote_management/foreman/foreman.rb', line 24

attribute :entity

#params ⇒ Hash

Returns Parameters associated to the entity resource to set or edit in dictionary format (e.g. name, description).

Returns:

  • (Hash) —

    Parameters associated to the entity resource to set or edit in dictionary format (e.g. name, description).



28
# File 'lib/ansible/ruby/modules/generated/remote_management/foreman/foreman.rb', line 28

attribute :params

#password ⇒ String

Returns Password for user accessing Foreman server.

Returns:

  • (String) —

    Password for user accessing Foreman server.



20
# File 'lib/ansible/ruby/modules/generated/remote_management/foreman/foreman.rb', line 20

attribute :password

#server_url ⇒ String

Returns URL of Foreman server.

Returns:

  • (String) —

    URL of Foreman server.



12
# File 'lib/ansible/ruby/modules/generated/remote_management/foreman/foreman.rb', line 12

attribute :server_url

#username ⇒ String

Returns Username on Foreman server.

Returns:

  • (String) —

    Username on Foreman server.



16
# File 'lib/ansible/ruby/modules/generated/remote_management/foreman/foreman.rb', line 16

attribute :username