Class: Ansible::Ruby::Modules::Gce_img

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb

Overview

This module can create and delete GCE private images from gzipped compressed tarball containing raw disk data or from existing detached disks in any zone. U(https://cloud.google.com/compute/docs/images)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#description ⇒ Object?

Returns an optional description.

Returns:

  • (Object, nil) —

    an optional description



16
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 16

attribute :description

#family ⇒ Object?

Returns an optional family name.

Returns:

  • (Object, nil) —

    an optional family name



19
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 19

attribute :family

#name ⇒ String

Returns the name of the image to create or delete.

Returns:

  • (String) —

    the name of the image to create or delete



12
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 12

attribute :name

#pem_file ⇒ Object?

Returns path to the pem file associated with the service account email.

Returns:

  • (Object, nil) —

    path to the pem file associated with the service account email



41
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 41

attribute :pem_file

#project_id ⇒ Object?

Returns your GCE project ID.

Returns:

  • (Object, nil) —

    your GCE project ID



44
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 44

attribute :project_id

#service_account_email ⇒ Object?

Returns service account email.

Returns:

  • (Object, nil) —

    service account email



38
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 38

attribute :service_account_email

#source ⇒ String?

Returns the source disk or the Google Cloud Storage URI to create the image from.

Returns:

  • (String, nil) —

    the source disk or the Google Cloud Storage URI to create the image from



22
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 22

attribute :source

#state ⇒ :present, ...

Returns desired state of the image.

Returns:

  • (:present, :absent, nil) —

    desired state of the image



26
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 26

attribute :state

#timeout ⇒ Integer?

Returns timeout for the operation.

Returns:

  • (Integer, nil) —

    timeout for the operation



34
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 34

attribute :timeout

#zone ⇒ String?

Returns the zone of the disk specified by source.

Returns:

  • (String, nil) —

    the zone of the disk specified by source



30
# File 'lib/ansible/ruby/modules/generated/cloud/google/gce_img.rb', line 30

attribute :zone