Class: Ansible::Ruby::Modules::Gcp_compute_health_check

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb

Overview

An HealthCheck resource. This resource defines a template for how individual virtual machines should be checked for health, via one of the supported protocols.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#check_interval_sec ⇒ Integer?

Returns How often (in seconds) to send a health check. The default value is 5 seconds.

Returns:

  • (Integer, nil) —

    How often (in seconds) to send a health check. The default value is 5 seconds.



16
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 16

attribute :check_interval_sec

#description ⇒ Object?

Returns An optional description of this resource. Provide this property when you create the resource.

Returns:

  • (Object, nil) —

    An optional description of this resource. Provide this property when you create the resource.



20
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 20

attribute :description

#healthy_threshold ⇒ Integer?

Returns A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.

Returns:

  • (Integer, nil) —

    A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2.



23
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 23

attribute :healthy_threshold

#http_health_check ⇒ Object?

Returns A nested object resource.

Returns:

  • (Object, nil) —

    A nested object resource.



43
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 43

attribute :http_health_check

#https_health_check ⇒ Object?

Returns A nested object resource.

Returns:

  • (Object, nil) —

    A nested object resource.



46
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 46

attribute :https_health_check

#name ⇒ String?

Returns Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

Returns:

  • (String, nil) —

    Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.



27
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 27

attribute :name

#ssl_health_check ⇒ Object?

Returns A nested object resource.

Returns:

  • (Object, nil) —

    A nested object resource.



53
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 53

attribute :ssl_health_check

#state ⇒ :present, ...

Returns Whether the given object should exist in GCP.

Returns:

  • (:present, :absent, nil) —

    Whether the given object should exist in GCP



12
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 12

attribute :state

#tcp_health_check ⇒ Hash?

Returns A nested object resource.

Returns:

  • (Hash, nil) —

    A nested object resource.



49
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 49

attribute :tcp_health_check

#timeout_sec ⇒ Integer?

Returns How long (in seconds) to wait before claiming failure.,The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec.

Returns:

  • (Integer, nil) —

    How long (in seconds) to wait before claiming failure.,The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec.



31
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 31

attribute :timeout_sec

#type ⇒ :TCP, ...

Returns Specifies the type of the healthCheck, either TCP, SSL, HTTP or HTTPS. If not specified, the default is TCP. Exactly one of the protocol-specific health check field must be specified, which must match type field.

Returns:

  • (:TCP, :SSL, :HTTP, nil) —

    Specifies the type of the healthCheck, either TCP, SSL, HTTP or HTTPS. If not specified, the default is TCP. Exactly one of the protocol-specific health check field must be specified, which must match type field.



39
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 39

attribute :type

#unhealthy_threshold ⇒ Integer?

Returns A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.

Returns:

  • (Integer, nil) —

    A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2.



35
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_health_check.rb', line 35

attribute :unhealthy_threshold