Class: Ansible::Ruby::Modules::Gcp_storage_bucket_access_control

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/google/gcp_storage_bucket_access_control.rb

Overview

The BucketAccessControls resource represents the Access Control Lists (ACLs) for buckets within Google Cloud Storage. ACLs let you specify who has access to your data and to what extent. There are three roles that can be assigned to an entity: READERs can get the bucket, though no acl property will be returned, and list the bucket’s objects. WRITERs are READERs, and they can insert objects into the bucket and delete the bucket’s objects. OWNERs are WRITERs, and they can get the acl property of a bucket, update a bucket, and call all BucketAccessControls methods on the bucket. For more information, see Access Control, with the caveat that this API uses READER, WRITER, and OWNER instead of READ, WRITE, and FULL_CONTROL.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#bucketString



17
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_storage_bucket_access_control.rb', line 17

attribute :bucket

#entityString



21
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_storage_bucket_access_control.rb', line 21

attribute :entity

#entity_idObject?



25
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_storage_bucket_access_control.rb', line 25

attribute :entity_id

#project_teamObject?



28
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_storage_bucket_access_control.rb', line 28

attribute :project_team

#role:OWNER, ...



31
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_storage_bucket_access_control.rb', line 31

attribute :role

#state:present, ...



13
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_storage_bucket_access_control.rb', line 13

attribute :state