Class: Ansible::Ruby::Modules::Github_hooks

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/source_control/github_hooks.rb

Overview

Adds service hooks and removes service hooks that have an error status.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#action ⇒ :create, ...

Returns This tells the githooks module what you want it to do.

Returns:

  • (:create, :cleanall, :list, :clean504) —

    This tells the githooks module what you want it to do.



28
# File 'lib/ansible/ruby/modules/generated/source_control/github_hooks.rb', line 28

attribute :action

#content_type ⇒ :json, ...

Returns Content type to use for requests made to the webhook.

Returns:

  • (:json, :form, nil) —

    Content type to use for requests made to the webhook



36
# File 'lib/ansible/ruby/modules/generated/source_control/github_hooks.rb', line 36

attribute :content_type

#hookurl ⇒ String?

Returns When creating a new hook, this is the url that you want GitHub to post to. It is only required when creating a new hook.

Returns:

  • (String, nil) —

    When creating a new hook, this is the url that you want GitHub to post to. It is only required when creating a new hook.



24
# File 'lib/ansible/ruby/modules/generated/source_control/github_hooks.rb', line 24

attribute :hookurl

#oauthkey ⇒ String

Returns The oauth key provided by GitHub. It can be found/generated on GitHub under "Edit Your Profile" >> "Developer settings" >> "Personal Access Tokens".

Returns:

  • (String) —

    The oauth key provided by GitHub. It can be found/generated on GitHub under "Edit Your Profile" >> "Developer settings" >> "Personal Access Tokens"



16
# File 'lib/ansible/ruby/modules/generated/source_control/github_hooks.rb', line 16

attribute :oauthkey

#repo ⇒ String

Returns This is the API url for the repository you want to manage hooks for. It should be in the form of: https://api.github.com/repos/user:/repo:. Note this is different than the normal repo url.\r\n.

Returns:

  • (String) —

    This is the API url for the repository you want to manage hooks for. It should be in the form of: https://api.github.com/repos/user:/repo:. Note this is different than the normal repo url.\r\n



20
# File 'lib/ansible/ruby/modules/generated/source_control/github_hooks.rb', line 20

attribute :repo

#user ⇒ String

Returns Github username.

Returns:

  • (String) —

    Github username.



12
# File 'lib/ansible/ruby/modules/generated/source_control/github_hooks.rb', line 12

attribute :user

#validate_certs ⇒ :yes, ...

Returns If C(no), SSL certificates for the target repo will not be validated. This should only be used on personally controlled sites using self-signed certificates.

Returns:

  • (:yes, :no, nil) —

    If C(no), SSL certificates for the target repo will not be validated. This should only be used on personally controlled sites using self-signed certificates.



32
# File 'lib/ansible/ruby/modules/generated/source_control/github_hooks.rb', line 32

attribute :validate_certs