Class: Ansible::Ruby::Modules::Github_key
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Github_key
- Defined in:
- lib/ansible/ruby/modules/generated/source_control/github_key.rb
Overview
Creates, removes, or updates GitHub access keys.
Instance Method Summary collapse
-
#force ⇒ :yes, ...
The default is C(yes), which will replace the existing remote key if it’s different than C(pubkey).
-
#name ⇒ String
SSH key name.
-
#pubkey ⇒ String?
SSH public key value.
-
#state ⇒ :present, ...
Whether to remove a key, ensure that it exists, or update its value.
-
#token ⇒ String
GitHub Access Token with permission to list and create public keys.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#force ⇒ :yes, ...
28 |
# File 'lib/ansible/ruby/modules/generated/source_control/github_key.rb', line 28 attribute :force |
#name ⇒ String
16 |
# File 'lib/ansible/ruby/modules/generated/source_control/github_key.rb', line 16 attribute :name |
#pubkey ⇒ String?
20 |
# File 'lib/ansible/ruby/modules/generated/source_control/github_key.rb', line 20 attribute :pubkey |
#state ⇒ :present, ...
24 |
# File 'lib/ansible/ruby/modules/generated/source_control/github_key.rb', line 24 attribute :state |
#token ⇒ String
12 |
# File 'lib/ansible/ruby/modules/generated/source_control/github_key.rb', line 12 attribute :token |