Class: Ansible::Ruby::Modules::Gitlab_user

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb

Overview

When the user does not exist in Gitlab, it will be created. When the user does exists and state=absent, the user will be deleted. When changes are made to user, the user will be updated.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#access_level ⇒ Object?

Returns The access level to the group. One of the following can be used.,guest,reporter,developer,master,owner.

Returns:

  • (Object, nil) —

    The access level to the group. One of the following can be used.,guest,reporter,developer,master,owner



61
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 61

attribute :access_level

#confirm ⇒ :yes, ...

Returns Require confirmation.

Returns:

  • (:yes, :no, nil) —

    Require confirmation.



68
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 68

attribute :confirm

#email ⇒ String

Returns The email that belongs to the user.

Returns:

  • (String) —

    The email that belongs to the user.



46
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 46

attribute :email

#group ⇒ Object?

Returns Add user as an member to this group.

Returns:

  • (Object, nil) —

    Add user as an member to this group.



58
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 58

attribute :group

#login_password ⇒ String?

Returns Gitlab password for login_user.

Returns:

  • (String, nil) —

    Gitlab password for login_user



26
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 26

attribute :login_password

#login_token ⇒ String?

Returns Gitlab token for logging in.

Returns:

  • (String, nil) —

    Gitlab token for logging in.



30
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 30

attribute :login_token

#login_user ⇒ String?

Returns Gitlab user name.

Returns:

  • (String, nil) —

    Gitlab user name.



22
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 22

attribute :login_user

#name ⇒ String

Returns Name of the user you want to create.

Returns:

  • (String) —

    Name of the user you want to create



34
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 34

attribute :name

#password ⇒ String

Returns The password of the user.,GitLab server enforces minimum password length to 8, set this value with 8 or more characters.

Returns:

  • (String) —

    The password of the user.,GitLab server enforces minimum password length to 8, set this value with 8 or more characters.



42
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 42

attribute :password

#server_url ⇒ String

Returns Url of Gitlab server, with protocol (http or https).

Returns:

  • (String) —

    Url of Gitlab server, with protocol (http or https).



14
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 14

attribute :server_url

#sshkey_file ⇒ String?

Returns The ssh key itself.

Returns:

  • (String, nil) —

    The ssh key itself.



54
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 54

attribute :sshkey_file

#sshkey_name ⇒ String?

Returns The name of the sshkey.

Returns:

  • (String, nil) —

    The name of the sshkey



50
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 50

attribute :sshkey_name

#state ⇒ :present, ...

Returns create or delete group.,Possible values are present and absent.

Returns:

  • (:present, :absent, nil) —

    create or delete group.,Possible values are present and absent.



64
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 64

attribute :state

#username ⇒ String

Returns The username of the user.

Returns:

  • (String) —

    The username of the user.



38
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 38

attribute :username

#validate_certs ⇒ :yes, ...

Returns When using https if SSL certificate needs to be verified.

Returns:

  • (:yes, :no, nil) —

    When using https if SSL certificate needs to be verified.



18
# File 'lib/ansible/ruby/modules/generated/source_control/gitlab_user.rb', line 18

attribute :validate_certs