Class: Ansible::Ruby::Modules::Gluster_volume
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Gluster_volume
- Defined in:
- lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb
Overview
Create, remove, start, stop and tune GlusterFS volumes
Instance Method Summary collapse
-
#arbiters ⇒ Object?
Arbiter count for volume.
-
#bricks ⇒ Array<String>, ...
Brick paths on servers.
-
#cluster ⇒ Array<String>, ...
List of hosts to use for probing and brick setup.
-
#directory ⇒ String?
Directory for limit-usage.
-
#disperses ⇒ Object?
Disperse count for volume.
-
#force ⇒ Symbol?
If brick is being created in the root partition, module will fail.
-
#host ⇒ Object?
Override local hostname (for peer probing purposes).
-
#name ⇒ String
The volume name.
-
#options ⇒ Hash?
A dictionary/hash with options/settings for the volume.
-
#quota ⇒ String?
Quota value for limit-usage (be sure to use 10.0MB instead of 10MB, see quota list).
-
#rebalance ⇒ :yes, ...
Controls whether the cluster is rebalanced after changes.
-
#redundancies ⇒ Object?
Redundancy count for volume.
-
#replicas ⇒ Object?
Replica count for volume.
-
#start_on_create ⇒ :yes, ...
Controls whether the volume is started after creation or not.
-
#state ⇒ :absent, ...
Use present/absent ensure if a volume exists or not.
-
#stripes ⇒ Object?
Stripe count for volume.
-
#transport ⇒ :tcp, ...
Transport type for volume.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#arbiters ⇒ Object?
30 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 30 attribute :arbiters |
#bricks ⇒ Array<String>, ...
46 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 46 attribute :bricks |
#cluster ⇒ Array<String>, ...
20 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 20 attribute :cluster |
#directory ⇒ String?
58 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 58 attribute :directory |
#disperses ⇒ Object?
36 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 36 attribute :disperses |
#force ⇒ Symbol?
70 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 70 attribute :force |
#host ⇒ Object?
24 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 24 attribute :host |
#name ⇒ String
12 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 12 attribute :name |
#options ⇒ Hash?
62 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 62 attribute :options |
#quota ⇒ String?
66 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 66 attribute :quota |
#rebalance ⇒ :yes, ...
54 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 54 attribute :rebalance |
#redundancies ⇒ Object?
39 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 39 attribute :redundancies |
#replicas ⇒ Object?
27 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 27 attribute :replicas |
#start_on_create ⇒ :yes, ...
50 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 50 attribute :start_on_create |
#state ⇒ :absent, ...
16 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 16 attribute :state |
#stripes ⇒ Object?
33 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 33 attribute :stripes |
#transport ⇒ :tcp, ...
42 |
# File 'lib/ansible/ruby/modules/generated/storage/glusterfs/gluster_volume.rb', line 42 attribute :transport |