Class: Ansible::Ruby::Modules::Grafana_datasource

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb

Overview

Create/update/delete Grafana datasources via API.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#access ⇒ :direct, ...

Returns The access mode for this datasource.

Returns:

  • (:direct, :proxy, nil) —

    The access mode for this datasource.



28
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 28

attribute :access

#basic_auth_password ⇒ String?

Returns The datasource basic auth password, when C(basic auth) is C(yes).

Returns:

  • (String, nil) —

    The datasource basic auth password, when C(basic auth) is C(yes).



57
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 57

attribute :basic_auth_password

#basic_auth_user ⇒ String?

Returns The datasource basic auth user.,Setting this option with basic_auth_password will enable basic auth.

Returns:

  • (String, nil) —

    The datasource basic auth user.,Setting this option with basic_auth_password will enable basic auth.



53
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 53

attribute :basic_auth_user

#database ⇒ String?

Returns Name of the database for the datasource.,This options is required when the C(ds_type) is C(influxdb), C(elasticsearch) (index name), C(mysql) or C(postgres).

Returns:

  • (String, nil) —

    Name of the database for the datasource.,This options is required when the C(ds_type) is C(influxdb), C(elasticsearch) (index name), C(mysql) or C(postgres).



43
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 43

attribute :database

#ds_type ⇒ :graphite, ...

Returns The type of the datasource.

Returns:

  • (:graphite, :prometheus, :elasticsearch, :influxdb, :opentsdb, :mysql, :postgres, :"alexanderzobnin-zabbix-datasource") —

    The type of the datasource.



20
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 20

attribute :ds_type

#es_version ⇒ 2, ...

Returns Elasticsearch version (for C(ds_type = elasticsearch) only),Version 56 is for elasticsearch 5.6+ where tou can specify the C(max_concurrent_shard_requests) option.

Returns:

  • (2, 5, 56, nil) —

    Elasticsearch version (for C(ds_type = elasticsearch) only),Version 56 is for elasticsearch 5.6+ where tou can specify the C(max_concurrent_shard_requests) option.



91
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 91

attribute :es_version

#grafana_api_key ⇒ Object?

Returns The Grafana API key.,If set, C(grafana_user) and C(grafana_password) will be ignored.

Returns:

  • (Object, nil) —

    The Grafana API key.,If set, C(grafana_user) and C(grafana_password) will be ignored.



40
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 40

attribute :grafana_api_key

#grafana_password ⇒ String?

Returns The Grafana API password.

Returns:

  • (String, nil) —

    The Grafana API password.



36
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 36

attribute :grafana_password

#grafana_url ⇒ String

Returns The Grafana URL.

Returns:

  • (String) —

    The Grafana URL.



12
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 12

attribute :grafana_url

#grafana_user ⇒ String?

Returns The Grafana API user.

Returns:

  • (String, nil) —

    The Grafana API user.



32
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 32

attribute :grafana_user

#interval ⇒ :"", ...

Returns For elasticsearch C(ds_type), this is the index pattern used.

Returns:

  • (:"", :Hourly, :Daily, :Weekly, :Monthly, :Yearly, nil) —

    For elasticsearch C(ds_type), this is the index pattern used.



107
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 107

attribute :interval

#is_default ⇒ :yes, ...

Returns Make this datasource the default one.

Returns:

  • (:yes, :no, nil) —

    Make this datasource the default one.



79
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 79

attribute :is_default

#max_concurrent_shard_requests ⇒ Integer?

Returns Starting with elasticsearch 5.6, you can specify the max concurrent shard per requests.

Returns:

  • (Integer, nil) —

    Starting with elasticsearch 5.6, you can specify the max concurrent shard per requests.



95
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 95

attribute :max_concurrent_shard_requests

#name ⇒ String

Returns The name of the datasource.

Returns:

  • (String) —

    The name of the datasource.



16
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 16

attribute :name

#org_id ⇒ Integer?

Returns Grafana Organisation ID in which the datasource should be created.,Not used when C(grafana_api_key) is set, because the C(grafana_api_key) only belong to one organisation.

Returns:

  • (Integer, nil) —

    Grafana Organisation ID in which the datasource should be created.,Not used when C(grafana_api_key) is set, because the C(grafana_api_key) only belong to one organisation.



83
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 83

attribute :org_id

#password ⇒ Object?

Returns The datasource password.

Returns:

  • (Object, nil) —

    The datasource password



50
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 50

attribute :password

#sslmode ⇒ :disable, ...

Returns SSL mode for C(postgres) datasoure type.

Returns:

  • (:disable, :require, :"verify-ca", :"verify-full", nil) —

    SSL mode for C(postgres) datasoure type.



119
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 119

attribute :sslmode

#state ⇒ :absent, ...

Returns Status of the datasource.

Returns:

  • (:absent, :present, nil) —

    Status of the datasource



87
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 87

attribute :state

#time_field ⇒ String?

Returns Name of the time field in elasticsearch ds.,For example C(@timestamp).

Returns:

  • (String, nil) —

    Name of the time field in elasticsearch ds.,For example C(@timestamp)



99
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 99

attribute :time_field

#time_interval ⇒ String?

Returns Minimum group by interval for C(influxdb) or C(elasticsearch) datasources.,for example C(>10s).

Returns:

  • (String, nil) —

    Minimum group by interval for C(influxdb) or C(elasticsearch) datasources.,for example C(>10s)



103
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 103

attribute :time_interval

#tls_ca_cert ⇒ String?

Returns The TLS CA certificate for self signed certificates.,Only used when C(tls_client_cert) and C(tls_client_key) are set.

Returns:

  • (String, nil) —

    The TLS CA certificate for self signed certificates.,Only used when C(tls_client_cert) and C(tls_client_key) are set.



71
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 71

attribute :tls_ca_cert

#tls_client_cert ⇒ Object?

Returns The client TLS certificate.,If C(tls_client_cert) and C(tls_client_key) are set, this will enable TLS authentication.,Starts with ----- BEGIN CERTIFICATE -----.

Returns:

  • (Object, nil) —

    The client TLS certificate.,If C(tls_client_cert) and C(tls_client_key) are set, this will enable TLS authentication.,Starts with ----- BEGIN CERTIFICATE -----



65
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 65

attribute :tls_client_cert

#tls_client_key ⇒ Object?

Returns The client TLS private key,Starts with ----- BEGIN RSA PRIVATE KEY -----.

Returns:

  • (Object, nil) —

    The client TLS private key,Starts with ----- BEGIN RSA PRIVATE KEY -----



68
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 68

attribute :tls_client_key

#tls_skip_verify ⇒ Symbol?

Returns Skip the TLS datasource certificate verification.

Returns:

  • (Symbol, nil) —

    Skip the TLS datasource certificate verification.



75
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 75

attribute :tls_skip_verify

Returns Use trends or not for zabbix datasource type.

Returns:

  • (Symbol, nil) —

    Use trends or not for zabbix datasource type



123
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 123

attribute :trends

#tsdb_resolution ⇒ :millisecond, ...

Returns The opentsdb time resolution.

Returns:

  • (:millisecond, :second, nil) —

    The opentsdb time resolution.



115
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 115

attribute :tsdb_resolution

#tsdb_version ⇒ 1, ...

Returns The opentsdb version.,Use C(1) for <=2.1, C(2) for ==2.2, C(3) for ==2.3.

Returns:

  • (1, 2, 3, nil) —

    The opentsdb version.,Use C(1) for <=2.1, C(2) for ==2.2, C(3) for ==2.3.



111
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 111

attribute :tsdb_version

#url ⇒ String

Returns The URL of the datasource.

Returns:

  • (String) —

    The URL of the datasource.



24
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 24

attribute :url

#user ⇒ Object?

Returns The datasource login user for influxdb datasources.

Returns:

  • (Object, nil) —

    The datasource login user for influxdb datasources.



47
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 47

attribute :user

#validate_certs ⇒ :yes, ...

Returns Whether to validate the Grafana certificate.

Returns:

  • (:yes, :no, nil) —

    Whether to validate the Grafana certificate.



127
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 127

attribute :validate_certs

#with_credentials ⇒ :yes, ...

Returns Whether credentials such as cookies or auth headers should be sent with cross-site requests.

Returns:

  • (:yes, :no, nil) —

    Whether credentials such as cookies or auth headers should be sent with cross-site requests.



61
# File 'lib/ansible/ruby/modules/generated/monitoring/grafana_datasource.rb', line 61

attribute :with_credentials