Class: Ansible::Ruby::Modules::Iam_group

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/amazon/iam_group.rb

Overview

Manage AWS IAM groups

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#managed_policy ⇒ Array<String>, ...

Returns A list of managed policy ARNs or friendly names to attach to the role. To embed an inline policy, use M(iam_policy).

Returns:

  • (Array<String>, String, nil) —

    A list of managed policy ARNs or friendly names to attach to the role. To embed an inline policy, use M(iam_policy).



16
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/iam_group.rb', line 16

attribute :managed_policy

#name ⇒ String

Returns The name of the group to create.

Returns:

  • (String) —

    The name of the group to create.



12
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/iam_group.rb', line 12

attribute :name

#purge_policy ⇒ Boolean?

Returns Deatach policy which not included in managed_policy list.

Returns:

  • (Boolean, nil) —

    Deatach policy which not included in managed_policy list



28
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/iam_group.rb', line 28

attribute :purge_policy

#purge_users ⇒ Boolean?

Returns Deatach users which not included in users list.

Returns:

  • (Boolean, nil) —

    Deatach users which not included in users list



32
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/iam_group.rb', line 32

attribute :purge_users

#state ⇒ :present, :absent

Returns Create or remove the IAM group.

Returns:

  • (:present, :absent) —

    Create or remove the IAM group



24
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/iam_group.rb', line 24

attribute :state

#users ⇒ Array<String>, ...

Returns A list of existing users to add as members of the group.

Returns:

  • (Array<String>, String, nil) —

    A list of existing users to add as members of the group.



20
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/iam_group.rb', line 20

attribute :users