Class: Ansible::Ruby::Modules::Ipadm_addrprop

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/illumos/ipadm_addrprop.rb

Overview

Modify IP address properties on Solaris/illumos systems.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#addrobj ⇒ String

Returns Specifies the address object we want to manage.

Returns:

  • (String) —

    Specifies the address object we want to manage.



12
# File 'lib/ansible/ruby/modules/generated/network/illumos/ipadm_addrprop.rb', line 12

attribute :addrobj

#property ⇒ String

Returns Specifies the name of the address property we want to manage.

Returns:

  • (String) —

    Specifies the name of the address property we want to manage.



16
# File 'lib/ansible/ruby/modules/generated/network/illumos/ipadm_addrprop.rb', line 16

attribute :property

#state ⇒ :present, ...

Returns Set or reset the property value.

Returns:

  • (:present, :absent, :reset, nil) —

    Set or reset the property value.



28
# File 'lib/ansible/ruby/modules/generated/network/illumos/ipadm_addrprop.rb', line 28

attribute :state

#temporary ⇒ Boolean?

Returns Specifies that the address property value is temporary. Temporary values do not persist across reboots.

Returns:

  • (Boolean, nil) —

    Specifies that the address property value is temporary. Temporary values do not persist across reboots.



24
# File 'lib/ansible/ruby/modules/generated/network/illumos/ipadm_addrprop.rb', line 24

attribute :temporary

#value ⇒ String?

Returns Specifies the value we want to set for the address property.

Returns:

  • (String, nil) —

    Specifies the value we want to set for the address property.



20
# File 'lib/ansible/ruby/modules/generated/network/illumos/ipadm_addrprop.rb', line 20

attribute :value