Class: Ansible::Ruby::Modules::Jboss

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/web_infrastructure/jboss.rb

Overview

Deploy applications to JBoss standalone using the filesystem

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#deploy_path ⇒ String?

Returns The location in the filesystem where the deployment scanner listens.

Returns:

  • (String, nil) —

    The location in the filesystem where the deployment scanner listens



20
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/jboss.rb', line 20

attribute :deploy_path

#deployment ⇒ String

Returns The name of the deployment.

Returns:

  • (String) —

    The name of the deployment



12
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/jboss.rb', line 12

attribute :deployment

#src ⇒ String?

Returns The remote path of the application ear or war to deploy.

Returns:

  • (String, nil) —

    The remote path of the application ear or war to deploy



16
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/jboss.rb', line 16

attribute :src

#state ⇒ :present, ...

Returns Whether the application should be deployed or undeployed.

Returns:

  • (:present, :absent, nil) —

    Whether the application should be deployed or undeployed



24
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/jboss.rb', line 24

attribute :state