Class: Ansible::Ruby::Modules::Junos_facts

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/junos/junos_facts.rb

Overview

Collects fact information from a remote device running the Junos operating system. By default, the module will collect basic fact information from the device to be included with the hostvars. Additional fact information can be collected based on the configured set of arguments.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#config_format:xml, ...



16
# File 'lib/ansible/ruby/modules/generated/network/junos/junos_facts.rb', line 16

attribute :config_format

#gather_subsetString?



12
# File 'lib/ansible/ruby/modules/generated/network/junos/junos_facts.rb', line 12

attribute :gather_subset