Class: Ansible::Ruby::Modules::K8s

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/clustering/k8s/k8s.rb,
lib/ansible/ruby/modules/generated/clustering/k8s/k8s_raw.rb,
lib/ansible/ruby/modules/generated/clustering/openshift/openshift_raw.rb

Overview

Use the OpenShift Python client to perform CRUD operations on K8s objects. Pass the object definition from a source file or inline. See examples for reading files and using Jinja templates. Access to the full range of K8s APIs. Use the M(k8s_facts) module to obtain a list of items about an object of type C(kind) Authenticate using either a config file, certificates, password or token. Supports check mode.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#merge_type:json, ...



17
# File 'lib/ansible/ruby/modules/generated/clustering/k8s/k8s.rb', line 17

attribute :merge_type