Class: Ansible::Ruby::Modules::Lxd_container
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Lxd_container
- Defined in:
- lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb
Overview
Management of LXD containers
Instance Method Summary collapse
-
#architecture ⇒ Object?
The architecture for the container (e.g. "x86_64" or "i686").
-
#cert_file ⇒ String?
The client certificate file path.
-
#config ⇒ Object?
The config for the container (e.g. "2").
-
#devices ⇒ Object?
The devices for the container (e.g. { "rootfs": { "path": "/dev/kvm", "type": "unix-char" }). See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#post-1).
-
#ephemeral ⇒ Object?
Whether or not the container is ephemeral (e.g. true or false).
-
#force_stop ⇒ Boolean?
If this is true, the C(lxd_container) forces to stop the container when it stops or restarts the container.
-
#key_file ⇒ String?
The client certificate key file path.
-
#name ⇒ String
Name of a container.
-
#source ⇒ Object?
The source for the container (e.g. { "type": "image", "mode": "pull", "server": "https://images.linuxcontainers.org", "protocol": "lxd", "alias": "ubuntu/xenial/amd64" }).
-
#state ⇒ :started, ...
Define the state of a container.
-
#timeout ⇒ Integer?
A timeout for changing the state of the container.,This is also used as a timeout for waiting until IPv4 addresses are set to the all network interfaces in the container after starting or restarting.
-
#trust_password ⇒ Object?
The client trusted password.,You need to set this password on the LXD server before running this module using the following command.
-
#url ⇒ String?
The unix domain socket path or the https URL for the LXD server.
-
#wait_for_ipv4_addresses ⇒ Boolean?
If this is true, the C(lxd_container) waits until IPv4 addresses are set to the all network interfaces in the container after starting or restarting.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#architecture ⇒ Object?
Returns The architecture for the container (e.g. "x86_64" or "i686"). See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#post-1).
16 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 16 attribute :architecture |
#cert_file ⇒ String?
Returns The client certificate file path.
55 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 55 attribute :cert_file |
#config ⇒ Object?
Returns The config for the container (e.g. "2"). See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#post-1),If the container already exists and its "config" value in metadata obtained from GET /1.0/containers/
19 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 19 attribute :config |
#devices ⇒ Object?
Returns The devices for the container (e.g. { "rootfs": { "path": "/dev/kvm", "type": "unix-char" }). See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#post-1).
22 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 22 attribute :devices |
#ephemeral ⇒ Object?
Returns Whether or not the container is ephemeral (e.g. true or false). See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#post-1).
25 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 25 attribute :ephemeral |
#force_stop ⇒ Boolean?
Returns If this is true, the C(lxd_container) forces to stop the container when it stops or restarts the container.
43 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 43 attribute :force_stop |
#key_file ⇒ String?
Returns The client certificate key file path.
51 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 51 attribute :key_file |
#name ⇒ String
Returns Name of a container.
12 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 12 attribute :name |
#source ⇒ Object?
Returns The source for the container (e.g. { "type": "image", "mode": "pull", "server": "https://images.linuxcontainers.org", "protocol": "lxd", "alias": "ubuntu/xenial/amd64" }). See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#post-1).
28 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 28 attribute :source |
#state ⇒ :started, ...
Returns Define the state of a container.
31 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 31 attribute :state |
#timeout ⇒ Integer?
Returns A timeout for changing the state of the container.,This is also used as a timeout for waiting until IPv4 addresses are set to the all network interfaces in the container after starting or restarting.
35 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 35 attribute :timeout |
#trust_password ⇒ Object?
Returns The client trusted password.,You need to set this password on the LXD server before running this module using the following command. lxc config set core.trust_password
59 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 59 attribute :trust_password |
#url ⇒ String?
Returns The unix domain socket path or the https URL for the LXD server.
47 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 47 attribute :url |
#wait_for_ipv4_addresses ⇒ Boolean?
Returns If this is true, the C(lxd_container) waits until IPv4 addresses are set to the all network interfaces in the container after starting or restarting.
39 |
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_container.rb', line 39 attribute :wait_for_ipv4_addresses |