Class: Ansible::Ruby::Modules::Lxd_profile

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb

Overview

Management of LXD profiles

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#cert_file ⇒ String?

Returns The client certificate file path.

Returns:

  • (String, nil) —

    The client certificate file path.



40
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 40

attribute :cert_file

#config ⇒ Object?

Returns The config for the container (e.g. "4GB"). See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#patch-3),If the profile already exists and its "config" value in metadata obtained from GET /1.0/profiles/ U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#get-19) are different, they this module tries to apply the configurations.,Not all config values are supported to apply the existing profile. Maybe you need to delete and recreate a profile.

Returns:



19
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 19

attribute :config

#description ⇒ Object?

Returns Description of the profile.

Returns:

  • (Object, nil) —

    Description of the profile.



16
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 16

attribute :description

#devices ⇒ Object?

Returns The devices for the profile (e.g. {"path": "/dev/kvm", "type": "unix-char"). See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#patch-3).

Returns:



22
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 22

attribute :devices

#key_file ⇒ String?

Returns The client certificate key file path.

Returns:

  • (String, nil) —

    The client certificate key file path.



36
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 36

attribute :key_file

#name ⇒ String

Returns Name of a profile.

Returns:

  • (String) —

    Name of a profile.



12
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 12

attribute :name

#new_name ⇒ Object?

Returns A new name of a profile.,If this parameter is specified a profile will be renamed to this name. See U(https://github.com/lxc/lxd/blob/master/doc/rest-api.md#post-11).

Returns:



25
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 25

attribute :new_name

#state ⇒ :present, ...

Returns Define the state of a profile.

Returns:

  • (:present, :absent, nil) —

    Define the state of a profile.



28
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 28

attribute :state

#trust_password ⇒ Object?

Returns The client trusted password.,You need to set this password on the LXD server before running this module using the following command. lxc config set core.trust_password See U(https://www.stgraber.org/2016/04/18/lxd-api-direct-interaction/),If trust_password is set, this module send a request for authentication before sending any requests.

Returns:

  • (Object, nil) —

    The client trusted password.,You need to set this password on the LXD server before running this module using the following command. lxc config set core.trust_password See U(https://www.stgraber.org/2016/04/18/lxd-api-direct-interaction/),If trust_password is set, this module send a request for authentication before sending any requests.



44
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 44

attribute :trust_password

#url ⇒ String?

Returns The unix domain socket path or the https URL for the LXD server.

Returns:

  • (String, nil) —

    The unix domain socket path or the https URL for the LXD server.



32
# File 'lib/ansible/ruby/modules/generated/cloud/lxd/lxd_profile.rb', line 32

attribute :url