Class: Ansible::Ruby::Modules::Meraki_network

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb

Overview

Allows for creation, management, and visibility into networks within Meraki.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#auth_key ⇒ String?

Returns Authentication key provided by the dashboard. Required if environmental variable MERAKI_KEY is not set.

Returns:

  • (String, nil) —

    Authentication key provided by the dashboard. Required if environmental variable MERAKI_KEY is not set.



12
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 12

attribute :auth_key

#disable_my_meraki ⇒ Symbol?

Returns - Disables the local device status pages (Umy.meraki.com, Uap.meraki.com, Uswitch.meraki.com, Uwired.meraki.com)\r\n.

Returns:



46
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 46

attribute :disable_my_meraki

#net_id ⇒ Object?

Returns ID number of a network.

Returns:

  • (Object, nil) —

    ID number of a network.



24
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 24

attribute :net_id

#net_name ⇒ String?

Returns Name of a network.

Returns:

  • (String, nil) —

    Name of a network.



20
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 20

attribute :net_name

#org_id ⇒ Object?

Returns ID of organization associated to a network.

Returns:

  • (Object, nil) —

    ID of organization associated to a network.



31
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 31

attribute :org_id

#org_name ⇒ String?

Returns Name of organization associated to a network.

Returns:

  • (String, nil) —

    Name of organization associated to a network.



27
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 27

attribute :org_name

#state ⇒ :absent, ...

Returns Create or modify an organization.

Returns:

  • (:absent, :present, :query, nil) —

    Create or modify an organization.



16
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 16

attribute :state

#tags ⇒ Array<String>, ...

Returns Comma delimited list of tags to assign to network.

Returns:

  • (Array<String>, String, nil) —

    Comma delimited list of tags to assign to network.



38
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 38

attribute :tags

#timezone ⇒ String?

Returns Timezone associated to network.,See U(https://en.wikipedia.org/wiki/List_of_tz_database_time_zones) for a list of valid timezones.

Returns:



42
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 42

attribute :timezone

#type ⇒ :appliance, ...

Returns Type of network device network manages.,Required when creating a network.

Returns:

  • (:appliance, :combined, :switch, :wireless, nil) —

    Type of network device network manages.,Required when creating a network.



34
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_network.rb', line 34

attribute :type