Class: Ansible::Ruby::Modules::Meraki_switchport

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb

Overview

Allows for management of switchports settings for Meraki MS switches.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#access_policy_number ⇒ Object?

Returns Number of the access policy to apply.,Only applicable to access port types.

Returns:

  • (Object, nil) —

    Number of the access policy to apply.,Only applicable to access port types.



16
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 16

attribute :access_policy_number

#allowed_vlans ⇒ String?

Returns List of VLAN numbers to be allowed on switchport.

Returns:

  • (String, nil) —

    List of VLAN numbers to be allowed on switchport.



19
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 19

attribute :allowed_vlans

#enabled ⇒ Boolean?

Returns Whether a switchport should be enabled or disabled.

Returns:

  • (Boolean, nil) —

    Whether a switchport should be enabled or disabled.



23
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 23

attribute :enabled

#isolation_enabled ⇒ Symbol?

Returns Isolation status of switchport.

Returns:

  • (Symbol, nil) —

    Isolation status of switchport.



27
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 27

attribute :isolation_enabled

Returns Link speed for the switchport.

Returns:

  • (:"Auto negotiate", :"100Megabit (auto)", :"100 Megabit full duplex (forced)", nil) —

    Link speed for the switchport.



31
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 31

attribute :link_negotiation

#name ⇒ String?

Returns Switchport description.

Returns:

  • (String, nil) —

    Switchport description.



35
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 35

attribute :name

#number ⇒ Integer?

Returns Port number.

Returns:

  • (Integer, nil) —

    Port number.



39
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 39

attribute :number

#poe_enabled ⇒ Boolean?

Returns Enable or disable Power Over Ethernet on a port.

Returns:

  • (Boolean, nil) —

    Enable or disable Power Over Ethernet on a port.



43
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 43

attribute :poe_enabled

#rstp_enabled ⇒ Boolean?

Returns Enable or disable Rapid Spanning Tree Protocol on a port.

Returns:

  • (Boolean, nil) —

    Enable or disable Rapid Spanning Tree Protocol on a port.



47
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 47

attribute :rstp_enabled

#serial ⇒ String?

Returns Serial nubmer of the switch.

Returns:

  • (String, nil) —

    Serial nubmer of the switch.



51
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 51

attribute :serial

#state ⇒ :query, ...

Returns Specifies whether a switchport should be queried or modified.

Returns:

  • (:query, :present, nil) —

    Specifies whether a switchport should be queried or modified.



12
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 12

attribute :state

#stp_guard ⇒ :disabled, ...

Returns Set state of STP guard.

Returns:

  • (:disabled, :"root guard", :"bpdu guard", :"loop guard", nil) —

    Set state of STP guard.



55
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 55

attribute :stp_guard

#tags ⇒ String?

Returns Space delimited list of tags to assign to a port.

Returns:

  • (String, nil) —

    Space delimited list of tags to assign to a port.



59
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 59

attribute :tags

#type ⇒ :access, ...

Returns Set port type.

Returns:

  • (:access, :trunk, nil) —

    Set port type.



63
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 63

attribute :type

#vlan ⇒ Integer?

Returns VLAN number assigned to port.,If a port is of type trunk, the specified VLAN is the native VLAN.

Returns:

  • (Integer, nil) —

    VLAN number assigned to port.,If a port is of type trunk, the specified VLAN is the native VLAN.



67
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 67

attribute :vlan

#voice_vlan ⇒ Integer?

Returns VLAN number assigned to a port for voice traffic.,Only applicable to access port type.

Returns:

  • (Integer, nil) —

    VLAN number assigned to a port for voice traffic.,Only applicable to access port type.



71
# File 'lib/ansible/ruby/modules/generated/network/meraki/meraki_switchport.rb', line 71

attribute :voice_vlan