Class: Ansible::Ruby::Modules::Na_cdot_volume

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb

Overview

Create or destroy volumes on NetApp cDOT

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#aggregate_name ⇒ String?

Returns The name of the aggregate the flexvol should exist on. Required when C(state=present).

Returns:

  • (String, nil) —

    The name of the aggregate the flexvol should exist on. Required when C(state=present).



28
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 28

attribute :aggregate_name

#export_policy ⇒ String?

Returns Export policy to set for the specified junction path.

Returns:

  • (String, nil) —

    Export policy to set for the specified junction path.



48
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 48

attribute :export_policy

#infinite ⇒ :yes, ...

Returns Set True if the volume is an Infinite Volume.

Returns:

  • (:yes, :no, nil) —

    Set True if the volume is an Infinite Volume.



20
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 20

attribute :infinite

#junction_path ⇒ String?

Returns Junction path where to mount the volume.

Returns:

  • (String, nil) —

    Junction path where to mount the volume



44
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 44

attribute :junction_path

#name ⇒ String

Returns The name of the volume to manage.

Returns:

  • (String) —

    The name of the volume to manage.



16
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 16

attribute :name

#online ⇒ :yes, ...

Returns Whether the specified volume is online, or not.

Returns:

  • (:yes, :no, nil) —

    Whether the specified volume is online, or not.



24
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 24

attribute :online

#size ⇒ Integer?

Returns The size of the volume in (size_unit). Required when C(state=present).

Returns:

  • (Integer, nil) —

    The size of the volume in (size_unit). Required when C(state=present).



32
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 32

attribute :size

#size_unit ⇒ :bytes, ...

Returns The unit used to interpret the size parameter.

Returns:

  • (:bytes, :b, :kb, :mb, :gb, :tb, :pb, :eb, :zb, :yb, nil) —

    The unit used to interpret the size parameter.



36
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 36

attribute :size_unit

#snapshot_policy ⇒ String?

Returns Snapshot policy to set for the specified volume.

Returns:

  • (String, nil) —

    Snapshot policy to set for the specified volume.



52
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 52

attribute :snapshot_policy

#state ⇒ :present, :absent

Returns Whether the specified volume should exist or not.

Returns:

  • (:present, :absent) —

    Whether the specified volume should exist or not.



12
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 12

attribute :state

#vserver ⇒ String

Returns Name of the vserver to use.

Returns:

  • (String) —

    Name of the vserver to use.



40
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_cdot_volume.rb', line 40

attribute :vserver