Class: Ansible::Ruby::Modules::Na_ontap_cifs_server

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb

Overview

Creating / deleting and modifying the CIFS server.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#admin_password ⇒ Object?

Returns Specifies the cifs server admin password.

Returns:

  • (Object, nil) —

    Specifies the cifs server admin password.



27
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 27

attribute :admin_password

#admin_user_name ⇒ Object?

Returns Specifies the cifs server admin username.

Returns:

  • (Object, nil) —

    Specifies the cifs server admin username.



24
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 24

attribute :admin_user_name

#cifs_server_name ⇒ String

Returns Specifies the cifs_server name.

Returns:

  • (String) —

    Specifies the cifs_server name.



20
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 20

attribute :cifs_server_name

#domain ⇒ Object?

Returns The Fully Qualified Domain Name of the Windows Active Directory this CIFS server belongs to.

Returns:

  • (Object, nil) —

    The Fully Qualified Domain Name of the Windows Active Directory this CIFS server belongs to.



30
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 30

attribute :domain

#force ⇒ Symbol?

Returns If this is set and a machine account with the same name as specified in 'cifs_server_name' exists in the Active Directory, it will be overwritten and reused.

Returns:

  • (Symbol, nil) —

    If this is set and a machine account with the same name as specified in 'cifs_server_name' exists in the Active Directory, it will be overwritten and reused.



39
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 39

attribute :force

#ou ⇒ Object?

Returns The Organizational Unit (OU) within the Windows Active Directory this CIFS server belongs to.

Returns:

  • (Object, nil) —

    The Organizational Unit (OU) within the Windows Active Directory this CIFS server belongs to.



36
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 36

attribute :ou

#service_state ⇒ :stopped, ...

Returns CIFS Server Administrative Status.

Returns:

  • (:stopped, :started, nil) —

    CIFS Server Administrative Status.



16
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 16

attribute :service_state

#state ⇒ :present, ...

Returns Whether the specified cifs_server should exist or not.

Returns:

  • (:present, :absent, nil) —

    Whether the specified cifs_server should exist or not.



12
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 12

attribute :state

#vserver ⇒ String

Returns The name of the vserver to use.

Returns:

  • (String) —

    The name of the vserver to use.



43
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 43

attribute :vserver

#workgroup ⇒ Object?

Returns The NetBIOS name of the domain or workgroup this CIFS server belongs to.

Returns:

  • (Object, nil) —

    The NetBIOS name of the domain or workgroup this CIFS server belongs to.



33
# File 'lib/ansible/ruby/modules/generated/storage/netapp/na_ontap_cifs_server.rb', line 33

attribute :workgroup