Class: Ansible::Ruby::Modules::Nclu
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Nclu
- Defined in:
- lib/ansible/ruby/modules/generated/network/cumulus/nclu.rb
Overview
Interface to the Network Command Line Utility, developed to make it easier to configure operating systems running ifupdown2 and Quagga, such as Cumulus Linux. Command documentation is available at U(docs.cumulusnetworks.com/display/DOCS/Network+Command+Line+Utility)
Instance Method Summary collapse
-
#abort ⇒ Boolean?
Boolean.
-
#atomic ⇒ Boolean?
When true, equivalent to both I(commit) and I(abort) being true.
-
#commands ⇒ Array<String>, ...
A list of strings containing the net commands to run.
-
#commit ⇒ Boolean?
When true, performs a ‘net commit’ at the end of the block.
-
#description ⇒ String?
Commit description that will be recorded to the commit log if I(commit) or I(atomic) are true.
-
#template ⇒ Array<String>, ...
A single, multi-line string with jinja2 formatting.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#abort ⇒ Boolean?
24 |
# File 'lib/ansible/ruby/modules/generated/network/cumulus/nclu.rb', line 24 attribute :abort |
#atomic ⇒ Boolean?
28 |
# File 'lib/ansible/ruby/modules/generated/network/cumulus/nclu.rb', line 28 attribute :atomic |
#commands ⇒ Array<String>, ...
12 |
# File 'lib/ansible/ruby/modules/generated/network/cumulus/nclu.rb', line 12 attribute :commands |
#commit ⇒ Boolean?
20 |
# File 'lib/ansible/ruby/modules/generated/network/cumulus/nclu.rb', line 20 attribute :commit |
#description ⇒ String?
32 |
# File 'lib/ansible/ruby/modules/generated/network/cumulus/nclu.rb', line 32 attribute :description |
#template ⇒ Array<String>, ...
16 |
# File 'lib/ansible/ruby/modules/generated/network/cumulus/nclu.rb', line 16 attribute :template |