Class: Ansible::Ruby::Modules::Netapp_e_alerts

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb

Overview

Certain E-Series systems have the capability to send email notifications on potentially critical events. This module will allow the owner of the system to specify email recipients for these messages.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#contactString?



25
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 25

attribute :contact

#log_pathObject?



37
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 37

attribute :log_path

#recipientsArray<String>, ...



29
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 29

attribute :recipients

#senderString?



21
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 21

attribute :sender

#serverString?



17
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 17

attribute :server

#state:enabled, ...



13
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 13

attribute :state

#testSymbol?



33
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 33

attribute :test