Class: Ansible::Ruby::Modules::Netapp_e_mgmt_interface
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Netapp_e_mgmt_interface
- Defined in:
- lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb
Overview
Configure the E-Series management interfaces
Instance Method Summary collapse
-
#address ⇒ String?
The IPv4 address to assign to the interface.,Should be specified in xx.xx.xx.xx form.,Mutually exclusive with I(config_method=dhcp).
-
#channel ⇒ Object?
The port to modify the configuration for.,The channel represents the port number (typically from left to right on the controller), beginning with a value of 1.,Mutually exclusive with I(name).
-
#config_method ⇒ :dhcp, ...
The configuration method type to use for network interface ports.,dhcp is mutually exclusive with I(address), I(subnet_mask), and I(gateway).
-
#controller ⇒ :A, :B
The controller that owns the port you want to configure.,Controller names are represented alphabetically, with the first controller as A, the second as B, and so on.,Current hardware models have either 1 or 2 available controllers, but that is not a guaranteed hard limitation and could change in the future.
-
#dns_address ⇒ String?
Primary IPv4 DNS server address.
-
#dns_address_backup ⇒ String?
Backup IPv4 DNS server address,Queried when primary DNS server fails.
-
#dns_config_method ⇒ :dhcp, ...
The configuration method type to use for DNS services.,dhcp is mutually exclusive with I(dns_address), and I(dns_address_backup).
-
#gateway ⇒ String?
The IPv4 gateway address to utilize for the interface.,Should be specified in xx.xx.xx.xx form.,Mutually exclusive with I(config_method=dhcp).
-
#log_path ⇒ Object?
A local path to a file to be used for debug logging.
-
#name ⇒ String?
The port to modify the configuration for.,The list of choices is not necessarily comprehensive.
-
#ntp_address ⇒ String?
Primary IPv4 NTP server address.
-
#ntp_address_backup ⇒ String?
Backup IPv4 NTP server address,Queried when primary NTP server fails.
-
#ntp_config_method ⇒ :disable, ...
The configuration method type to use for NTP services.,disable is mutually exclusive with I(ntp_address) and I(ntp_address_backup).,dhcp is mutually exclusive with I(ntp_address) and I(ntp_address_backup).
-
#ssh ⇒ Symbol?
Enable ssh access to the controller for debug purposes.,This is a controller-level setting.,rlogin/telnet will be enabled for ancient equipment where ssh is not available.
-
#state ⇒ :enable, ...
Enable or disable IPv4 network interface configuration.,Either IPv4 or IPv6 must be enabled otherwise error will occur.,Only required when enabling or disabling IPv4 network interface.
-
#subnet_mask ⇒ String?
The subnet mask to utilize for the interface.,Should be specified in xx.xx.xx.xx form.,Mutually exclusive with I(config_method=dhcp).
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#address ⇒ String?
27 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 27 attribute :address |
#channel ⇒ Object?
24 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 24 attribute :channel |
#config_method ⇒ :dhcp, ...
39 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 39 attribute :config_method |
#controller ⇒ :A, :B
16 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 16 attribute :controller |
#dns_address ⇒ String?
47 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 47 attribute :dns_address |
#dns_address_backup ⇒ String?
51 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 51 attribute :dns_address_backup |
#dns_config_method ⇒ :dhcp, ...
43 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 43 attribute :dns_config_method |
#gateway ⇒ String?
35 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 35 attribute :gateway |
#log_path ⇒ Object?
71 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 71 attribute :log_path |
#name ⇒ String?
20 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 20 attribute :name |
#ntp_address ⇒ String?
59 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 59 attribute :ntp_address |
#ntp_address_backup ⇒ String?
63 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 63 attribute :ntp_address_backup |
#ntp_config_method ⇒ :disable, ...
55 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 55 attribute :ntp_config_method |
#ssh ⇒ Symbol?
67 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 67 attribute :ssh |
#state ⇒ :enable, ...
12 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 12 attribute :state |
#subnet_mask ⇒ String?
31 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_mgmt_interface.rb', line 31 attribute :subnet_mask |