Class: Ansible::Ruby::Modules::Netscaler

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/citrix/netscaler.rb

Overview

Manages Citrix NetScaler server and service entities.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#action ⇒ :disable, ...

Returns The action you want to perform on the entity.

Returns:

  • (:disable, :enable, nil) —

    The action you want to perform on the entity.



28
# File 'lib/ansible/ruby/modules/generated/network/citrix/netscaler.rb', line 28

attribute :action

#name ⇒ String

Returns Name of the entity.

Returns:

  • (String) —

    Name of the entity.



32
# File 'lib/ansible/ruby/modules/generated/network/citrix/netscaler.rb', line 32

attribute :name

#nsc_host ⇒ String

Returns Hostname or ip of your netscaler.

Returns:

  • (String) —

    Hostname or ip of your netscaler.



12
# File 'lib/ansible/ruby/modules/generated/network/citrix/netscaler.rb', line 12

attribute :nsc_host

#nsc_protocol ⇒ String?

Returns Protocol used to access netscaler.

Returns:

  • (String, nil) —

    Protocol used to access netscaler.



16
# File 'lib/ansible/ruby/modules/generated/network/citrix/netscaler.rb', line 16

attribute :nsc_protocol

#password ⇒ String

Returns Password.

Returns:

  • (String) —

    Password.



24
# File 'lib/ansible/ruby/modules/generated/network/citrix/netscaler.rb', line 24

attribute :password

#type ⇒ :server, ...

Returns Type of the entity.

Returns:

  • (:server, :service, nil) —

    Type of the entity.



36
# File 'lib/ansible/ruby/modules/generated/network/citrix/netscaler.rb', line 36

attribute :type

#user ⇒ String

Returns Username.

Returns:

  • (String) —

    Username.



20
# File 'lib/ansible/ruby/modules/generated/network/citrix/netscaler.rb', line 20

attribute :user

#validate_certs ⇒ :yes, ...

Returns If C(no), SSL certificates for the target url will not be validated.,This should only be used on personally controlled sites using self-signed certificates.

Returns:

  • (:yes, :no, nil) —

    If C(no), SSL certificates for the target url will not be validated.,This should only be used on personally controlled sites using self-signed certificates.



40
# File 'lib/ansible/ruby/modules/generated/network/citrix/netscaler.rb', line 40

attribute :validate_certs