Class: Ansible::Ruby::Modules::Nios_network
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Nios_network
- Defined in:
- lib/ansible/ruby/modules/generated/net_tools/nios/nios_network.rb
Overview
Adds and/or removes instances of network objects from Infoblox NIOS servers. This module manages NIOS C(network) objects using the Infoblox WAPI interface over REST. Supports both IPV4 and IPV6 internet protocols
Instance Method Summary collapse
-
#comment ⇒ String?
Configures a text string comment to be associated with the instance of this object.
-
#extattrs ⇒ Object?
Allows for the configuration of Extensible Attributes on the instance of the object.
-
#network ⇒ String
Specifies the network to add or remove from the system.
-
#network_view ⇒ String
Configures the name of the network view to associate with this configured instance.
-
#options ⇒ Array<Hash>, ...
Configures the set of DHCP options to be included as part of the configured network instance.
-
#state ⇒ :present, ...
Configures the intended state of the instance of the object on the NIOS server.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#comment ⇒ String?
28 |
# File 'lib/ansible/ruby/modules/generated/net_tools/nios/nios_network.rb', line 28 attribute :comment |
#extattrs ⇒ Object?
25 |
# File 'lib/ansible/ruby/modules/generated/net_tools/nios/nios_network.rb', line 25 attribute :extattrs |
#network ⇒ String
13 |
# File 'lib/ansible/ruby/modules/generated/net_tools/nios/nios_network.rb', line 13 attribute :network |
#network_view ⇒ String
17 |
# File 'lib/ansible/ruby/modules/generated/net_tools/nios/nios_network.rb', line 17 attribute :network_view |
#options ⇒ Array<Hash>, ...
21 |
# File 'lib/ansible/ruby/modules/generated/net_tools/nios/nios_network.rb', line 21 attribute :options |
#state ⇒ :present, ...
32 |
# File 'lib/ansible/ruby/modules/generated/net_tools/nios/nios_network.rb', line 32 attribute :state |