Class: Ansible::Ruby::Modules::Nso_action

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/nso/nso_action.rb

Overview

This module provices support for executing Cisco NSO actions and then verifying that the output is as expected.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#input ⇒ Object?

Returns NSO action parameters.\r\n.

Returns:

  • (Object, nil) —

    NSO action parameters.\r\n



16
# File 'lib/ansible/ruby/modules/generated/network/nso/nso_action.rb', line 16

attribute :input

#output_invalid ⇒ Object?

Returns List of result parameter names that will cause the task to fail if they are present.\r\n.

Returns:

  • (Object, nil) —

    List of result parameter names that will cause the task to fail if they are present.\r\n



23
# File 'lib/ansible/ruby/modules/generated/network/nso/nso_action.rb', line 23

attribute :output_invalid

#output_required ⇒ Hash?

Returns Required output parameters.\r\n.

Returns:

  • (Hash, nil) —

    Required output parameters.\r\n



19
# File 'lib/ansible/ruby/modules/generated/network/nso/nso_action.rb', line 19

attribute :output_required

#path ⇒ String

Returns Path to NSO action.

Returns:

  • (String) —

    Path to NSO action.



12
# File 'lib/ansible/ruby/modules/generated/network/nso/nso_action.rb', line 12

attribute :path

#validate_strict ⇒ Object?

Returns If set to true, the task will fail if any output parameters not in output_required is present in the output.\r\n.

Returns:

  • (Object, nil) —

    If set to true, the task will fail if any output parameters not in output_required is present in the output.\r\n



26
# File 'lib/ansible/ruby/modules/generated/network/nso/nso_action.rb', line 26

attribute :validate_strict