Class: Ansible::Ruby::Modules::Nsupdate

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb

Overview

Create, update and remove DNS records using DDNS updates DDNS works well with both bind and Microsoft DNS (see https://technet.microsoft.com/en-us/library/cc961412.aspx)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#key_algorithm ⇒ :"HMAC-MD5.SIG-ALG.REG.INT", ...

Returns Specify key algorithm used by C(key_secret).

Returns:

  • (:"HMAC-MD5.SIG-ALG.REG.INT", :"hmac-md5", :"hmac-sha1", :"hmac-sha224", :"hmac-sha256", :"hmac-sha384", :"hmac-sha512", nil) —

    Specify key algorithm used by C(key_secret).



33
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 33

attribute :key_algorithm

#key_name ⇒ String?

Returns Use TSIG key name to authenticate against DNS C(server).

Returns:

  • (String, nil) —

    Use TSIG key name to authenticate against DNS C(server)



25
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 25

attribute :key_name

#key_secret ⇒ String?

Returns Use TSIG key secret, associated with C(key_name), to authenticate against C(server).

Returns:

  • (String, nil) —

    Use TSIG key secret, associated with C(key_name), to authenticate against C(server)



29
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 29

attribute :key_secret

#port ⇒ Integer?

Returns Use this TCP port when connecting to C(server).

Returns:

  • (Integer, nil) —

    Use this TCP port when connecting to C(server).



21
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 21

attribute :port

#record ⇒ String

Returns Sets the DNS record to modify. When zone is omitted this has to be absolute (ending with a dot).

Returns:

  • (String) —

    Sets the DNS record to modify. When zone is omitted this has to be absolute (ending with a dot).



41
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 41

attribute :record

#server ⇒ String

Returns Apply DNS modification on this server.

Returns:

  • (String) —

    Apply DNS modification on this server.



17
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 17

attribute :server

#state ⇒ :present, ...

Returns Manage DNS record.

Returns:

  • (:present, :absent, nil) —

    Manage DNS record.



13
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 13

attribute :state

#ttl ⇒ Integer?

Returns Sets the record TTL.

Returns:

  • (Integer, nil) —

    Sets the record TTL.



49
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 49

attribute :ttl

#type ⇒ String?

Returns Sets the record type.

Returns:

  • (String, nil) —

    Sets the record type.



45
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 45

attribute :type

#value ⇒ Array<String>, ...

Returns Sets the record value.

Returns:

  • (Array<String>, String, nil) —

    Sets the record value.



53
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 53

attribute :value

#zone ⇒ String?

Returns DNS record will be modified on this C(zone).,When omitted DNS will be queried to attempt finding the correct zone.,Starting with Ansible 2.7 this parameter is optional.

Returns:

  • (String, nil) —

    DNS record will be modified on this C(zone).,When omitted DNS will be queried to attempt finding the correct zone.,Starting with Ansible 2.7 this parameter is optional.



37
# File 'lib/ansible/ruby/modules/generated/net_tools/nsupdate.rb', line 37

attribute :zone