Class: Ansible::Ruby::Modules::Nxos_acl

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb

Overview

Manages access list entries for ACLs.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#ack ⇒ :enable?

Returns Match on the ACK bit.

Returns:

  • (:enable, nil) —

    Match on the ACK bit.



67
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 67

attribute :ack

#action ⇒ :permit, ...

Returns Action of the ACE.

Returns:

  • (:permit, :deny, :remark, nil) —

    Action of the ACE.



20
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 20

attribute :action

#dest ⇒ String?

Returns Destination ip and mask using IP/MASK notation and supports the keyword 'any'.

Returns:

  • (String, nil) —

    Destination ip and mask using IP/MASK notation and supports the keyword 'any'.



45
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 45

attribute :dest

#dest_port1 ⇒ Object?

Returns Port/protocol and also first (lower) port when using range operand.

Returns:

  • (Object, nil) —

    Port/protocol and also first (lower) port when using range operand.



53
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 53

attribute :dest_port1

#dest_port2 ⇒ Object?

Returns Second (end) port when using range operand.

Returns:

  • (Object, nil) —

    Second (end) port when using range operand.



56
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 56

attribute :dest_port2

#dest_port_op ⇒ :any, ...

Returns Destination port operands such as eq, neq, gt, lt, range.

Returns:

  • (:any, :eq, :gt, :lt, :neq, :range, nil) —

    Destination port operands such as eq, neq, gt, lt, range.



49
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 49

attribute :dest_port_op

#dscp ⇒ :af11, ...

Returns Match packets with given dscp value.

Returns:

  • (:af11, :af12, :af13, :af21, :af22, :af23, :af31, :af32, :af33, :af41, :af42, :af43, :cs1, :cs2, :cs3, :cs4, :cs5, :cs6, :cs7, :default, :ef, nil) —

    Match packets with given dscp value.



102
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 102

attribute :dscp

#established ⇒ :enable?

Returns Match established connections.

Returns:

  • (:enable, nil) —

    Match established connections.



87
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 87

attribute :established

#fin ⇒ :enable?

Returns Match on the FIN bit.

Returns:

  • (:enable, nil) —

    Match on the FIN bit.



83
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 83

attribute :fin

#fragments ⇒ :enable?

Returns Check non-initial fragments.

Returns:

  • (:enable, nil) —

    Check non-initial fragments.



91
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 91

attribute :fragments

#log ⇒ :enable?

Returns Log matches against this entry.

Returns:

  • (:enable, nil) —

    Log matches against this entry.



59
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 59

attribute :log

#name ⇒ String

Returns Case sensitive name of the access list (ACL).

Returns:

  • (String) —

    Case sensitive name of the access list (ACL).



16
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 16

attribute :name

#precedence ⇒ :critical, ...

Returns Match packets with given precedence.

Returns:

  • (:critical, :flash, :"flash-override", :immediate, :internet, :network, :priority, :routine, nil) —

    Match packets with given precedence.



98
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 98

attribute :precedence

#proto ⇒ String?

Returns Port number or protocol (as supported by the switch).

Returns:

  • (String, nil) —

    Port number or protocol (as supported by the switch).



27
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 27

attribute :proto

#psh ⇒ :enable?

Returns Match on the PSH bit.

Returns:

  • (:enable, nil) —

    Match on the PSH bit.



71
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 71

attribute :psh

#remark ⇒ Object?

Returns If action is set to remark, this is the description.

Returns:

  • (Object, nil) —

    If action is set to remark, this is the description.



24
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 24

attribute :remark

#rst ⇒ :enable?

Returns Match on the RST bit.

Returns:

  • (:enable, nil) —

    Match on the RST bit.



75
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 75

attribute :rst

#seq ⇒ Integer?

Returns Sequence number of the entry (ACE).

Returns:

  • (Integer, nil) —

    Sequence number of the entry (ACE).



12
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 12

attribute :seq

#src ⇒ String?

Returns Source ip and mask using IP/MASK notation and supports keyword 'any'.

Returns:

  • (String, nil) —

    Source ip and mask using IP/MASK notation and supports keyword 'any'.



31
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 31

attribute :src

#src_port1 ⇒ Object?

Returns Port/protocol and also first (lower) port when using range operand.

Returns:

  • (Object, nil) —

    Port/protocol and also first (lower) port when using range operand.



39
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 39

attribute :src_port1

#src_port2 ⇒ Object?

Returns Second (end) port when using range operand.

Returns:

  • (Object, nil) —

    Second (end) port when using range operand.



42
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 42

attribute :src_port2

#src_port_op ⇒ :any, ...

Returns Source port operands such as eq, neq, gt, lt, range.

Returns:

  • (:any, :eq, :gt, :lt, :neq, :range, nil) —

    Source port operands such as eq, neq, gt, lt, range.



35
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 35

attribute :src_port_op

#state ⇒ :present, ...

Returns Specify desired state of the resource.

Returns:

  • (:present, :absent, :delete_acl, nil) —

    Specify desired state of the resource.



106
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 106

attribute :state

#syn ⇒ :enable?

Returns Match on the SYN bit.

Returns:

  • (:enable, nil) —

    Match on the SYN bit.



79
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 79

attribute :syn

#time_range ⇒ Object?

Returns Name of time-range to apply.

Returns:

  • (Object, nil) —

    Name of time-range to apply.



95
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 95

attribute :time_range

#urg ⇒ :enable?

Returns Match on the URG bit.

Returns:

  • (:enable, nil) —

    Match on the URG bit.



63
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_acl.rb', line 63

attribute :urg