Class: Ansible::Ruby::Modules::Nxos_vxlan_vtep_vni

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/nxos/nxos_vxlan_vtep_vni.rb

Overview

Creates a Virtual Network Identifier member (VNI) for an NVE overlay interface.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#assoc_vrf ⇒ Symbol?

Returns This attribute is used to identify and separate processing VNIs that are associated with a VRF and used for routing. The VRF and VNI specified with this command must match the configuration of the VNI under the VRF.

Returns:

  • (Symbol, nil) —

    This attribute is used to identify and separate processing VNIs that are associated with a VRF and used for routing. The VRF and VNI specified with this command must match the configuration of the VNI under the VRF.



20
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_vxlan_vtep_vni.rb', line 20

attribute :assoc_vrf

#ingress_replication ⇒ :bgp, ...

Returns Specifies mechanism for host reachability advertisement.

Returns:

  • (:bgp, :static, :default, nil) —

    Specifies mechanism for host reachability advertisement.



24
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_vxlan_vtep_vni.rb', line 24

attribute :ingress_replication

#interface ⇒ String

Returns Interface name for the VXLAN Network Virtualization Endpoint.

Returns:

  • (String) —

    Interface name for the VXLAN Network Virtualization Endpoint.



12
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_vxlan_vtep_vni.rb', line 12

attribute :interface

#multicast_group ⇒ Object?

Returns The multicast group (range) of the VNI. Valid values are string and keyword 'default'.

Returns:

  • (Object, nil) —

    The multicast group (range) of the VNI. Valid values are string and keyword 'default'.



28
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_vxlan_vtep_vni.rb', line 28

attribute :multicast_group

#peer_list ⇒ Object?

Returns Set the ingress-replication static peer list. Valid values are an array, a space-separated string of ip addresses, or the keyword 'default'.

Returns:

  • (Object, nil) —

    Set the ingress-replication static peer list. Valid values are an array, a space-separated string of ip addresses, or the keyword 'default'.



31
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_vxlan_vtep_vni.rb', line 31

attribute :peer_list

#state ⇒ :present, ...

Returns Determines whether the config should be present or not on the device.

Returns:

  • (:present, :absent, nil) —

    Determines whether the config should be present or not on the device.



38
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_vxlan_vtep_vni.rb', line 38

attribute :state

#suppress_arp ⇒ Symbol?

Returns Suppress arp under layer 2 VNI.

Returns:

  • (Symbol, nil) —

    Suppress arp under layer 2 VNI.



34
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_vxlan_vtep_vni.rb', line 34

attribute :suppress_arp

#vni ⇒ Integer

Returns ID of the Virtual Network Identifier.

Returns:

  • (Integer) —

    ID of the Virtual Network Identifier.



16
# File 'lib/ansible/ruby/modules/generated/network/nxos/nxos_vxlan_vtep_vni.rb', line 16

attribute :vni