Class: Ansible::Ruby::Modules::Openssl_pkcs12

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb

Overview

This module allows one to (re-)generate PKCS#12.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#action ⇒ :parse, ...

Returns C(export) or C(parse) a PKCS#12.

Returns:

  • (:parse, :export, nil) —

    C(export) or C(parse) a PKCS#12.



12
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 12

attribute :action

#ca_certificates ⇒ String?

Returns List of CA certificate to include.

Returns:

  • (String, nil) —

    List of CA certificate to include.



16
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 16

attribute :ca_certificates

#certificate_path ⇒ String?

Returns The path to read certificates and private keys from. Must be in PEM format.

Returns:

  • (String, nil) —

    The path to read certificates and private keys from. Must be in PEM format.



20
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 20

attribute :certificate_path

#force ⇒ Symbol?

Returns Should the file be regenerated even if it already exists.

Returns:

  • (Symbol, nil) —

    Should the file be regenerated even if it already exists.



24
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 24

attribute :force

#friendly_name ⇒ String?

Returns Specifies the friendly name for the certificate and private key.

Returns:

  • (String, nil) —

    Specifies the friendly name for the certificate and private key.



28
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 28

attribute :friendly_name

#iter_size ⇒ Integer?

Returns Number of times to repeat the encryption step.

Returns:

  • (Integer, nil) —

    Number of times to repeat the encryption step.



32
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 32

attribute :iter_size

#maciter_size ⇒ Integer?

Returns Number of times to repeat the MAC step.

Returns:

  • (Integer, nil) —

    Number of times to repeat the MAC step.



36
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 36

attribute :maciter_size

#passphrase ⇒ Object?

Returns The PKCS#12 password.

Returns:

  • (Object, nil) —

    The PKCS#12 password.



40
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 40

attribute :passphrase

#path ⇒ String

Returns Filename to write the PKCS#12 file to.

Returns:

  • (String) —

    Filename to write the PKCS#12 file to.



43
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 43

attribute :path

#privatekey_passphrase ⇒ Object?

Returns Passphrase source to decrypt any input private keys with.

Returns:

  • (Object, nil) —

    Passphrase source to decrypt any input private keys with.



47
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 47

attribute :privatekey_passphrase

#privatekey_path ⇒ String?

Returns File to read private key from.

Returns:

  • (String, nil) —

    File to read private key from.



50
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 50

attribute :privatekey_path

#src ⇒ String?

Returns PKCS#12 file path to parse.

Returns:

  • (String, nil) —

    PKCS#12 file path to parse.



58
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 58

attribute :src

#state ⇒ :present, ...

Returns Whether the file should exist or not. All parameters except C(path) are ignored when state is C(absent).

Returns:

  • (:present, :absent, nil) —

    Whether the file should exist or not. All parameters except C(path) are ignored when state is C(absent).



54
# File 'lib/ansible/ruby/modules/generated/crypto/openssl_pkcs12.rb', line 54

attribute :state