Class: Ansible::Ruby::Modules::Os_image

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb

Overview

Add or Remove images from the OpenStack Image Repository

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#availability_zone ⇒ Object?

Returns Ignored. Present for backwards compatibility.

Returns:

  • (Object, nil) —

    Ignored. Present for backwards compatibility



62
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 62

attribute :availability_zone

#checksum ⇒ Object?

Returns The checksum of the image.

Returns:

  • (Object, nil) —

    The checksum of the image



19
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 19

attribute :checksum

#container_format ⇒ String?

Returns The format of the container.

Returns:

  • (String, nil) —

    The format of the container



26
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 26

attribute :container_format

#disk_format ⇒ String?

Returns The format of the disk that is getting uploaded.

Returns:

  • (String, nil) —

    The format of the disk that is getting uploaded



22
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 22

attribute :disk_format

#filename ⇒ String?

Returns The path to the file which has to be uploaded.

Returns:

  • (String, nil) —

    The path to the file which has to be uploaded



43
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 43

attribute :filename

#id ⇒ Object?

Returns The Id of the image.

Returns:

  • (Object, nil) —

    The Id of the image



16
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 16

attribute :id

#is_public ⇒ :yes, ...

Returns Whether the image can be accessed publicly. Note that publicizing an image requires admin role by default.

Returns:

  • (:yes, :no, nil) —

    Whether the image can be accessed publicly. Note that publicizing an image requires admin role by default.



39
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 39

attribute :is_public

#kernel ⇒ String?

Returns The name of an existing kernel image that will be associated with this image.

Returns:

  • (String, nil) —

    The name of an existing kernel image that will be associated with this image



51
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 51

attribute :kernel

#min_disk ⇒ Object?

Returns The minimum disk space (in GB) required to boot this image.

Returns:

  • (Object, nil) —

    The minimum disk space (in GB) required to boot this image



33
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 33

attribute :min_disk

#min_ram ⇒ Object?

Returns The minimum ram (in MB) required to boot this image.

Returns:

  • (Object, nil) —

    The minimum ram (in MB) required to boot this image



36
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 36

attribute :min_ram

#name ⇒ String

Returns Name that has to be given to the image.

Returns:

  • (String) —

    Name that has to be given to the image



12
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 12

attribute :name

#owner ⇒ Object?

Returns The owner of the image.

Returns:

  • (Object, nil) —

    The owner of the image



30
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 30

attribute :owner

#properties ⇒ Object?

Returns Additional properties to be associated with this image.

Returns:

  • (Object, nil) —

    Additional properties to be associated with this image



55
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 55

attribute :properties

#ramdisk ⇒ String?

Returns The name of an existing ramdisk image that will be associated with this image.

Returns:

  • (String, nil) —

    The name of an existing ramdisk image that will be associated with this image



47
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 47

attribute :ramdisk

#state ⇒ :present, ...

Returns Should the resource be present or absent.

Returns:

  • (:present, :absent, nil) —

    Should the resource be present or absent.



58
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_image.rb', line 58

attribute :state