Class: Ansible::Ruby::Modules::Os_loadbalancer

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb

Overview

Add or Remove load balancer from the OpenStack load-balancer service.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#availability_zone ⇒ Object?

Returns Ignored. Present for backwards compatibility.

Returns:

  • (Object, nil) —

    Ignored. Present for backwards compatibility



43
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb', line 43

attribute :availability_zone

#name ⇒ String

Returns Name that has to be given to the load balancer.

Returns:

  • (String) —

    Name that has to be given to the load balancer



12
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb', line 12

attribute :name

#state ⇒ :present, ...

Returns Should the resource be present or absent.

Returns:

  • (:present, :absent, nil) —

    Should the resource be present or absent.



16
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb', line 16

attribute :state

#timeout ⇒ Integer?

Returns The amount of time the module should wait for the load balancer to get into ACTIVE state.

Returns:

  • (Integer, nil) —

    The amount of time the module should wait for the load balancer to get into ACTIVE state.



39
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb', line 39

attribute :timeout

#vip_address ⇒ String?

Returns IP address of the load balancer virtual IP.

Returns:

  • (String, nil) —

    IP address of the load balancer virtual IP.



31
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb', line 31

attribute :vip_address

#vip_network ⇒ String?

Returns The name or id of the network for the virtual IP of the load balancer. One of vip_network, vip_subnet, or vip_port must be specified.

Returns:

  • (String, nil) —

    The name or id of the network for the virtual IP of the load balancer. One of vip_network, vip_subnet, or vip_port must be specified.



20
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb', line 20

attribute :vip_network

#vip_port ⇒ Object?

Returns The name or id of the load balancer virtual IP port. One of vip_network, vip_subnet, or vip_port must be specified.

Returns:

  • (Object, nil) —

    The name or id of the load balancer virtual IP port. One of vip_network, vip_subnet, or vip_port must be specified.



28
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb', line 28

attribute :vip_port

#vip_subnet ⇒ String?

Returns The name or id of the subnet for the virtual IP of the load balancer. One of vip_network, vip_subnet, or vip_port must be specified.

Returns:

  • (String, nil) —

    The name or id of the subnet for the virtual IP of the load balancer. One of vip_network, vip_subnet, or vip_port must be specified.



24
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb', line 24

attribute :vip_subnet

#wait ⇒ :yes, ...

Returns If the module should wait for the load balancer to be created.

Returns:

  • (:yes, :no, nil) —

    If the module should wait for the load balancer to be created.



35
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_loadbalancer.rb', line 35

attribute :wait