Class: Ansible::Ruby::Modules::Os_quota

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb

Overview

Manage OpenStack Quotas. Quotas can be created, updated or deleted using this module. A quota will be updated if matches an existing project and is present.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#availability_zone ⇒ Object?

Returns Ignored. Present for backwards compatibility.

Returns:

  • (Object, nil) —

    Ignored. Present for backwards compatibility



140
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 140

attribute :availability_zone

#backup_gigabytes ⇒ String?

Returns Maximum size of backups in GB's.

Returns:

  • (String, nil) —

    Maximum size of backups in GB's.



20
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 20

attribute :backup_gigabytes

#backups ⇒ String?

Returns Maximum number of backups allowed.

Returns:

  • (String, nil) —

    Maximum number of backups allowed.



24
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 24

attribute :backups

#cores ⇒ Integer, ...

Returns Maximum number of CPU's per project.

Returns:

  • (Integer, String, nil) —

    Maximum number of CPU's per project.



28
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 28

attribute :cores

#fixed_ips ⇒ String?

Returns Number of fixed IP's to allow.

Returns:

  • (String, nil) —

    Number of fixed IP's to allow.



32
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 32

attribute :fixed_ips

#floating_ips ⇒ String?

Returns Number of floating IP's to allow in Compute.

Returns:

  • (String, nil) —

    Number of floating IP's to allow in Compute.



36
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 36

attribute :floating_ips

#floatingip ⇒ String?

Returns Number of floating IP's to allow in Network.

Returns:

  • (String, nil) —

    Number of floating IP's to allow in Network.



40
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 40

attribute :floatingip

#gigabytes ⇒ String?

Returns Maximum volume storage allowed for project.

Returns:

  • (String, nil) —

    Maximum volume storage allowed for project.



44
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 44

attribute :gigabytes

#gigabytes_lvm ⇒ Object?

Returns Maximum size in GB's of individual lvm volumes.

Returns:

  • (Object, nil) —

    Maximum size in GB's of individual lvm volumes.



48
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 48

attribute :gigabytes_lvm

#injected_file_size ⇒ String?

Returns Maximum file size in bytes.

Returns:

  • (String, nil) —

    Maximum file size in bytes.



51
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 51

attribute :injected_file_size

#injected_files ⇒ String?

Returns Number of injected files to allow.

Returns:

  • (String, nil) —

    Number of injected files to allow.



55
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 55

attribute :injected_files

#injected_path_size ⇒ String?

Returns Maximum path size.

Returns:

  • (String, nil) —

    Maximum path size.



59
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 59

attribute :injected_path_size

#instances ⇒ String?

Returns Maximum number of instances allowed.

Returns:

  • (String, nil) —

    Maximum number of instances allowed.



63
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 63

attribute :instances

#key_pairs ⇒ String?

Returns Number of key pairs to allow.

Returns:

  • (String, nil) —

    Number of key pairs to allow.



67
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 67

attribute :key_pairs

#loadbalancer ⇒ String?

Returns Number of load balancers to allow.

Returns:

  • (String, nil) —

    Number of load balancers to allow.



71
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 71

attribute :loadbalancer

#name ⇒ String

Returns Name of the OpenStack Project to manage.

Returns:

  • (String) —

    Name of the OpenStack Project to manage.



12
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 12

attribute :name

#network ⇒ Object?

Returns Number of networks to allow.

Returns:

  • (Object, nil) —

    Number of networks to allow.



75
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 75

attribute :network

#per_volume_gigabytes ⇒ String?

Returns Maximum size in GB's of individual volumes.

Returns:

  • (String, nil) —

    Maximum size in GB's of individual volumes.



78
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 78

attribute :per_volume_gigabytes

#pool ⇒ String?

Returns Number of load balancer pools to allow.

Returns:

  • (String, nil) —

    Number of load balancer pools to allow.



82
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 82

attribute :pool

#port ⇒ String?

Returns Number of Network ports to allow, this needs to be greater than the instances limit.

Returns:

  • (String, nil) —

    Number of Network ports to allow, this needs to be greater than the instances limit.



86
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 86

attribute :port

#properties ⇒ String?

Returns Number of properties to allow.

Returns:

  • (String, nil) —

    Number of properties to allow.



90
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 90

attribute :properties

#ram ⇒ String?

Returns Maximum amount of ram in MB to allow.

Returns:

  • (String, nil) —

    Maximum amount of ram in MB to allow.



94
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 94

attribute :ram

#rbac_policy ⇒ Object?

Returns Number of policies to allow.

Returns:

  • (Object, nil) —

    Number of policies to allow.



98
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 98

attribute :rbac_policy

#router ⇒ Object?

Returns Number of routers to allow.

Returns:

  • (Object, nil) —

    Number of routers to allow.



101
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 101

attribute :router

#security_group ⇒ String?

Returns Number of security groups to allow.

Returns:

  • (String, nil) —

    Number of security groups to allow.



108
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 108

attribute :security_group

#security_group_rule ⇒ String?

Returns Number of rules per security group to allow.

Returns:

  • (String, nil) —

    Number of rules per security group to allow.



104
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 104

attribute :security_group_rule

#server_group_members ⇒ String?

Returns Number of server group members to allow.

Returns:

  • (String, nil) —

    Number of server group members to allow.



112
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 112

attribute :server_group_members

#server_groups ⇒ String?

Returns Number of server groups to allow.

Returns:

  • (String, nil) —

    Number of server groups to allow.



116
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 116

attribute :server_groups

#snapshots ⇒ String?

Returns Number of snapshots to allow.

Returns:

  • (String, nil) —

    Number of snapshots to allow.



120
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 120

attribute :snapshots

#snapshots_lvm ⇒ Object?

Returns Number of LVM snapshots to allow.

Returns:

  • (Object, nil) —

    Number of LVM snapshots to allow.



124
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 124

attribute :snapshots_lvm

#state ⇒ String?

Returns A value of present sets the quota and a value of absent resets the quota to system defaults.

Returns:

  • (String, nil) —

    A value of present sets the quota and a value of absent resets the quota to system defaults.



16
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 16

attribute :state

#subnet ⇒ Object?

Returns Number of subnets to allow.

Returns:

  • (Object, nil) —

    Number of subnets to allow.



127
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 127

attribute :subnet

#subnetpool ⇒ Object?

Returns Number of subnet pools to allow.

Returns:

  • (Object, nil) —

    Number of subnet pools to allow.



130
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 130

attribute :subnetpool

#volumes ⇒ Integer, ...

Returns Number of volumes to allow.

Returns:

  • (Integer, String, nil) —

    Number of volumes to allow.



133
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 133

attribute :volumes

#volumes_lvm ⇒ Object?

Returns Number of LVM volumes to allow.

Returns:

  • (Object, nil) —

    Number of LVM volumes to allow.



137
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_quota.rb', line 137

attribute :volumes_lvm