Class: Ansible::Ruby::Modules::Os_subnet

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb

Overview

Add or Remove a subnet to an OpenStack network

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#allocation_pool_end ⇒ Object?

Returns From the subnet pool the last IP that should be assigned to the virtual machines.

Returns:

  • (Object, nil) —

    From the subnet pool the last IP that should be assigned to the virtual machines.



50
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 50

attribute :allocation_pool_end

#allocation_pool_start ⇒ Object?

Returns From the subnet pool the starting address from which the IP should be allocated.

Returns:

  • (Object, nil) —

    From the subnet pool the starting address from which the IP should be allocated.



47
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 47

attribute :allocation_pool_start

#availability_zone ⇒ Object?

Returns Ignored. Present for backwards compatibility.

Returns:

  • (Object, nil) —

    Ignored. Present for backwards compatibility



72
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 72

attribute :availability_zone

#cidr ⇒ String?

Returns The CIDR representation of the subnet that should be assigned to the subnet. Required when I(state) is 'present' and a subnetpool is not specified.

Returns:

  • (String, nil) —

    The CIDR representation of the subnet that should be assigned to the subnet. Required when I(state) is 'present' and a subnetpool is not specified.



24
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 24

attribute :cidr

#dns_nameservers ⇒ Array<String>, ...

Returns List of DNS nameservers for this subnet.

Returns:

  • (Array<String>, String, nil) —

    List of DNS nameservers for this subnet.



43
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 43

attribute :dns_nameservers

#enable_dhcp ⇒ :yes, ...

Returns Whether DHCP should be enabled for this subnet.

Returns:

  • (:yes, :no, nil) —

    Whether DHCP should be enabled for this subnet.



32
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 32

attribute :enable_dhcp

#extra_specs ⇒ Object?

Returns Dictionary with extra key/value pairs passed to the API.

Returns:

  • (Object, nil) —

    Dictionary with extra key/value pairs passed to the API



75
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 75

attribute :extra_specs

#gateway_ip ⇒ Object?

Returns The ip that would be assigned to the gateway for this subnet.

Returns:

  • (Object, nil) —

    The ip that would be assigned to the gateway for this subnet



36
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 36

attribute :gateway_ip

#host_routes ⇒ Array<Hash>, ...

Returns A list of host route dictionaries for the subnet.

Returns:

  • (Array<Hash>, Hash, nil) —

    A list of host route dictionaries for the subnet.



53
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 53

attribute :host_routes

#ip_version ⇒ Integer?

Returns The IP version of the subnet 4 or 6.

Returns:

  • (Integer, nil) —

    The IP version of the subnet 4 or 6



28
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 28

attribute :ip_version

#ipv6_address_mode ⇒ :"dhcpv6-stateful", ...

Returns IPv6 address mode.

Returns:

  • (:"dhcpv6-stateful", :"dhcpv6-stateless", :slaac, nil) —

    IPv6 address mode



61
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 61

attribute :ipv6_address_mode

#ipv6_ra_mode ⇒ :"dhcpv6-stateful", ...

Returns IPv6 router advertisement mode.

Returns:

  • (:"dhcpv6-stateful", :"dhcpv6-stateless", :slaac, nil) —

    IPv6 router advertisement mode



57
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 57

attribute :ipv6_ra_mode

#name ⇒ String

Returns The name of the subnet that should be created. Although Neutron allows for non-unique subnet names, this module enforces subnet name uniqueness.

Returns:

  • (String) —

    The name of the subnet that should be created. Although Neutron allows for non-unique subnet names, this module enforces subnet name uniqueness.



20
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 20

attribute :name

#network_name ⇒ String?

Returns Name of the network to which the subnet should be attached,Required when I(state) is 'present'.

Returns:

  • (String, nil) —

    Name of the network to which the subnet should be attached,Required when I(state) is 'present'



16
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 16

attribute :network_name

#no_gateway_ip ⇒ :yes, ...

Returns The gateway IP would not be assigned for this subnet.

Returns:

  • (:yes, :no, nil) —

    The gateway IP would not be assigned for this subnet



39
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 39

attribute :no_gateway_ip

#project ⇒ Object?

Returns Project name or ID containing the subnet (name admin-only).

Returns:

  • (Object, nil) —

    Project name or ID containing the subnet (name admin-only)



69
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 69

attribute :project

#state ⇒ :present, ...

Returns Indicate desired state of the resource.

Returns:

  • (:present, :absent, nil) —

    Indicate desired state of the resource



12
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 12

attribute :state

#use_default_subnetpool ⇒ :yes, ...

Returns Use the default subnetpool for I(ip_version) to obtain a CIDR.

Returns:

  • (:yes, :no, nil) —

    Use the default subnetpool for I(ip_version) to obtain a CIDR.



65
# File 'lib/ansible/ruby/modules/generated/cloud/openstack/os_subnet.rb', line 65

attribute :use_default_subnetpool