Class: Ansible::Ruby::Modules::Ovirt

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb

Overview

This module only supports oVirt/RHEV version 3. A newer module M(ovirt_vms) supports oVirt/RHV version 4. Allows you to create new instances, either from scratch or an image, in addition to deleting or stopping instances on the oVirt/RHEV platform.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#disk_alloc ⇒ :preallocated, ...

Returns Define whether disk is thin or preallocated.

Returns:

  • (:preallocated, :thin, nil) —

    Define whether disk is thin or preallocated.



65
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 65

attribute :disk_alloc

#disk_int ⇒ :ide, ...

Returns Interface type of the disk.

Returns:

  • (:ide, :virtio, nil) —

    Interface type of the disk.



69
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 69

attribute :disk_int

#image ⇒ String?

Returns The template to use for the instance.

Returns:

  • (String, nil) —

    The template to use for the instance.



29
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 29

attribute :image

#instance_cores ⇒ Integer?

Returns Define the instance's number of cores.

Returns:

  • (Integer, nil) —

    Define the instance's number of cores.



77
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 77

attribute :instance_cores

#instance_cpus ⇒ Integer?

Returns The instance's number of CPUs.

Returns:

  • (Integer, nil) —

    The instance's number of CPUs.



45
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 45

attribute :instance_cpus

#instance_disksize ⇒ Integer?

Returns Size of the instance's disk in GB.

Returns:

  • (Integer, nil) —

    Size of the instance's disk in GB.



41
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 41

attribute :instance_disksize

#instance_dns ⇒ Object?

Returns Define the instance's Primary DNS server.

Returns:

  • (Object, nil) —

    Define the instance's Primary DNS server.



89
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 89

attribute :instance_dns

#instance_domain ⇒ Object?

Returns Define the instance's Domain.

Returns:

  • (Object, nil) —

    Define the instance's Domain.



92
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 92

attribute :instance_domain

#instance_hostname ⇒ Object?

Returns Define the instance's Hostname.

Returns:

  • (Object, nil) —

    Define the instance's Hostname.



95
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 95

attribute :instance_hostname

#instance_ip ⇒ Object?

Returns Define the instance's IP.

Returns:

  • (Object, nil) —

    Define the instance's IP.



98
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 98

attribute :instance_ip

#instance_key ⇒ Object?

Returns Define the instance's Authorized key.

Returns:

  • (Object, nil) —

    Define the instance's Authorized key.



107
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 107

attribute :instance_key

#instance_mem ⇒ Integer?

Returns The instance's amount of memory in MB.

Returns:

  • (Integer, nil) —

    The instance's amount of memory in MB.



57
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 57

attribute :instance_mem

#instance_name ⇒ String

Returns The name of the instance to use.

Returns:

  • (String) —

    The name of the instance to use.



21
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 21

attribute :instance_name

#instance_netmask ⇒ Object?

Returns Define the instance's Netmask.

Returns:

  • (Object, nil) —

    Define the instance's Netmask.



101
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 101

attribute :instance_netmask

#instance_network ⇒ String?

Returns The logical network the machine should belong to.

Returns:

  • (String, nil) —

    The logical network the machine should belong to.



53
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 53

attribute :instance_network

#instance_nic ⇒ String?

Returns The name of the network interface in oVirt/RHEV.

Returns:

  • (String, nil) —

    The name of the network interface in oVirt/RHEV.



49
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 49

attribute :instance_nic

#instance_os ⇒ String?

Returns Type of Operating System.

Returns:

  • (String, nil) —

    Type of Operating System.



73
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 73

attribute :instance_os

#instance_rootpw ⇒ Object?

Returns Define the instance's Root password.

Returns:

  • (Object, nil) —

    Define the instance's Root password.



104
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 104

attribute :instance_rootpw

#instance_type ⇒ :desktop, ...

Returns Define whether the instance is a server, desktop or high_performance.,I(high_performance) is supported since Ansible 2.5 and oVirt/RHV 4.2.

Returns:

  • (:desktop, :server, :high_performance, nil) —

    Define whether the instance is a server, desktop or high_performance.,I(high_performance) is supported since Ansible 2.5 and oVirt/RHV 4.2.



61
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 61

attribute :instance_type

#password ⇒ String

Returns Password of the user to authenticate with.

Returns:

  • (String) —

    Password of the user to authenticate with.



25
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 25

attribute :password

#region ⇒ String?

Returns The oVirt/RHEV datacenter where you want to deploy to.

Returns:

  • (String, nil) —

    The oVirt/RHEV datacenter where you want to deploy to.



85
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 85

attribute :region

#resource_type ⇒ :new, ...

Returns Whether you want to deploy an image or create an instance from scratch.

Returns:

  • (:new, :template, nil) —

    Whether you want to deploy an image or create an instance from scratch.



33
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 33

attribute :resource_type

#sdomain ⇒ String?

Returns The Storage Domain where you want to create the instance's disk on.

Returns:

  • (String, nil) —

    The Storage Domain where you want to create the instance's disk on.



81
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 81

attribute :sdomain

#state ⇒ :absent, ...

Returns Create, terminate or remove instances.

Returns:

  • (:absent, :present, :restarted, :shutdown, :started, nil) —

    Create, terminate or remove instances.



110
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 110

attribute :state

#url ⇒ String

Returns The url of the oVirt instance.

Returns:

  • (String) —

    The url of the oVirt instance.



17
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 17

attribute :url

#user ⇒ String

Returns The user to authenticate with.

Returns:

  • (String) —

    The user to authenticate with.



13
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 13

attribute :user

#zone ⇒ String?

Returns Deploy the image to this oVirt cluster.

Returns:

  • (String, nil) —

    Deploy the image to this oVirt cluster.



37
# File 'lib/ansible/ruby/modules/generated/cloud/misc/ovirt.rb', line 37

attribute :zone