Class: Ansible::Ruby::Modules::Ovirt_auth
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Ovirt_auth
- Defined in:
- lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb
Overview
This module authenticates to oVirt/RHV engine and creates SSO token, which should be later used in all other oVirt/RHV modules, so all modules don’t need to perform login and logout. This module returns an Ansible fact called I(ovirt_auth). Every module can use this fact as C(auth) parameter, to perform authentication.
Instance Method Summary collapse
-
#ca_file ⇒ Object?
A PEM file containing the trusted CA certificates.
-
#compress ⇒ Object?
A boolean flag indicating if the SDK should ask the server to send compressed responses.
-
#headers ⇒ Object?
A dictionary of HTTP headers to be added to each API call.
-
#hostname ⇒ Object?
A string containing the hostname of the server.
-
#insecure ⇒ Object?
A boolean flag that indicates if the server TLS certificate and host name should be checked.
-
#kerberos ⇒ Object?
A boolean flag indicating if Kerberos authentication should be used instead of the default basic authentication.
-
#password ⇒ Object?
The password of the user.
-
#state ⇒ :present, ...
Specifies if a token should be created or revoked.
-
#timeout ⇒ Object?
The maximum total time to wait for the response, in seconds.
-
#token ⇒ Object?
SSO token to be used instead of login with username/password.
-
#url ⇒ Object?
A string containing the API URL of the server.
-
#username ⇒ Object?
The name of the user.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#ca_file ⇒ Object?
34 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 34 attribute :ca_file |
#compress ⇒ Object?
40 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 40 attribute :compress |
#headers ⇒ Object?
46 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 46 attribute :headers |
#hostname ⇒ Object?
28 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 28 attribute :hostname |
#insecure ⇒ Object?
31 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 31 attribute :insecure |
#kerberos ⇒ Object?
43 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 43 attribute :kerberos |
#password ⇒ Object?
19 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 19 attribute :password |
#state ⇒ :present, ...
12 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 12 attribute :state |
#timeout ⇒ Object?
37 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 37 attribute :timeout |
#token ⇒ Object?
22 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 22 attribute :token |
#url ⇒ Object?
25 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 25 attribute :url |
#username ⇒ Object?
16 |
# File 'lib/ansible/ruby/modules/generated/cloud/ovirt/ovirt_auth.rb', line 16 attribute :username |