Class: Ansible::Ruby::Modules::Panos_match_rule

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb

Overview

Security policies allow you to enforce rules and take action, and can be as general or specific as needed.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#api_key ⇒ Object?

Returns API key that can be used instead of I(username)/I(password) credentials.

Returns:

  • (Object, nil) —

    API key that can be used instead of I(username)/I(password) credentials.



24
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 24

attribute :api_key

#application ⇒ String?

Returns The application.

Returns:

  • (String, nil) —

    The application.



62
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 62

attribute :application

#category ⇒ Object?

Returns URL category.

Returns:

  • (Object, nil) —

    URL category



70
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 70

attribute :category

#destination_ip ⇒ String?

Returns The destination IP address.

Returns:

  • (String, nil) —

    The destination IP address.



54
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 54

attribute :destination_ip

#destination_port ⇒ String?

Returns The destination port.

Returns:

  • (String, nil) —

    The destination port.



58
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 58

attribute :destination_port

#destination_zone ⇒ String?

Returns The destination zone.

Returns:

  • (String, nil) —

    The destination zone.



50
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 50

attribute :destination_zone

#ip_address ⇒ String

Returns IP address (or hostname) of PAN-OS device being configured.

Returns:

  • (String) —

    IP address (or hostname) of PAN-OS device being configured.



12
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 12

attribute :ip_address

#password ⇒ String

Returns Password credentials to use for auth unless I(api_key) is set.

Returns:

  • (String) —

    Password credentials to use for auth unless I(api_key) is set.



20
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 20

attribute :password

#protocol ⇒ String?

Returns The IP protocol number from 1 to 255.

Returns:

  • (String, nil) —

    The IP protocol number from 1 to 255.



66
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 66

attribute :protocol

#rule_type ⇒ String?

Returns Type of rule. Valid types are I(security) or I(nat).

Returns:

  • (String, nil) —

    Type of rule. Valid types are I(security) or I(nat).



27
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 27

attribute :rule_type

#source_ip ⇒ String

Returns The source IP address.

Returns:

  • (String) —

    The source IP address.



35
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 35

attribute :source_ip

#source_port ⇒ Object?

Returns The source port.

Returns:

  • (Object, nil) —

    The source port.



39
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 39

attribute :source_port

#source_user ⇒ String?

Returns The source user or group.

Returns:

  • (String, nil) —

    The source user or group.



42
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 42

attribute :source_user

#source_zone ⇒ String?

Returns The source zone.

Returns:

  • (String, nil) —

    The source zone.



31
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 31

attribute :source_zone

#to_interface ⇒ String?

Returns The inbound interface in a NAT rule.

Returns:

  • (String, nil) —

    The inbound interface in a NAT rule.



46
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 46

attribute :to_interface

#username ⇒ String?

Returns Username credentials to use for auth unless I(api_key) is set.

Returns:

  • (String, nil) —

    Username credentials to use for auth unless I(api_key) is set.



16
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 16

attribute :username

#vsys_id ⇒ String

Returns ID of the VSYS object.

Returns:

  • (String) —

    ID of the VSYS object.



73
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_match_rule.rb', line 73

attribute :vsys_id