Class: Ansible::Ruby::Modules::Panos_query_rules

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb

Overview

  • Security policies allow you to enforce rules and take action, and can be as general or specific as needed. The policy rules are compared against the incoming traffic in sequence, and because the first rule that matches the traffic is applied, the more specific rules must precede the more general ones.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#api_keyString?



25
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 25

attribute :api_key

#applicationObject?



29
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 29

attribute :application

#destination_ipString?



46
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 46

attribute :destination_ip

#destination_portString?



50
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 50

attribute :destination_port

#destination_zoneString?



42
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 42

attribute :destination_zone

#devicegroupObject?



62
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 62

attribute :devicegroup

#ip_addressString



13
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 13

attribute :ip_address

#passwordString



21
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 21

attribute :password

#protocolString?



54
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 54

attribute :protocol

#source_ipObject?



36
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 36

attribute :source_ip

#source_portObject?



39
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 39

attribute :source_port

#source_zoneString?



32
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 32

attribute :source_zone

#tag_nameString?



58
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 58

attribute :tag_name

#usernameString?



17
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 17

attribute :username