Class: Ansible::Ruby::Modules::Pn_show

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/netvisor/pn_show.rb

Overview

Execute show command in the nodes and returns the results read from the device.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#pn_clipassword ⇒ Object?

Returns Provide login password if user is not root.

Returns:

  • (Object, nil) —

    Provide login password if user is not root.



15
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_show.rb', line 15

attribute :pn_clipassword

#pn_cliswitch ⇒ Object?

Returns Target switch(es) to run the cli on.

Returns:

  • (Object, nil) —

    Target switch(es) to run the cli on.



18
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_show.rb', line 18

attribute :pn_cliswitch

#pn_cliusername ⇒ Object?

Returns Provide login username if user is not root.

Returns:

  • (Object, nil) —

    Provide login username if user is not root.



12
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_show.rb', line 12

attribute :pn_cliusername

#pn_command ⇒ String

Returns The C(pn_command) takes a CLI show command as value.

Returns:

  • (String) —

    The C(pn_command) takes a CLI show command as value.



21
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_show.rb', line 21

attribute :pn_command

#pn_options ⇒ String?

Returns Specify formatting options.

Returns:

  • (String, nil) —

    Specify formatting options.



29
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_show.rb', line 29

attribute :pn_options

#pn_parameters ⇒ Array<String>, ...

Returns Display output using a specific parameter. Use 'all' to display possible output. List of comma separated parameters.

Returns:

  • (Array<String>, String, nil) —

    Display output using a specific parameter. Use 'all' to display possible output. List of comma separated parameters.



25
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_show.rb', line 25

attribute :pn_parameters