Class: Ansible::Ruby::Modules::Pn_vlag

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb

Overview

Execute vlag-create/vlag-delete/vlag-modify command. A virtual link aggregation group (VLAG) allows links that are physically connected to two different Pluribus Networks devices to appear as a single trunk to a third device. The third device can be a switch, server, or any Ethernet device. A VLAG can provide Layer 2 multipathing, which allows you to create redundancy by increasing bandwidth, enabling multiple parallel paths between nodes and loadbalancing traffic where alternative paths exist.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#pn_clipassword ⇒ Object?

Returns Provide login password if user is not root.

Returns:

  • (Object, nil) —

    Provide login password if user is not root.



16
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 16

attribute :pn_clipassword

#pn_cliswitch ⇒ Object?

Returns Target switch(es) to run this command on.

Returns:

  • (Object, nil) —

    Target switch(es) to run this command on.



19
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 19

attribute :pn_cliswitch

#pn_cliusername ⇒ Object?

Returns Provide login username if user is not root.

Returns:

  • (Object, nil) —

    Provide login username if user is not root.



13
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 13

attribute :pn_cliusername

#pn_failover_action ⇒ :move, ...

Returns Specify the failover action as move or ignore.

Returns:

  • (:move, :ignore, nil) —

    Specify the failover action as move or ignore.



46
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 46

attribute :pn_failover_action

#pn_lacp_fallback ⇒ :bundle, ...

Returns Specify the LACP fallback mode as bundles or individual.

Returns:

  • (:bundle, :individual, nil) —

    Specify the LACP fallback mode as bundles or individual.



58
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 58

attribute :pn_lacp_fallback

#pn_lacp_fallback_timeout ⇒ Object?

Returns Specify the LACP fallback timeout in seconds. The range is between 30 and 60 seconds with a default value of 50 seconds.

Returns:

  • (Object, nil) —

    Specify the LACP fallback timeout in seconds. The range is between 30 and 60 seconds with a default value of 50 seconds.



62
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 62

attribute :pn_lacp_fallback_timeout

#pn_lacp_mode ⇒ :off, ...

Returns Specify the LACP mode.

Returns:

  • (:off, :passive, :active, nil) —

    Specify the LACP mode.



50
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 50

attribute :pn_lacp_mode

#pn_lacp_timeout ⇒ :slow, ...

Returns Specify the LACP timeout as slow(30 seconds) or fast(4 seconds).

Returns:

  • (:slow, :fast, nil) —

    Specify the LACP timeout as slow(30 seconds) or fast(4 seconds).



54
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 54

attribute :pn_lacp_timeout

#pn_mode ⇒ :"active-active", ...

Returns Specify the mode for the VLAG. Active-standby indicates one side is active and the other side is in standby mode. Active-active indicates that both sides of the vlag are up by default.

Returns:

  • (:"active-active", :"active-standby", nil) —

    Specify the mode for the VLAG. Active-standby indicates one side is active and the other side is in standby mode. Active-active indicates that both sides of the vlag are up by default.



38
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 38

attribute :pn_mode

#pn_name ⇒ String

Returns The C(pn_name) takes a valid name for vlag configuration.

Returns:

  • (String) —

    The C(pn_name) takes a valid name for vlag configuration.



26
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 26

attribute :pn_name

#pn_peer_port ⇒ String?

Returns Specify the peer VLAG port.,Required for vlag-create.

Returns:

  • (String, nil) —

    Specify the peer VLAG port.,Required for vlag-create.



34
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 34

attribute :pn_peer_port

#pn_peer_switch ⇒ String?

Returns Specify the fabric-name of the peer switch.

Returns:

  • (String, nil) —

    Specify the fabric-name of the peer switch.



42
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 42

attribute :pn_peer_switch

#pn_port ⇒ String?

Returns Specify the local VLAG port.,Required for vlag-create.

Returns:

  • (String, nil) —

    Specify the local VLAG port.,Required for vlag-create.



30
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 30

attribute :pn_port

#state ⇒ :present, ...

Returns State the action to perform. Use 'present' to create vlag, 'absent' to delete vlag and 'update' to modify vlag.

Returns:

  • (:present, :absent, :update) —

    State the action to perform. Use 'present' to create vlag, 'absent' to delete vlag and 'update' to modify vlag.



22
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vlag.rb', line 22

attribute :state