Class: Ansible::Ruby::Modules::Pn_vrouter

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb

Overview

Execute vrouter-create, vrouter-delete, vrouter-modify command. Each fabric, cluster, standalone switch, or virtual network (VNET) can provide its tenants with a virtual router (vRouter) service that forwards traffic between networks and implements Layer 3 protocols. C(vrouter-create) creates a new vRouter service. C(vrouter-delete) deletes a vRouter service. C(vrouter-modify) modifies a vRouter service.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#pn_bgp_as ⇒ Object?

Returns Specify the Autonomous System Number(ASN) if the vRouter runs Border Gateway Protocol(BGP).

Returns:

  • (Object, nil) —

    Specify the Autonomous System Number(ASN) if the vRouter runs Border Gateway Protocol(BGP).



56
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 56

attribute :pn_bgp_as

#pn_bgp_max_paths ⇒ Object?

Returns Specify the maximum number of paths for BGP. This is a number between 1 and 255 or 0 to unset.

Returns:

  • (Object, nil) —

    Specify the maximum number of paths for BGP. This is a number between 1 and 255 or 0 to unset.



63
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 63

attribute :pn_bgp_max_paths

#pn_bgp_options ⇒ Object?

Returns Specify other BGP options as a whitespaces separated string within single quotes ''.

Returns:

  • (Object, nil) —

    Specify other BGP options as a whitespaces separated string within single quotes ''.



66
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 66

attribute :pn_bgp_options

#pn_bgp_redistribute ⇒ :static, ...

Returns Specify how BGP routes are redistributed.

Returns:

  • (:static, :connected, :rip, :ospf, nil) —

    Specify how BGP routes are redistributed.



59
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 59

attribute :pn_bgp_redistribute

#pn_clipassword ⇒ Object?

Returns Provide login password if user is not root.

Returns:

  • (Object, nil) —

    Provide login password if user is not root.



19
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 19

attribute :pn_clipassword

#pn_cliswitch ⇒ Object?

Returns Target switch(es) to run the CLI on.

Returns:

  • (Object, nil) —

    Target switch(es) to run the CLI on.



22
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 22

attribute :pn_cliswitch

#pn_cliusername ⇒ Object?

Returns Provide login username if user is not root.

Returns:

  • (Object, nil) —

    Provide login username if user is not root.



16
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 16

attribute :pn_cliusername

#pn_hw_vrrp_id ⇒ Object?

Returns Specifies the VRRP ID for a hardware vrouter.

Returns:

  • (Object, nil) —

    Specifies the VRRP ID for a hardware vrouter.



49
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 49

attribute :pn_hw_vrrp_id

#pn_name ⇒ String

Returns Specify the name of the vRouter.

Returns:

  • (String) —

    Specify the name of the vRouter.



29
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 29

attribute :pn_name

#pn_ospf_options ⇒ Object?

Returns Specify other OSPF options as a whitespaces separated string within single quotes ''.

Returns:

  • (Object, nil) —

    Specify other OSPF options as a whitespaces separated string within single quotes ''.



77
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 77

attribute :pn_ospf_options

#pn_ospf_redistribute ⇒ :static, ...

Returns Specify how OSPF routes are redistributed.

Returns:

  • (:static, :connected, :bgp, :rip, nil) —

    Specify how OSPF routes are redistributed.



73
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 73

attribute :pn_ospf_redistribute

#pn_rip_redistribute ⇒ :static, ...

Returns Specify how RIP routes are redistributed.

Returns:

  • (:static, :connected, :ospf, :bgp, nil) —

    Specify how RIP routes are redistributed.



69
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 69

attribute :pn_rip_redistribute

#pn_router_id ⇒ String?

Returns Specify the vRouter IP address.

Returns:

  • (String, nil) —

    Specify the vRouter IP address.



52
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 52

attribute :pn_router_id

#pn_router_type ⇒ :hardware, ...

Returns Specify if the vRouter uses software or hardware.,Note that if you specify hardware as router type, you cannot assign IP addresses using DHCP. You must specify a static IP address.

Returns:

  • (:hardware, :software, nil) —

    Specify if the vRouter uses software or hardware.,Note that if you specify hardware as router type, you cannot assign IP addresses using DHCP. You must specify a static IP address.



45
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 45

attribute :pn_router_type

#pn_service_state ⇒ :enable, ...

Returns Specify to enable or disable vRouter service.

Returns:

  • (:enable, :disable, nil) —

    Specify to enable or disable vRouter service.



41
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 41

attribute :pn_service_state

#pn_service_type ⇒ :dedicated, ...

Returns Specify if the vRouter is a dedicated or shared VNET service.

Returns:

  • (:dedicated, :shared, nil) —

    Specify if the vRouter is a dedicated or shared VNET service.



37
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 37

attribute :pn_service_type

#pn_vnet ⇒ String?

Returns Specify the name of the VNET.,Required for vrouter-create.

Returns:

  • (String, nil) —

    Specify the name of the VNET.,Required for vrouter-create.



33
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 33

attribute :pn_vnet

#state ⇒ :present, ...

Returns State the action to perform. Use 'present' to create vrouter, 'absent' to delete vrouter and 'update' to modify vrouter.

Returns:

  • (:present, :absent, :update) —

    State the action to perform. Use 'present' to create vrouter, 'absent' to delete vrouter and 'update' to modify vrouter.



25
# File 'lib/ansible/ruby/modules/generated/network/netvisor/pn_vrouter.rb', line 25

attribute :state