Class: Ansible::Ruby::Modules::Postgresql_schema

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb

Overview

Add or remove PostgreSQL schema from a remote host.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#database ⇒ String?

Returns Name of the database to connect to.

Returns:

  • (String, nil) —

    Name of the database to connect to.



16
# File 'lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb', line 16

attribute :database

#login_host ⇒ String?

Returns Host running the database.

Returns:

  • (String, nil) —

    Host running the database.



26
# File 'lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb', line 26

attribute :login_host

#login_password ⇒ Object?

Returns The password used to authenticate with.

Returns:

  • (Object, nil) —

    The password used to authenticate with.



23
# File 'lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb', line 23

attribute :login_password

#login_unix_socket ⇒ Object?

Returns Path to a Unix domain socket for local connections.

Returns:

  • (Object, nil) —

    Path to a Unix domain socket for local connections.



30
# File 'lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb', line 30

attribute :login_unix_socket

#login_user ⇒ Object?

Returns The username used to authenticate with.

Returns:

  • (Object, nil) —

    The username used to authenticate with.



20
# File 'lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb', line 20

attribute :login_user

#name ⇒ String

Returns Name of the schema to add or remove.

Returns:

  • (String) —

    Name of the schema to add or remove.



12
# File 'lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb', line 12

attribute :name

#owner ⇒ String?

Returns Name of the role to set as owner of the schema.

Returns:

  • (String, nil) —

    Name of the role to set as owner of the schema.



33
# File 'lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb', line 33

attribute :owner

#port ⇒ Integer?

Returns Database port to connect to.

Returns:

  • (Integer, nil) —

    Database port to connect to.



37
# File 'lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb', line 37

attribute :port

#state ⇒ :present, ...

Returns The schema state.

Returns:

  • (:present, :absent, nil) —

    The schema state.



41
# File 'lib/ansible/ruby/modules/generated/database/postgresql/postgresql_schema.rb', line 41

attribute :state