Class: Ansible::Ruby::Modules::Purefb_fs

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb

Overview

This module manages filesystems on Pure Storage FlashBlade.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#eradicate ⇒ Symbol?

Returns Define whether to eradicate the filesystem on delete or leave in trash.

Returns:

  • (Symbol, nil) —

    Define whether to eradicate the filesystem on delete or leave in trash.



20
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 20

attribute :eradicate

#fastremove ⇒ Symbol?

Returns Define whether the fast remove directory is enabled for the filesystem.

Returns:

  • (Symbol, nil) —

    Define whether the fast remove directory is enabled for the filesystem.



48
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 48

attribute :fastremove

#http ⇒ Symbol?

Returns Define whether to HTTP/HTTPS protocol is enabled for the filesystem.

Returns:

  • (Symbol, nil) —

    Define whether to HTTP/HTTPS protocol is enabled for the filesystem.



40
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 40

attribute :http

#name ⇒ String

Returns Filesystem Name.

Returns:

  • (String) —

    Filesystem Name.



12
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 12

attribute :name

#nfs ⇒ Boolean?

Returns Define whether to NFS protocol is enabled for the filesystem.

Returns:

  • (Boolean, nil) —

    Define whether to NFS protocol is enabled for the filesystem.



28
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 28

attribute :nfs

#nfs_rules ⇒ Array<String>, ...

Returns Define the NFS rules in operation.

Returns:

  • (Array<String>, String, nil) —

    Define the NFS rules in operation.



32
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 32

attribute :nfs_rules

#size ⇒ String?

Returns Volume size in M, G, T or P units. See examples.

Returns:

  • (String, nil) —

    Volume size in M, G, T or P units. See examples.



24
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 24

attribute :size

#smb ⇒ Symbol?

Returns Define whether to SMB protocol is enabled for the filesystem.

Returns:

  • (Symbol, nil) —

    Define whether to SMB protocol is enabled for the filesystem.



36
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 36

attribute :smb

#snapshot ⇒ Symbol?

Returns Define whether a snapshot directory is enabled for the filesystem.

Returns:

  • (Symbol, nil) —

    Define whether a snapshot directory is enabled for the filesystem.



44
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 44

attribute :snapshot

#state ⇒ :present, ...

Returns Create, delete or modifies a filesystem.

Returns:

  • (:present, :absent, nil) —

    Create, delete or modifies a filesystem.



16
# File 'lib/ansible/ruby/modules/generated/storage/purestorage/purefb_fs.rb', line 16

attribute :state