Class: Ansible::Ruby::Modules::Pushbullet

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/notification/pushbullet.rb

Overview

This module sends push notifications via Pushbullet to channels or devices.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#api_key ⇒ String

Returns Push bullet API token.

Returns:

  • (String) —

    Push bullet API token



12
# File 'lib/ansible/ruby/modules/generated/notification/pushbullet.rb', line 12

attribute :api_key

#body ⇒ String?

Returns Body of the notification, e.g. Details of the fault you're alerting.

Returns:

  • (String, nil) —

    Body of the notification, e.g. Details of the fault you're alerting.



32
# File 'lib/ansible/ruby/modules/generated/notification/pushbullet.rb', line 32

attribute :body

#channel ⇒ String?

Returns The channel TAG you wish to broadcast a push notification, as seen on the "My Channels" > "Edit your channel" at Pushbullet page.

Returns:

  • (String, nil) —

    The channel TAG you wish to broadcast a push notification, as seen on the "My Channels" > "Edit your channel" at Pushbullet page.



16
# File 'lib/ansible/ruby/modules/generated/notification/pushbullet.rb', line 16

attribute :channel

#device ⇒ String?

Returns The device NAME you wish to send a push notification, as seen on the Pushbullet main page.

Returns:

  • (String, nil) —

    The device NAME you wish to send a push notification, as seen on the Pushbullet main page.



20
# File 'lib/ansible/ruby/modules/generated/notification/pushbullet.rb', line 20

attribute :device

#push_type ⇒ :note, ...

Returns Thing you wish to push.

Returns:

  • (:note, :link, nil) —

    Thing you wish to push.



24
# File 'lib/ansible/ruby/modules/generated/notification/pushbullet.rb', line 24

attribute :push_type

#title ⇒ String

Returns Title of the notification.

Returns:

  • (String) —

    Title of the notification.



28
# File 'lib/ansible/ruby/modules/generated/notification/pushbullet.rb', line 28

attribute :title