Class: Ansible::Ruby::Modules::Rax_cbs_attachments

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/rackspace/rax_cbs_attachments.rb

Overview

Manipulate Rackspace Cloud Block Storage Volume Attachments

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#device ⇒ Object?

Returns The device path to attach the volume to, e.g. /dev/xvde.,Before 2.4 this was a required field. Now it can be left to null to auto assign the device name.

Returns:

  • (Object, nil) —

    The device path to attach the volume to, e.g. /dev/xvde.,Before 2.4 this was a required field. Now it can be left to null to auto assign the device name.



12
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_cbs_attachments.rb', line 12

attribute :device

#server ⇒ Object

Returns Name or id of the server to attach/detach.

Returns:

  • (Object) —

    Name or id of the server to attach/detach



19
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_cbs_attachments.rb', line 19

attribute :server

#state ⇒ :present, :absent

Returns Indicate desired state of the resource.

Returns:

  • (:present, :absent) —

    Indicate desired state of the resource



23
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_cbs_attachments.rb', line 23

attribute :state

#volume ⇒ Object

Returns Name or id of the volume to attach/detach.

Returns:

  • (Object) —

    Name or id of the volume to attach/detach



15
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_cbs_attachments.rb', line 15

attribute :volume

#wait ⇒ :yes, ...

Returns wait for the volume to be in 'in-use'/'available' state before returning.

Returns:

  • (:yes, :no, nil) —

    wait for the volume to be in 'in-use'/'available' state before returning



27
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_cbs_attachments.rb', line 27

attribute :wait

#wait_timeout ⇒ Integer?

Returns how long before wait gives up, in seconds.

Returns:

  • (Integer, nil) —

    how long before wait gives up, in seconds



31
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_cbs_attachments.rb', line 31

attribute :wait_timeout