Class: Ansible::Ruby::Modules::Rax_clb

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb

Overview

creates / deletes a Rackspace Public Cloud load balancer.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#algorithm ⇒ :RANDOM, ...

Returns algorithm for the balancer being created.

Returns:

  • (:RANDOM, :LEAST_CONNECTIONS, :ROUND_ROBIN, :WEIGHTED_LEAST_CONNECTIONS, :WEIGHTED_ROUND_ROBIN, nil) —

    algorithm for the balancer being created



12
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 12

attribute :algorithm

#meta ⇒ Object?

Returns A hash of metadata to associate with the instance.

Returns:

  • (Object, nil) —

    A hash of metadata to associate with the instance



16
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 16

attribute :meta

#name ⇒ String?

Returns Name to give the load balancer.

Returns:

  • (String, nil) —

    Name to give the load balancer



19
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 19

attribute :name

#port ⇒ Integer?

Returns Port for the balancer being created.

Returns:

  • (Integer, nil) —

    Port for the balancer being created



23
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 23

attribute :port

#protocol ⇒ :DNS_TCP, ...

Returns Protocol for the balancer being created.

Returns:

  • (:DNS_TCP, :DNS_UDP, :FTP, :HTTP, :HTTPS, :IMAPS, :IMAPv4, :LDAP, :LDAPS, :MYSQL, :POP3, :POP3S, :SMTP, :TCP, :TCP_CLIENT_FIRST, :UDP, :UDP_STREAM, :SFTP, nil) —

    Protocol for the balancer being created



27
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 27

attribute :protocol

#state ⇒ :present, ...

Returns Indicate desired state of the resource.

Returns:

  • (:present, :absent, nil) —

    Indicate desired state of the resource



31
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 31

attribute :state

#timeout ⇒ Integer?

Returns timeout for communication between the balancer and the node.

Returns:

  • (Integer, nil) —

    timeout for communication between the balancer and the node



35
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 35

attribute :timeout

#type ⇒ :PUBLIC, ...

Returns type of interface for the balancer being created.

Returns:

  • (:PUBLIC, :SERVICENET, nil) —

    type of interface for the balancer being created



39
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 39

attribute :type

#vip_id ⇒ Object?

Returns Virtual IP ID to use when creating the load balancer for purposes of sharing an IP with another load balancer of another protocol.

Returns:

  • (Object, nil) —

    Virtual IP ID to use when creating the load balancer for purposes of sharing an IP with another load balancer of another protocol



43
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 43

attribute :vip_id

#wait ⇒ :yes, ...

Returns wait for the balancer to be in state 'running' before returning.

Returns:

  • (:yes, :no, nil) —

    wait for the balancer to be in state 'running' before returning



46
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 46

attribute :wait

#wait_timeout ⇒ Integer?

Returns how long before wait gives up, in seconds.

Returns:

  • (Integer, nil) —

    how long before wait gives up, in seconds



50
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_clb.rb', line 50

attribute :wait_timeout