Class: Ansible::Ruby::Modules::Rax_dns_record

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb

Overview

Manage DNS records on Rackspace Cloud DNS

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#comment ⇒ Object?

Returns Brief description of the domain. Maximum length of 160 characters.

Returns:

  • (Object, nil) —

    Brief description of the domain. Maximum length of 160 characters



12
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 12

attribute :comment

#data ⇒ Object

Returns IP address for A/AAAA record, FQDN for CNAME/MX/NS, or text data for SRV/TXT.

Returns:

  • (Object) —

    IP address for A/AAAA record, FQDN for CNAME/MX/NS, or text data for SRV/TXT



15
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 15

attribute :data

#domain ⇒ Object?

Returns Domain name to create the record in. This is an invalid option when type=PTR.

Returns:

  • (Object, nil) —

    Domain name to create the record in. This is an invalid option when type=PTR



19
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 19

attribute :domain

#loadbalancer ⇒ Object?

Returns Load Balancer ID to create a PTR record for. Only used with type=PTR.

Returns:

  • (Object, nil) —

    Load Balancer ID to create a PTR record for. Only used with type=PTR



22
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 22

attribute :loadbalancer

#name ⇒ String

Returns FQDN record name to create.

Returns:

  • (String) —

    FQDN record name to create



25
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 25

attribute :name

#overwrite ⇒ Boolean?

Returns Add new records if data doesn't match, instead of updating existing record with matching name. If there are already multiple records with matching name and overwrite=true, this module will fail.

Returns:

  • (Boolean, nil) —

    Add new records if data doesn't match, instead of updating existing record with matching name. If there are already multiple records with matching name and overwrite=true, this module will fail.



29
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 29

attribute :overwrite

#priority ⇒ Object?

Returns Required for MX and SRV records, but forbidden for other record types. If specified, must be an integer from 0 to 65535.

Returns:

  • (Object, nil) —

    Required for MX and SRV records, but forbidden for other record types. If specified, must be an integer from 0 to 65535.



33
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 33

attribute :priority

#server ⇒ Object?

Returns Server ID to create a PTR record for. Only used with type=PTR.

Returns:

  • (Object, nil) —

    Server ID to create a PTR record for. Only used with type=PTR



36
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 36

attribute :server

#state ⇒ :present, ...

Returns Indicate desired state of the resource.

Returns:

  • (:present, :absent, nil) —

    Indicate desired state of the resource



39
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 39

attribute :state

#ttl ⇒ Integer?

Returns Time to live of record in seconds.

Returns:

  • (Integer, nil) —

    Time to live of record in seconds



43
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 43

attribute :ttl

#type ⇒ :A, ...

Returns DNS record type.

Returns:

  • (:A, :AAAA, :CNAME, :MX, :NS, :SRV, :TXT, :PTR) —

    DNS record type



47
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_dns_record.rb', line 47

attribute :type