Class: Ansible::Ruby::Modules::Rax_facts

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/rackspace/rax_facts.rb

Overview

Gather facts for Rackspace Cloud Servers.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#address ⇒ Object?

Returns Server IP address to retrieve facts for, will match any IP assigned to the server.

Returns:

  • (Object, nil) —

    Server IP address to retrieve facts for, will match any IP assigned to the server



12
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_facts.rb', line 12

attribute :address

#id ⇒ Object?

Returns Server ID to retrieve facts for.

Returns:

  • (Object, nil) —

    Server ID to retrieve facts for



15
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_facts.rb', line 15

attribute :id

#name ⇒ String?

Returns Server name to retrieve facts for.

Returns:

  • (String, nil) —

    Server name to retrieve facts for



18
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_facts.rb', line 18

attribute :name