Class: Ansible::Ruby::Modules::Rax_scaling_group

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb

Overview

Manipulate Rackspace Cloud Autoscale Groups

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#config_drive ⇒ :yes, ...

Returns Attach read-only configuration drive to server as label config-2.

Returns:

  • (:yes, :no, nil) —

    Attach read-only configuration drive to server as label config-2



12
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 12

attribute :config_drive

#cooldown ⇒ Object?

Returns The period of time, in seconds, that must pass before any scaling can occur after the previous scaling. Must be an integer between 0 and 86400 (24 hrs).

Returns:

  • (Object, nil) —

    The period of time, in seconds, that must pass before any scaling can occur after the previous scaling. Must be an integer between 0 and 86400 (24 hrs).



16
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 16

attribute :cooldown

#disk_config ⇒ :auto, ...

Returns Disk partitioning strategy.

Returns:

  • (:auto, :manual, nil) —

    Disk partitioning strategy



19
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 19

attribute :disk_config

#files ⇒ Object?

Returns Files to insert into the instance. Hash of C(remotepath: localpath).

Returns:

  • (Object, nil) —

    Files to insert into the instance. Hash of C(remotepath: localpath)



23
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 23

attribute :files

#flavor ⇒ Object

Returns flavor to use for the instance.

Returns:

  • (Object) —

    flavor to use for the instance



26
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 26

attribute :flavor

#image ⇒ Object

Returns image to use for the instance. Can be an C(id), C(human_id) or C(name).

Returns:

  • (Object) —

    image to use for the instance. Can be an C(id), C(human_id) or C(name)



30
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 30

attribute :image

#key_name ⇒ Object?

Returns key pair to use on the instance.

Returns:

  • (Object, nil) —

    key pair to use on the instance



34
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 34

attribute :key_name

#loadbalancers ⇒ Object?

Returns List of load balancer C(id) and C(port) hashes.

Returns:

  • (Object, nil) —

    List of load balancer C(id) and C(port) hashes



37
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 37

attribute :loadbalancers

#max_entities ⇒ Object

Returns The maximum number of entities that are allowed in the scaling group. Must be an integer between 0 and 1000.

Returns:

  • (Object) —

    The maximum number of entities that are allowed in the scaling group. Must be an integer between 0 and 1000.



40
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 40

attribute :max_entities

#meta ⇒ Object?

Returns A hash of metadata to associate with the instance.

Returns:

  • (Object, nil) —

    A hash of metadata to associate with the instance



44
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 44

attribute :meta

#min_entities ⇒ Object

Returns The minimum number of entities that are allowed in the scaling group. Must be an integer between 0 and 1000.

Returns:

  • (Object) —

    The minimum number of entities that are allowed in the scaling group. Must be an integer between 0 and 1000.



47
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 47

attribute :min_entities

#name ⇒ Object

Returns Name to give the scaling group.

Returns:

  • (Object) —

    Name to give the scaling group



51
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 51

attribute :name

#networks ⇒ String?

Returns The network to attach to the instances. If specified, you must include ALL networks including the public and private interfaces. Can be C(id) or C(label).

Returns:

  • (String, nil) —

    The network to attach to the instances. If specified, you must include ALL networks including the public and private interfaces. Can be C(id) or C(label).



55
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 55

attribute :networks

#server_name ⇒ Object

Returns The base name for servers created by Autoscale.

Returns:

  • (Object) —

    The base name for servers created by Autoscale



59
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 59

attribute :server_name

#state ⇒ :present, ...

Returns Indicate desired state of the resource.

Returns:

  • (:present, :absent, nil) —

    Indicate desired state of the resource



63
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 63

attribute :state

#user_data ⇒ Object?

Returns Data to be uploaded to the servers config drive. This option implies I(config_drive). Can be a file path or a string.

Returns:

  • (Object, nil) —

    Data to be uploaded to the servers config drive. This option implies I(config_drive). Can be a file path or a string



67
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 67

attribute :user_data

#wait ⇒ :yes, ...

Returns wait for the scaling group to finish provisioning the minimum amount of servers.

Returns:

  • (:yes, :no, nil) —

    wait for the scaling group to finish provisioning the minimum amount of servers



70
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 70

attribute :wait

#wait_timeout ⇒ Integer?

Returns how long before wait gives up, in seconds.

Returns:

  • (Integer, nil) —

    how long before wait gives up, in seconds



74
# File 'lib/ansible/ruby/modules/generated/cloud/rackspace/rax_scaling_group.rb', line 74

attribute :wait_timeout