Class: Ansible::Ruby::Modules::Rds
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Rds
- Defined in:
- lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb
Overview
Creates, deletes, or modifies rds instances. When creating an instance it can be either a new instance or a read-only replica of an existing instance. This module has a dependency on python-boto >= 2.5. The ‘promote’ command requires boto >= 2.18.0. Certain features such as tags rely on boto.rds2 (boto >= 2.26.0)
Instance Method Summary collapse
-
#apply_immediately ⇒ :yes, ...
Used only when command=modify.
-
#aws_access_key ⇒ Object?
AWS access key.
-
#aws_secret_key ⇒ Object?
AWS secret key.
-
#backup_retention ⇒ Object?
Number of days backups are retained.
-
#backup_window ⇒ Object?
Backup window in format of hh24:mi-hh24:mi.
-
#character_set_name ⇒ Object?
Associate the DB instance with a specified character set.
-
#command ⇒ :create, ...
Specifies the action to take.
-
#db_engine ⇒ :mariadb, ...
The type of database.
-
#db_name ⇒ Object?
Name of a database to create within the instance.
-
#engine_version ⇒ Object?
Version number of the database engine to use.
-
#force_failover ⇒ :yes, ...
Used only when command=reboot.
-
#instance_name ⇒ String?
Database instance identifier.
-
#instance_type ⇒ String?
The instance type of the database.
-
#iops ⇒ Object?
Specifies the number of IOPS for the instance.
-
#license_model ⇒ :"license-included", ...
The license model for this DB instance.
-
#maint_window ⇒ Object?
Maintenance window in format of ddd:hh24:mi-ddd:hh24:mi.
-
#multi_zone ⇒ Symbol?
Specifies if this is a Multi-availability-zone deployment.
-
#new_instance_name ⇒ String?
Name to rename an instance to.
-
#option_group ⇒ Object?
The name of the option group to use.
-
#parameter_group ⇒ Object?
Name of the DB parameter group to associate with this instance.
-
#password ⇒ String?
Password for the master database username.
-
#port ⇒ Integer?
Port number that the DB instance uses for connections.
-
#publicly_accessible ⇒ Boolean?
Explicitly set whether the resource should be publicly accessible or not.
-
#region ⇒ String
The AWS region to use.
-
#security_groups ⇒ Object?
Comma separated list of one or more security groups.
-
#size ⇒ Integer?
Size in gigabytes of the initial storage for the DB instance.
-
#snapshot ⇒ String?
Name of snapshot to take.
-
#source_instance ⇒ String?
Name of the database to replicate.
-
#subnet ⇒ String?
VPC subnet group.
-
#tags ⇒ Hash?
Tags dict to apply to a resource.
-
#upgrade ⇒ :yes, ...
Indicates that minor version upgrades should be applied automatically.
-
#username ⇒ String?
Master database username.
-
#vpc_security_groups ⇒ String?
Comma separated list of one or more vpc security group ids.
-
#wait ⇒ :yes, ...
When command=create, replicate, modify or restore then wait for the database to enter the ‘available’ state.
-
#wait_timeout ⇒ Integer?
How long before wait gives up, in seconds.
-
#zone ⇒ String?
Availability zone in which to launch the instance.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#apply_immediately ⇒ :yes, ...
121 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 121 attribute :apply_immediately |
#aws_access_key ⇒ Object?
110 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 110 attribute :aws_access_key |
#aws_secret_key ⇒ Object?
107 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 107 attribute :aws_secret_key |
#backup_retention ⇒ Object?
92 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 92 attribute :backup_retention |
#backup_window ⇒ Object?
89 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 89 attribute :backup_window |
#character_set_name ⇒ Object?
133 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 133 attribute :character_set_name |
#command ⇒ :create, ...
12 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 12 attribute :command |
#db_engine ⇒ :mariadb, ...
24 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 24 attribute :db_engine |
#db_name ⇒ Object?
48 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 48 attribute :db_name |
#engine_version ⇒ Object?
51 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 51 attribute :engine_version |
#force_failover ⇒ :yes, ...
125 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 125 attribute :force_failover |
#instance_name ⇒ String?
16 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 16 attribute :instance_name |
#instance_type ⇒ String?
32 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 32 attribute :instance_type |
#iops ⇒ Object?
65 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 65 attribute :iops |
#license_model ⇒ :"license-included", ...
57 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 57 attribute :license_model |
#maint_window ⇒ Object?
86 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 86 attribute :maint_window |
#multi_zone ⇒ Symbol?
61 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 61 attribute :multi_zone |
#new_instance_name ⇒ String?
129 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 129 attribute :new_instance_name |
#option_group ⇒ Object?
83 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 83 attribute :option_group |
#parameter_group ⇒ Object?
54 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 54 attribute :parameter_group |
#password ⇒ String?
40 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 40 attribute :password |
#port ⇒ Integer?
75 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 75 attribute :port |
#publicly_accessible ⇒ Boolean?
136 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 136 attribute :publicly_accessible |
#region ⇒ String
44 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 44 attribute :region |
#security_groups ⇒ Object?
68 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 68 attribute :security_groups |
#size ⇒ Integer?
28 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 28 attribute :size |
#snapshot ⇒ String?
103 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 103 attribute :snapshot |
#source_instance ⇒ String?
20 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 20 attribute :source_instance |
#subnet ⇒ String?
99 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 99 attribute :subnet |
#tags ⇒ Hash?
140 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 140 attribute :tags |
#upgrade ⇒ :yes, ...
79 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 79 attribute :upgrade |
#username ⇒ String?
36 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 36 attribute :username |
#vpc_security_groups ⇒ String?
71 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 71 attribute :vpc_security_groups |
#wait ⇒ :yes, ...
113 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 113 attribute :wait |
#wait_timeout ⇒ Integer?
117 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 117 attribute :wait_timeout |
#zone ⇒ String?
95 |
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/rds.rb', line 95 attribute :zone |