Class: Ansible::Ruby::Modules::Redshift

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb

Overview

Creates, deletes, or modifies amazon Redshift cluster instances.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#allow_version_upgrade ⇒ String?

Returns flag to determinate if upgrade of version is possible.

Returns:

  • (String, nil) —

    flag to determinate if upgrade of version is possible



77
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 77

attribute :allow_version_upgrade

#automated_snapshot_retention_period ⇒ Object?

Returns period when the snapshot take place.

Returns:

  • (Object, nil) —

    period when the snapshot take place



67
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 67

attribute :automated_snapshot_retention_period

#availability_zone ⇒ Object?

Returns availability zone in which to launch cluster.

Returns:

  • (Object, nil) —

    availability zone in which to launch cluster



39
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 39

attribute :availability_zone

#cluster_parameter_group_name ⇒ Object?

Returns name of the cluster parameter group.

Returns:

  • (Object, nil) —

    name of the cluster parameter group



64
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 64

attribute :cluster_parameter_group_name

#cluster_security_groups ⇒ Object?

Returns in which security group the cluster belongs.

Returns:

  • (Object, nil) —

    in which security group the cluster belongs



48
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 48

attribute :cluster_security_groups

#cluster_subnet_group_name ⇒ Object?

Returns which subnet to place the cluster.

Returns:

  • (Object, nil) —

    which subnet to place the cluster



45
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 45

attribute :cluster_subnet_group_name

#cluster_type ⇒ :"multi-node", ...

Returns The type of cluster.

Returns:

  • (:"multi-node", :"single-node", nil) —

    The type of cluster.



32
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 32

attribute :cluster_type

#cluster_version ⇒ 1.0?

Returns which version the cluster should have.

Returns:

  • (1.0, nil) —

    which version the cluster should have



73
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 73

attribute :cluster_version

#command ⇒ :create, ...

Returns Specifies the action to take.

Returns:

  • (:create, :facts, :delete, :modify) —

    Specifies the action to take.



12
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 12

attribute :command

#db_name ⇒ Object?

Returns Name of the database.

Returns:

  • (Object, nil) —

    Name of the database.



36
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 36

attribute :db_name

#elastic_ip ⇒ Object?

Returns if the cluster has an elastic IP or not.

Returns:

  • (Object, nil) —

    if the cluster has an elastic IP or not



89
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 89

attribute :elastic_ip

#encrypted ⇒ String?

Returns if the cluster is encrypted or not.

Returns:

  • (String, nil) —

    if the cluster is encrypted or not



85
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 85

attribute :encrypted

#final_cluster_snapshot_identifier ⇒ Object?

Returns identifier of the final snapshot to be created before deleting the cluster. If this parameter is provided, final_cluster_snapshot_identifier must be false. Used only when command=delete.

Returns:

  • (Object, nil) —

    identifier of the final snapshot to be created before deleting the cluster. If this parameter is provided, final_cluster_snapshot_identifier must be false. Used only when command=delete.



58
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 58

attribute :final_cluster_snapshot_identifier

#identifier ⇒ String

Returns Redshift cluster identifier.

Returns:

  • (String) —

    Redshift cluster identifier.



16
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 16

attribute :identifier

#new_cluster_identifier ⇒ Object?

Returns Only used when command=modify.

Returns:

  • (Object, nil) —

    Only used when command=modify.



92
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 92

attribute :new_cluster_identifier

#node_type ⇒ :"ds1.xlarge", ...

Returns The node type of the cluster. Must be specified when command=create.

Returns:

  • (:"ds1.xlarge", :"ds1.8xlarge", :"ds2.xlarge", :"ds2.8xlarge", :"dc1.large", :"dc1.8xlarge", :"dc2.large", :"dc2.8xlarge", :"dw1.xlarge", :"dw1.8xlarge", :"dw2.large", :"dw2.8xlarge", nil) —

    The node type of the cluster. Must be specified when command=create.



20
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 20

attribute :node_type

#number_of_nodes ⇒ Object?

Returns Number of nodes. Only used when cluster_type=multi-node.

Returns:

  • (Object, nil) —

    Number of nodes. Only used when cluster_type=multi-node.



42
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 42

attribute :number_of_nodes

#password ⇒ String?

Returns Master database password. Used only when command=create.

Returns:

  • (String, nil) —

    Master database password. Used only when command=create.



28
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 28

attribute :password

#port ⇒ Object?

Returns which port the cluster is listining.

Returns:

  • (Object, nil) —

    which port the cluster is listining



70
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 70

attribute :port

#preferred_maintenance_window ⇒ Object?

Returns maintenance window.

Returns:

  • (Object, nil) —

    maintenance window



61
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 61

attribute :preferred_maintenance_window

#publicly_accessible ⇒ String?

Returns if the cluster is accessible publicly or not.

Returns:

  • (String, nil) —

    if the cluster is accessible publicly or not



81
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 81

attribute :publicly_accessible

#skip_final_cluster_snapshot ⇒ String?

Returns skip a final snapshot before deleting the cluster. Used only when command=delete.

Returns:

  • (String, nil) —

    skip a final snapshot before deleting the cluster. Used only when command=delete.



54
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 54

attribute :skip_final_cluster_snapshot

#username ⇒ String?

Returns Master database username. Used only when command=create.

Returns:

  • (String, nil) —

    Master database username. Used only when command=create.



24
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 24

attribute :username

#vpc_security_group_ids ⇒ Object?

Returns VPC security group.

Returns:

  • (Object, nil) —

    VPC security group



51
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 51

attribute :vpc_security_group_ids

#wait ⇒ :yes, ...

Returns When command=create, modify or restore then wait for the database to enter the 'available' state. When command=delete wait for the database to be terminated.

Returns:

  • (:yes, :no, nil) —

    When command=create, modify or restore then wait for the database to enter the 'available' state. When command=delete wait for the database to be terminated.



95
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 95

attribute :wait

#wait_timeout ⇒ Integer?

Returns how long before wait gives up, in seconds.

Returns:

  • (Integer, nil) —

    how long before wait gives up, in seconds



99
# File 'lib/ansible/ruby/modules/generated/cloud/amazon/redshift.rb', line 99

attribute :wait_timeout