Class: Ansible::Ruby::Modules::Sensu_handler

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb

Overview

Manages Sensu handler configuration For more information, refer to the Sensu documentation: U(https://sensuapp.org/docs/latest/reference/handlers.html)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#command ⇒ String?

Returns The handler command to be executed.,The event data is passed to the process via STDIN.,NOTE: the command attribute is only required for Pipe handlers (i.e. handlers configured with "type": "pipe").

Returns:

  • (String, nil) —

    The handler command to be executed.,The event data is passed to the process via STDIN.,NOTE: the command attribute is only required for Pipe handlers (i.e. handlers configured with "type": "pipe").



50
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 50

attribute :command

#filter ⇒ Object?

Returns The Sensu event filter (name) to use when filtering events for the handler.

Returns:

  • (Object, nil) —

    The Sensu event filter (name) to use when filtering events for the handler.



25
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 25

attribute :filter

#filters ⇒ Object?

Returns An array of Sensu event filters (names) to use when filtering events for the handler.,Each array item must be a string.

Returns:

  • (Object, nil) —

    An array of Sensu event filters (names) to use when filtering events for the handler.,Each array item must be a string.



28
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 28

attribute :filters

#handle_flapping ⇒ :yes, ...

Returns If events in the flapping state should be handled.

Returns:

  • (:yes, :no, nil) —

    If events in the flapping state should be handled.



46
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 46

attribute :handle_flapping

#handle_silenced ⇒ :yes, ...

Returns If events matching one or more silence entries should be handled.

Returns:

  • (:yes, :no, nil) —

    If events matching one or more silence entries should be handled.



42
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 42

attribute :handle_silenced

#handlers ⇒ Object?

Returns An array of Sensu event handlers (names) to use for events using the handler set.,Each array item must be a string.,NOTE: the handlers attribute is only required for handler sets (i.e. handlers configured with "type": "set").

Returns:

  • (Object, nil) —

    An array of Sensu event handlers (names) to use for events using the handler set.,Each array item must be a string.,NOTE: the handlers attribute is only required for handler sets (i.e. handlers configured with "type": "set").



61
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 61

attribute :handlers

#mutator ⇒ Object?

Returns The Sensu event mutator (name) to use to mutate event data for the handler.

Returns:

  • (Object, nil) —

    The Sensu event mutator (name) to use to mutate event data for the handler.



35
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 35

attribute :mutator

#name ⇒ String

Returns A unique name for the handler. The name cannot contain special characters or spaces.

Returns:

  • (String) —

    A unique name for the handler. The name cannot contain special characters or spaces.



17
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 17

attribute :name

#pipe ⇒ Object?

Returns The pipe definition scope, used to configure the Sensu transport pipe.,NOTE: the pipe attribute is only required for Transport handlers (i.e. handlers configured with "type": "transport").

Returns:

  • (Object, nil) —

    The pipe definition scope, used to configure the Sensu transport pipe.,NOTE: the pipe attribute is only required for Transport handlers (i.e. handlers configured with "type": "transport").



58
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 58

attribute :pipe

#severities ⇒ :warning, ...

Returns An array of check result severities the handler will handle.,NOTE: event resolution bypasses this filtering.

Returns:

  • (:warning, :critical, :unknown, nil) —

    An array of check result severities the handler will handle.,NOTE: event resolution bypasses this filtering.



31
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 31

attribute :severities

#socket ⇒ Hash?

Returns The socket definition scope, used to configure the TCP/UDP handler socket.,NOTE: the socket attribute is only required for TCP/UDP handlers (i.e. handlers configured with "type": "tcp" or "type": "udp").

Returns:

  • (Hash, nil) —

    The socket definition scope, used to configure the TCP/UDP handler socket.,NOTE: the socket attribute is only required for TCP/UDP handlers (i.e. handlers configured with "type": "tcp" or "type": "udp").



54
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 54

attribute :socket

#state ⇒ :present, ...

Returns Whether the handler should be present or not.

Returns:

  • (:present, :absent, nil) —

    Whether the handler should be present or not



13
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 13

attribute :state

#timeout ⇒ Integer?

Returns The handler execution duration timeout in seconds (hard stop).,Only used by pipe and tcp handler types.

Returns:

  • (Integer, nil) —

    The handler execution duration timeout in seconds (hard stop).,Only used by pipe and tcp handler types.



38
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 38

attribute :timeout

#type ⇒ :pipe, ...

Returns The handler type.

Returns:

  • (:pipe, :tcp, :udp, :transport, :set) —

    The handler type



21
# File 'lib/ansible/ruby/modules/generated/monitoring/sensu_handler.rb', line 21

attribute :type