Class: Ansible::Ruby::Modules::Snow_record

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/notification/snow_record.rb

Overview

Creates/Deletes/Updates a single record in ServiceNow

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#attachment ⇒ String?

Returns Attach a file to the record.

Returns:

  • (String, nil) —

    Attach a file to the record



44
# File 'lib/ansible/ruby/modules/generated/notification/snow_record.rb', line 44

attribute :attachment

#data ⇒ Hash?

Returns key, value pairs of data to load into the record. See Examples. Required for C(state:present).

Returns:

  • (Hash, nil) —

    key, value pairs of data to load into the record. See Examples. Required for C(state:present)



32
# File 'lib/ansible/ruby/modules/generated/notification/snow_record.rb', line 32

attribute :data

#instance ⇒ String

Returns The service now instance name.

Returns:

  • (String) —

    The service now instance name



12
# File 'lib/ansible/ruby/modules/generated/notification/snow_record.rb', line 12

attribute :instance

#lookup_field ⇒ String?

Returns Changes the field that C(number) uses to find records.

Returns:

  • (String, nil) —

    Changes the field that C(number) uses to find records



40
# File 'lib/ansible/ruby/modules/generated/notification/snow_record.rb', line 40

attribute :lookup_field

#number ⇒ String, ...

Returns Record number to update. Required for C(state:absent).

Returns:

  • (String, Integer, nil) —

    Record number to update. Required for C(state:absent)



36
# File 'lib/ansible/ruby/modules/generated/notification/snow_record.rb', line 36

attribute :number

#password ⇒ String

Returns Password for username.

Returns:

  • (String) —

    Password for username



20
# File 'lib/ansible/ruby/modules/generated/notification/snow_record.rb', line 20

attribute :password

#state ⇒ :present, :absent

Returns If C(present) is supplied with a C(number) argument, the module will attempt to update the record with the supplied data. If no such record exists, a new one will be created. C(absent) will delete a record.

Returns:

  • (:present, :absent) —

    If C(present) is supplied with a C(number) argument, the module will attempt to update the record with the supplied data. If no such record exists, a new one will be created. C(absent) will delete a record.



28
# File 'lib/ansible/ruby/modules/generated/notification/snow_record.rb', line 28

attribute :state

#table ⇒ String?

Returns Table to query for records.

Returns:

  • (String, nil) —

    Table to query for records



24
# File 'lib/ansible/ruby/modules/generated/notification/snow_record.rb', line 24

attribute :table

#username ⇒ String

Returns User to connect to ServiceNow as.

Returns:

  • (String) —

    User to connect to ServiceNow as



16
# File 'lib/ansible/ruby/modules/generated/notification/snow_record.rb', line 16

attribute :username