Class: Ansible::Ruby::Modules::Spectrum_device

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb

Overview

This module allows you to create and delete devices in CA Spectrum U(https://www.ca.com/us/products/ca-spectrum.html). Tested on CA Spectrum 9.4.2, 10.1.1 and 10.2.1

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#agentport ⇒ Integer?

Returns UDP port used for SNMP discovery.

Returns:

  • (Integer, nil) —

    UDP port used for SNMP discovery.



49
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 49

attribute :agentport

#community ⇒ String?

Returns SNMP community used for device discovery.,Required when C(state=present).

Returns:

  • (String, nil) —

    SNMP community used for device discovery.,Required when C(state=present).



17
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 17

attribute :community

#device ⇒ String

Returns IP address of the device.,If a hostname is given, it will be resolved to the IP address.

Returns:

  • (String) —

    IP address of the device.,If a hostname is given, it will be resolved to the IP address.



13
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 13

attribute :device

#landscape ⇒ String

Returns Landscape handle of the SpectroServer to which add or remove the device.

Returns:

  • (String) —

    Landscape handle of the SpectroServer to which add or remove the device.



21
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 21

attribute :landscape

#state ⇒ :present, ...

Returns On C(present) creates the device when it does not exist.,On C(absent) removes the device when it exists.

Returns:

  • (:present, :absent, nil) —

    On C(present) creates the device when it does not exist.,On C(absent) removes the device when it exists.



25
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 25

attribute :state

#url ⇒ Object

Returns HTTP, HTTPS URL of the Oneclick server in the form (http|https)://host.domain.

Returns:

  • (Object) —

    HTTP, HTTPS URL of the Oneclick server in the form (http|https)://host.domain



29
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 29

attribute :url

#url_password ⇒ Object

Returns Oneclick user password.

Returns:

  • (Object) —

    Oneclick user password.



37
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 37

attribute :url_password

#url_username ⇒ Object

Returns Oneclick user name.

Returns:

  • (Object) —

    Oneclick user name.



33
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 33

attribute :url_username

#use_proxy ⇒ :yes, ...

Returns if C(no), it will not use a proxy, even if one is defined in an environment variable on the target hosts.

Returns:

  • (:yes, :no, nil) —

    if C(no), it will not use a proxy, even if one is defined in an environment variable on the target hosts.



41
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 41

attribute :use_proxy

#validate_certs ⇒ :yes, ...

Returns If C(no), SSL certificates will not be validated. This should only be used on personally controlled sites using self-signed certificates.

Returns:

  • (:yes, :no, nil) —

    If C(no), SSL certificates will not be validated. This should only be used on personally controlled sites using self-signed certificates.



45
# File 'lib/ansible/ruby/modules/generated/monitoring/spectrum_device.rb', line 45

attribute :validate_certs