Method: Ansible::Ruby::Modules::Template#variable_end_string

Defined in:
lib/ansible/ruby/modules/generated/files/template.rb

#variable_end_stringString?

Returns The string marking the end of a print statement.

Returns:

  • (String, nil)

    The string marking the end of a print statement.



41
# File 'lib/ansible/ruby/modules/generated/files/template.rb', line 41

attribute :variable_end_string