Class: Ansible::Ruby::Modules::Tower_role

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb

Overview

Create, update, or destroy Ansible Tower roles. See U(https://www.ansible.com/tower) for an overview.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#credential ⇒ Object?

Returns Credential the role acts on.

Returns:

  • (Object, nil) —

    Credential the role acts on.



33
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 33

attribute :credential

#inventory ⇒ Object?

Returns Inventory the role acts on.

Returns:

  • (Object, nil) —

    Inventory the role acts on.



27
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 27

attribute :inventory

#job_template ⇒ Object?

Returns The job template the role acts on.

Returns:

  • (Object, nil) —

    The job template the role acts on.



30
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 30

attribute :job_template

#organization ⇒ Object?

Returns Organization the role acts on.

Returns:

  • (Object, nil) —

    Organization the role acts on.



36
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 36

attribute :organization

#project ⇒ Object?

Returns Project the role acts on.

Returns:

  • (Object, nil) —

    Project the role acts on.



39
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 39

attribute :project

#role ⇒ :admin, ...

Returns The role type to grant/revoke.

Returns:

  • (:admin, :read, :member, :execute, :adhoc, :update, :use, :auditor) —

    The role type to grant/revoke.



19
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 19

attribute :role

#state ⇒ :present, ...

Returns Desired state of the resource.

Returns:

  • (:present, :absent, nil) —

    Desired state of the resource.



42
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 42

attribute :state

#target_team ⇒ String?

Returns Team that the role acts on.

Returns:

  • (String, nil) —

    Team that the role acts on.



23
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 23

attribute :target_team

#team ⇒ Object?

Returns Team that receives the permissions specified by the role.

Returns:

  • (Object, nil) —

    Team that receives the permissions specified by the role.



16
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 16

attribute :team

#user ⇒ String?

Returns User that receives the permissions specified by the role.

Returns:

  • (String, nil) —

    User that receives the permissions specified by the role.



12
# File 'lib/ansible/ruby/modules/generated/web_infrastructure/ansible_tower/tower_role.rb', line 12

attribute :user