Class: Ansible::Ruby::Modules::Ucs_storage_profile
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Ucs_storage_profile
- Defined in:
- lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_storage_profile.rb
Overview
Configures storage profiles on Cisco UCS Manager. Examples can be used with the L(UCS Platform Emulator,communities.cisco.com/ucspe).
Instance Method Summary collapse
-
#description ⇒ Object?
The user-defined description of the storage profile.,Enter up to 256 characters.,You can use any characters or spaces except the following:,‘ (accent mark), (backslash), ^ (carat), “ (double quote), = (equal sign), > (greater than), < (less than), or ’ (single quote).
-
#local_luns ⇒ Array<Hash>, ...
List of Local LUNs used by the storage profile.
-
#name ⇒ String
The name of the storage profile.,This name can be between 1 and 16 alphanumeric characters.,You cannot use spaces or any special characters other than - (hyphen), “_” (underscore), : (colon), and .
-
#org_dn ⇒ String?
The distinguished name (dn) of the organization where the resource is assigned.
-
#state ⇒ :absent, ...
If C(present), will verify that the storage profile is present and will create if needed.,If C(absent), will verify that the storage profile is absent and will delete if needed.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#description ⇒ Object?
21 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_storage_profile.rb', line 21 attribute :description |
#local_luns ⇒ Array<Hash>, ...
24 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_storage_profile.rb', line 24 attribute :local_luns |
#name ⇒ String
17 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_storage_profile.rb', line 17 attribute :name |
#org_dn ⇒ String?
28 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_storage_profile.rb', line 28 attribute :org_dn |
#state ⇒ :absent, ...
13 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_storage_profile.rb', line 13 attribute :state |