Class: Ansible::Ruby::Modules::Ucs_vlans
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Ucs_vlans
- Defined in:
- lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_vlans.rb
Overview
Configures VLANs on Cisco UCS Manager. Examples can be used with the UCS Platform Emulator U(communities.cisco.com/ucspe).
Instance Method Summary collapse
-
#fabric ⇒ :common, ...
The fabric configuration of the VLAN.
-
#id ⇒ String
The unique string identifier assigned to the VLAN.,A VLAN ID can be between ‘1’ and ‘3967’, or between ‘4048’ and ‘4093’.,You cannot create VLANs with IDs from 4030 to 4047.
-
#multicast_policy ⇒ String?
The multicast policy associated with this VLAN.,This option is only valid if the Sharing Type field is set to None or Primary.
-
#name ⇒ String
The name assigned to the VLAN.,The VLAN name is case sensitive.,This name can be between 1 and 32 alphanumeric characters.,You cannot use spaces or any special characters other than - (hyphen), “_” (underscore), : (colon), and .
-
#native ⇒ :yes, ...
Designates the VLAN as a native VLAN.
-
#sharing ⇒ :none, ...
The Sharing Type field.,Whether this VLAN is subdivided into private or secondary VLANs.
-
#state ⇒ :present, ...
If C(present), will verify VLANs are present and will create if needed.,If C(absent), will verify VLANs are absent and will delete if needed.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#fabric ⇒ :common, ...
25 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_vlans.rb', line 25 attribute :fabric |
#id ⇒ String
29 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_vlans.rb', line 29 attribute :id |
#multicast_policy ⇒ String?
21 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_vlans.rb', line 21 attribute :multicast_policy |
#name ⇒ String
17 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_vlans.rb', line 17 attribute :name |
#native ⇒ :yes, ...
37 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_vlans.rb', line 37 attribute :native |
#sharing ⇒ :none, ...
33 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_vlans.rb', line 33 attribute :sharing |
#state ⇒ :present, ...
13 |
# File 'lib/ansible/ruby/modules/generated/remote_management/ucs/ucs_vlans.rb', line 13 attribute :state |