Class: Ansible::Ruby::Modules::Vdirect_commit
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Vdirect_commit
- Defined in:
- lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb
Overview
Commits pending configuration changes on one or more Radware devices via vDirect server. For Alteon ADC device, apply, sync and save actions will be performed by default. Skipping of an action is possible by explicit parameter specifying. For Alteon VX Container device, no sync operation will be performed since sync action is only relevant for Alteon ADC devices. For DefensePro and AppWall devices, a bulk commit action will be performed. Explicit apply, sync and save actions specifying is not relevant.
Instance Method Summary collapse
-
#apply ⇒ :yes, ...
If C(no), apply action will not be performed.
-
#devices ⇒ Array<String>, String
List of Radware Alteon device names for commit operations.
-
#save ⇒ :yes, ...
If C(no), save action will not be performed.
-
#sync ⇒ :yes, ...
If C(no), sync action will not be performed.
-
#vdirect_http_port ⇒ Integer?
VDirect server HTTP port number, may be set as C(VDIRECT_HTTP_PORT) environment variable.
-
#vdirect_https_port ⇒ Integer?
VDirect server HTTPS port number, may be set as C(VDIRECT_HTTPS_PORT) environment variable.
-
#vdirect_ip ⇒ String
Primary vDirect server IP address, may be set as C(VDIRECT_IP) environment variable.
-
#vdirect_password ⇒ String
VDirect server password, may be set as C(VDIRECT_PASSWORD) environment variable.
-
#vdirect_secondary_ip ⇒ Object?
Secondary vDirect server IP address, may be set as C(VDIRECT_SECONDARY_IP) environment variable.
-
#vdirect_timeout ⇒ Integer?
Amount of time to wait for async operation completion [seconds],,may be set as C(VDIRECT_TIMEOUT) environment variable.
-
#vdirect_use_ssl ⇒ :yes, ...
If C(no), an HTTP connection will be used instead of the default HTTPS connection,,may be set as C(VDIRECT_HTTPS) or C(VDIRECT_USE_SSL) environment variable.
-
#vdirect_user ⇒ String
VDirect server username, may be set as C(VDIRECT_USER) environment variable.
-
#vdirect_validate_certs ⇒ :yes, ...
If C(no), SSL certificates will not be validated,,may be set as C(VDIRECT_VALIDATE_CERTS) or C(VDIRECT_VERIFY) environment variable.,This should only set to C(no) used on personally controlled sites using self-signed certificates.
-
#vdirect_wait ⇒ :yes, ...
Wait for async operation to complete, may be set as C(VDIRECT_WAIT) environment variable.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#apply ⇒ :yes, ...
58 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 58 attribute :apply |
#devices ⇒ Array<String>, String
54 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 54 attribute :devices |
#save ⇒ :yes, ...
62 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 62 attribute :save |
#sync ⇒ :yes, ...
66 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 66 attribute :sync |
#vdirect_http_port ⇒ Integer?
38 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 38 attribute :vdirect_http_port |
#vdirect_https_port ⇒ Integer?
34 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 34 attribute :vdirect_https_port |
#vdirect_ip ⇒ String
15 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 15 attribute :vdirect_ip |
#vdirect_password ⇒ String
23 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 23 attribute :vdirect_password |
#vdirect_secondary_ip ⇒ Object?
27 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 27 attribute :vdirect_secondary_ip |
#vdirect_timeout ⇒ Integer?
42 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 42 attribute :vdirect_timeout |
#vdirect_use_ssl ⇒ :yes, ...
46 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 46 attribute :vdirect_use_ssl |
#vdirect_user ⇒ String
19 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 19 attribute :vdirect_user |
#vdirect_validate_certs ⇒ :yes, ...
50 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 50 attribute :vdirect_validate_certs |
#vdirect_wait ⇒ :yes, ...
30 |
# File 'lib/ansible/ruby/modules/generated/network/radware/vdirect_commit.rb', line 30 attribute :vdirect_wait |