Class: Ansible::Ruby::Modules::Vertica_user

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb

Overview

Adds or removes Vertica database user and, optionally, assigns roles. A user will not be removed until all the dependencies have been dropped. In such a situation, if the module tries to remove the user it will fail and only remove roles granted to the user.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#cluster ⇒ String?

Returns Name of the Vertica cluster.

Returns:

  • (String, nil) —

    Name of the Vertica cluster.



47
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 47

attribute :cluster

#db ⇒ String?

Returns Name of the Vertica database.

Returns:

  • (String, nil) —

    Name of the Vertica database.



43
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 43

attribute :db

#expired ⇒ Object?

Returns Sets the user's password expiration.

Returns:

  • (Object, nil) —

    Sets the user's password expiration.



28
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 28

attribute :expired

#ldap ⇒ String?

Returns Set to true if users are authenticated via LDAP.,The user will be created with password expired and set to I($ldap$).

Returns:

  • (String, nil) —

    Set to true if users are authenticated via LDAP.,The user will be created with password expired and set to I($ldap$).



31
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 31

attribute :ldap

#login_password ⇒ Object?

Returns The password used to authenticate with.

Returns:

  • (Object, nil) —

    The password used to authenticate with.



59
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 59

attribute :login_password

#login_user ⇒ String?

Returns The username used to authenticate with.

Returns:

  • (String, nil) —

    The username used to authenticate with.



55
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 55

attribute :login_user

#name ⇒ String

Returns Name of the user to add or remove.

Returns:

  • (String) —

    Name of the user to add or remove.



14
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 14

attribute :name

#password ⇒ String?

Returns The user's password encrypted by the MD5 algorithm.,The password must be generated with the format C("md5" + md5[password + username]), resulting in a total of 35 characters. An easy way to do this is by querying the Vertica database with select 'md5'||md5('<user_password><user_name>').

Returns:

  • (String, nil) —

    The user's password encrypted by the MD5 algorithm.,The password must be generated with the format C("md5" + md5[password + username]), resulting in a total of 35 characters. An easy way to do this is by querying the Vertica database with select 'md5'||md5('<user_password><user_name>').



24
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 24

attribute :password

#port ⇒ Integer?

Returns Vertica cluster port to connect to.

Returns:

  • (Integer, nil) —

    Vertica cluster port to connect to.



51
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 51

attribute :port

#profile ⇒ Object?

Returns Sets the user's profile.

Returns:

  • (Object, nil) —

    Sets the user's profile.



18
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 18

attribute :profile

#resource_pool ⇒ Object?

Returns Sets the user's resource pool.

Returns:

  • (Object, nil) —

    Sets the user's resource pool.



21
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 21

attribute :resource_pool

#roles ⇒ String?

Returns Comma separated list of roles to assign to the user.

Returns:

  • (String, nil) —

    Comma separated list of roles to assign to the user.



35
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 35

attribute :roles

#state ⇒ :present, ...

Returns Whether to create C(present), drop C(absent) or lock C(locked) a user.

Returns:

  • (:present, :absent, :locked, nil) —

    Whether to create C(present), drop C(absent) or lock C(locked) a user.



39
# File 'lib/ansible/ruby/modules/generated/database/vertica/vertica_user.rb', line 39

attribute :state