Class: Ansible::Ruby::Modules::Vmware_dvswitch
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Vmware_dvswitch
- Defined in:
- lib/ansible/ruby/modules/generated/cloud/vmware/vmware_dvswitch.rb
Overview
Create or remove a distributed vSwitch
Instance Method Summary collapse
-
#datacenter_name ⇒ String
The name of the datacenter that will contain the dvSwitch.
-
#discovery_operation ⇒ :both, ...
Select the discovery operation.
-
#discovery_proto ⇒ :cdp, :lldp
Link discovery protocol between Cisco and Link Layer discovery.
-
#mtu ⇒ Integer
The switch maximum transmission unit.
-
#state ⇒ :present, ...
Create or remove dvSwitch.
-
#switch_name ⇒ String
The name of the switch to create or remove.
-
#switch_version ⇒ String?
The version of the switch to create.
-
#uplink_quantity ⇒ Integer
Quantity of uplink per ESXi host added to the switch.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#datacenter_name ⇒ String
12 |
# File 'lib/ansible/ruby/modules/generated/cloud/vmware/vmware_dvswitch.rb', line 12 attribute :datacenter_name |
#discovery_operation ⇒ :both, ...
36 |
# File 'lib/ansible/ruby/modules/generated/cloud/vmware/vmware_dvswitch.rb', line 36 attribute :discovery_operation |
#discovery_proto ⇒ :cdp, :lldp
32 |
# File 'lib/ansible/ruby/modules/generated/cloud/vmware/vmware_dvswitch.rb', line 32 attribute :discovery_proto |
#mtu ⇒ Integer
24 |
# File 'lib/ansible/ruby/modules/generated/cloud/vmware/vmware_dvswitch.rb', line 24 attribute :mtu |
#state ⇒ :present, ...
40 |
# File 'lib/ansible/ruby/modules/generated/cloud/vmware/vmware_dvswitch.rb', line 40 attribute :state |
#switch_name ⇒ String
16 |
# File 'lib/ansible/ruby/modules/generated/cloud/vmware/vmware_dvswitch.rb', line 16 attribute :switch_name |
#switch_version ⇒ String?
20 |
# File 'lib/ansible/ruby/modules/generated/cloud/vmware/vmware_dvswitch.rb', line 20 attribute :switch_version |
#uplink_quantity ⇒ Integer
28 |
# File 'lib/ansible/ruby/modules/generated/cloud/vmware/vmware_dvswitch.rb', line 28 attribute :uplink_quantity |