Class: Ansible::Ruby::Modules::Vyos_user
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Vyos_user
- Defined in:
- lib/ansible/ruby/modules/generated/network/vyos/vyos_user.rb
Overview
This module provides declarative management of the local usernames configured on network devices. It allows playbooks to manage either individual usernames or the collection of usernames in the current running config. It also supports purging usernames from the configuration that are not explicitly defined.
Instance Method Summary collapse
-
#aggregate ⇒ Array<Hash>, ...
The set of username objects to be configured on the remote VyOS device.
-
#configured_password ⇒ String?
The password to be configured on the VyOS device.
-
#full_name ⇒ Object?
The C(full_name) argument provides the full name of the user account to be created on the remote device.
-
#level ⇒ String?
The C(level) argument configures the level of the user when logged into the system.
-
#name ⇒ String?
The username to be configured on the VyOS device.
-
#purge ⇒ Symbol?
Instructs the module to consider the resource definition absolute.
-
#state ⇒ :present, ...
Configures the state of the username definition as it relates to the device operational configuration.
-
#update_password ⇒ :on_create, ...
Since passwords are encrypted in the device running config, this argument will instruct the module when to change the password.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#aggregate ⇒ Array<Hash>, ...
12 |
# File 'lib/ansible/ruby/modules/generated/network/vyos/vyos_user.rb', line 12 attribute :aggregate |
#configured_password ⇒ String?
23 |
# File 'lib/ansible/ruby/modules/generated/network/vyos/vyos_user.rb', line 23 attribute :configured_password |
#full_name ⇒ Object?
20 |
# File 'lib/ansible/ruby/modules/generated/network/vyos/vyos_user.rb', line 20 attribute :full_name |
#level ⇒ String?
31 |
# File 'lib/ansible/ruby/modules/generated/network/vyos/vyos_user.rb', line 31 attribute :level |
#name ⇒ String?
16 |
# File 'lib/ansible/ruby/modules/generated/network/vyos/vyos_user.rb', line 16 attribute :name |
#purge ⇒ Symbol?
35 |
# File 'lib/ansible/ruby/modules/generated/network/vyos/vyos_user.rb', line 35 attribute :purge |
#state ⇒ :present, ...
39 |
# File 'lib/ansible/ruby/modules/generated/network/vyos/vyos_user.rb', line 39 attribute :state |
#update_password ⇒ :on_create, ...
27 |
# File 'lib/ansible/ruby/modules/generated/network/vyos/vyos_user.rb', line 27 attribute :update_password |