Class: Ansible::Ruby::Modules::Win_defrag

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/windows/win_defrag.rb

Overview

Locates and consolidates fragmented files on local volumes to improve system performance. More information regarding C(win_defrag) is available from: U(https://technet.microsoft.com/en-us/library/cc731650(v=ws.11).aspx)

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#exclude_volumes ⇒ Array<String>, ...

Returns A list of drive letters or mount point paths to exclude from defragmentation.

Returns:

  • (Array<String>, String, nil) —

    A list of drive letters or mount point paths to exclude from defragmentation.



17
# File 'lib/ansible/ruby/modules/generated/windows/win_defrag.rb', line 17

attribute :exclude_volumes

#freespace_consolidation ⇒ Boolean?

Returns Perform free space consolidation on the specified volumes.

Returns:

  • (Boolean, nil) —

    Perform free space consolidation on the specified volumes.



21
# File 'lib/ansible/ruby/modules/generated/windows/win_defrag.rb', line 21

attribute :freespace_consolidation

#include_volumes ⇒ Array<String>, ...

Returns A list of drive letters or mount point paths of the volumes to be defragmented.,If this parameter is omitted, all volumes (not excluded) will be fragmented.

Returns:

  • (Array<String>, String, nil) —

    A list of drive letters or mount point paths of the volumes to be defragmented.,If this parameter is omitted, all volumes (not excluded) will be fragmented.



13
# File 'lib/ansible/ruby/modules/generated/windows/win_defrag.rb', line 13

attribute :include_volumes

#parallel ⇒ :yes, ...

Returns Run the operation on each volume in parallel in the background.

Returns:

  • (:yes, :no, nil) —

    Run the operation on each volume in parallel in the background.



29
# File 'lib/ansible/ruby/modules/generated/windows/win_defrag.rb', line 29

attribute :parallel

#priority ⇒ :low, ...

Returns Run the operation at low or normal priority.

Returns:

  • (:low, :normal, nil) —

    Run the operation at low or normal priority.



25
# File 'lib/ansible/ruby/modules/generated/windows/win_defrag.rb', line 25

attribute :priority