Class: Ansible::Ruby::Modules::Win_iis_website

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/windows/win_iis_website.rb

Overview

Creates, Removes and configures a IIS Web site.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#application_pool ⇒ String?

Returns The application pool in which the new site executes.

Returns:

  • (String, nil) —

    The application pool in which the new site executes.



27
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 27

attribute :application_pool

#hostname ⇒ String?

Returns The host header to bind to / use for the new site.

Returns:

  • (String, nil) —

    The host header to bind to / use for the new site.



39
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 39

attribute :hostname

#ip ⇒ String?

Returns The IP address to bind to / use for the new site.

Returns:

  • (String, nil) —

    The IP address to bind to / use for the new site.



35
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 35

attribute :ip

#name ⇒ String

Returns Names of web site.

Returns:

  • (String) —

    Names of web site.



12
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 12

attribute :name

#parameters ⇒ String?

Returns Custom site Parameters from string where properties are separated by a pipe and property name/values by colon Ex. "foo:1|bar:2".

Returns:

  • (String, nil) —

    Custom site Parameters from string where properties are separated by a pipe and property name/values by colon Ex. "foo:1|bar:2"



46
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 46

attribute :parameters

#physical_path ⇒ String?

Returns The physical path on the remote host to use for the new site.,The specified folder must already exist.

Returns:

  • (String, nil) —

    The physical path on the remote host to use for the new site.,The specified folder must already exist.



23
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 23

attribute :physical_path

#port ⇒ Integer?

Returns The port to bind to / use for the new site.

Returns:

  • (Integer, nil) —

    The port to bind to / use for the new site.



31
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 31

attribute :port

#site_id ⇒ Object?

Returns Explicitly set the IIS numeric ID for a site.,Note that this value cannot be changed after the website has been created.

Returns:

  • (Object, nil) —

    Explicitly set the IIS numeric ID for a site.,Note that this value cannot be changed after the website has been created.



16
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 16

attribute :site_id

#ssl ⇒ Object?

Returns Enables HTTPS binding on the site..

Returns:

  • (Object, nil) —

    Enables HTTPS binding on the site..



43
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 43

attribute :ssl

#state ⇒ :absent, ...

Returns State of the web site.

Returns:

  • (:absent, :started, :stopped, :restarted, nil) —

    State of the web site



19
# File 'lib/ansible/ruby/modules/generated/windows/win_iis_website.rb', line 19

attribute :state