Method: Ansible::Ruby::Modules::Win_service#path

Defined in:
lib/ansible/ruby/modules/generated/windows/win_service.rb

#pathString?

Returns The path to the executable to set for the service.

Returns:

  • (String, nil)

    The path to the executable to set for the service.



41
# File 'lib/ansible/ruby/modules/generated/windows/win_service.rb', line 41

attribute :path