Class: Ansible::Ruby::Modules::Win_share

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/windows/win_share.rb

Overview

Add, modify or remove Windows share and set share permissions.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#caching_mode ⇒ :BranchCache, ...

Returns Set the CachingMode for this share.

Returns:

  • (:BranchCache, :Documents, :Manual, :None, :Programs, :Unknown, nil) —

    Set the CachingMode for this share.



47
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 47

attribute :caching_mode

#change ⇒ Object?

Returns Specify user list that should get read and write access on share, separated by comma.

Returns:

  • (Object, nil) —

    Specify user list that should get read and write access on share, separated by comma.



36
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 36

attribute :change

#deny ⇒ String?

Returns Specify user list that should get no access, regardless of implied access on share, separated by comma.

Returns:

  • (String, nil) —

    Specify user list that should get no access, regardless of implied access on share, separated by comma.



43
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 43

attribute :deny

#description ⇒ String?

Returns Share description.

Returns:

  • (String, nil) —

    Share description.



24
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 24

attribute :description

#encrypt ⇒ :yes, ...

Returns Sets whether to encrypt the traffic to the share or not.

Returns:

  • (:yes, :no, nil) —

    Sets whether to encrypt the traffic to the share or not.



51
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 51

attribute :encrypt

#full ⇒ Array<String>, ...

Returns Specify user list that should get full access on share, separated by comma.

Returns:

  • (Array<String>, String, nil) —

    Specify user list that should get full access on share, separated by comma.



39
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 39

attribute :full

#list ⇒ :yes, ...

Returns Specify whether to allow or deny file listing, in case user has no permission on share. Also known as Access-Based Enumeration.

Returns:

  • (:yes, :no, nil) —

    Specify whether to allow or deny file listing, in case user has no permission on share. Also known as Access-Based Enumeration.



28
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 28

attribute :list

#name ⇒ String

Returns Share name.

Returns:

  • (String) —

    Share name.



12
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 12

attribute :name

#path ⇒ String

Returns Share directory.

Returns:

  • (String) —

    Share directory.



16
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 16

attribute :path

#read ⇒ String?

Returns Specify user list that should get read access on share, separated by comma.

Returns:

  • (String, nil) —

    Specify user list that should get read access on share, separated by comma.



32
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 32

attribute :read

#state ⇒ :absent, ...

Returns Specify whether to add C(present) or remove C(absent) the specified share.

Returns:

  • (:absent, :present, nil) —

    Specify whether to add C(present) or remove C(absent) the specified share.



20
# File 'lib/ansible/ruby/modules/generated/windows/win_share.rb', line 20

attribute :state