Class: Ansible::Ruby::Modules::Win_wait_for

Inherits:
Base show all
Defined in:
lib/ansible/ruby/modules/generated/windows/win_wait_for.rb

Overview

You can wait for a set amount of time C(timeout), this is the default if nothing is specified. Waiting for a port to become available is useful for when services are not immediately available after their init scripts return which is true of certain Java application servers. You can wait for a file to exist or not exist on the filesystem. This module can also be used to wait for a regex match string to be present in a file. You can wait for active connections to be closed before continuing on a local port.

Instance Method Summary collapse

Methods inherited from Base

#ansible_name, #to_h

Methods inherited from Ansible::Ruby::Models::Base

attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates

Constructor Details

This class inherits a constructor from Ansible::Ruby::Models::Base

Instance Method Details

#connect_timeoutInteger?



16
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 16

attribute :connect_timeout

#delayInteger?



20
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 20

attribute :delay

#exclude_hostsArray<String>, ...



24
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 24

attribute :exclude_hosts

#hostString?



28
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 28

attribute :host

#pathString?



32
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 32

attribute :path

#portInteger?



36
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 36

attribute :port

#search_regexString?



40
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 40

attribute :search_regex

#sleepInteger?



44
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 44

attribute :sleep

#state:absent, ...



48
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 48

attribute :state

#timeoutInteger?



52
# File 'lib/ansible/ruby/modules/generated/windows/win_wait_for.rb', line 52

attribute :timeout