Class: Ansible::Ruby::Modules::Azure_rm_appgateway
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Azure_rm_appgateway
- Defined in:
- lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb
Overview
Create, update and delete instance of Application Gateway.
Instance Method Summary collapse
-
#authentication_certificates ⇒ Object?
Authentication certificates of the application gateway resource.
-
#backend_address_pools ⇒ Array<Hash>, ...
List of backend address pool of the application gateway resource.
-
#backend_http_settings_collection ⇒ Array<Hash>, ...
Backend http settings of the application gateway resource.
-
#frontend_ip_configurations ⇒ Array<Hash>, ...
Frontend IP addresses of the application gateway resource.
-
#frontend_ports ⇒ Array<Hash>, ...
List of frontend ports of the application gateway resource.
-
#gateway_ip_configurations ⇒ Array<Hash>, ...
List of subnets used by the application gateway.
-
#http_listeners ⇒ Array<Hash>, ...
List of HTTP listeners of the application gateway resource.
-
#location ⇒ Object?
Resource location.
-
#name ⇒ String
The name of the application gateway.
-
#request_routing_rules ⇒ Array<Hash>, ...
List of request routing rules of the application gateway resource.
-
#resource_group ⇒ String
The name of the resource group.
-
#sku ⇒ Hash?
SKU of the application gateway resource.
-
#ssl_certificates ⇒ Object?
SSL certificates of the application gateway resource.
-
#ssl_policy ⇒ Object?
SSL policy of the application gateway resource.
-
#state ⇒ :absent, ...
Assert the state of the Public IP.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#authentication_certificates ⇒ Object?
34 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 34 attribute :authentication_certificates |
#backend_address_pools ⇒ Array<Hash>, ...
48 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 48 attribute :backend_address_pools |
#backend_http_settings_collection ⇒ Array<Hash>, ...
52 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 52 attribute :backend_http_settings_collection |
#frontend_ip_configurations ⇒ Array<Hash>, ...
40 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 40 attribute :frontend_ip_configurations |
#frontend_ports ⇒ Array<Hash>, ...
44 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 44 attribute :frontend_ports |
#gateway_ip_configurations ⇒ Array<Hash>, ...
30 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 30 attribute :gateway_ip_configurations |
#http_listeners ⇒ Array<Hash>, ...
56 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 56 attribute :http_listeners |
#location ⇒ Object?
20 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 20 attribute :location |
#name ⇒ String
16 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 16 attribute :name |
#request_routing_rules ⇒ Array<Hash>, ...
60 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 60 attribute :request_routing_rules |
#resource_group ⇒ String
12 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 12 attribute :resource_group |
#sku ⇒ Hash?
23 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 23 attribute :sku |
#ssl_certificates ⇒ Object?
37 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 37 attribute :ssl_certificates |
#ssl_policy ⇒ Object?
27 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 27 attribute :ssl_policy |
#state ⇒ :absent, ...
64 |
# File 'lib/ansible/ruby/modules/generated/cloud/azure/azure_rm_appgateway.rb', line 64 attribute :state |