Class: Ansible::Ruby::Modules::Clc_server
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Clc_server
- Defined in:
- lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb
Overview
An Ansible module to Create, Delete, Start and Stop servers in CenturyLink Cloud.
Instance Method Summary collapse
-
#add_public_ip ⇒ :yes, ...
Whether to add a public ip to the server.
-
#additional_disks ⇒ Object?
The list of additional disks for the server.
-
#alert_policy_id ⇒ Object?
The alert policy to assign to the server.
-
#alert_policy_name ⇒ Object?
The alert policy to assign to the server.
-
#alias ⇒ Object?
The account alias to provision the servers under.
-
#anti_affinity_policy_id ⇒ Object?
The anti-affinity policy to assign to the server.
-
#anti_affinity_policy_name ⇒ Object?
The anti-affinity policy to assign to the server.
-
#configuration_id ⇒ Object?
Only required for bare metal servers.
-
#count ⇒ Integer?
The number of servers to build (mutually exclusive with exact_count).
-
#count_group ⇒ String?
Required when exact_count is specified.
-
#cpu ⇒ Integer?
How many CPUs to provision on the server.
-
#cpu_autoscale_policy_id ⇒ Object?
The autoscale policy to assign to the server.
-
#custom_fields ⇒ Object?
The list of custom fields to set on the server.
-
#description ⇒ Object?
The description to set for the server.
-
#exact_count ⇒ Integer?
Run in idempotent mode.
-
#group ⇒ String?
The Server Group to create servers under.
-
#ip_address ⇒ Object?
The IP Address for the server.
-
#location ⇒ Object?
The Datacenter to create servers in.
-
#managed_os ⇒ :yes, ...
Whether to create the server as ‘Managed’ or not.
-
#memory ⇒ Integer?
Memory in GB.
-
#name ⇒ String?
A 1 to 6 character identifier to use for the server.
-
#network_id ⇒ Object?
The network UUID on which to create servers.
-
#os_type ⇒ :redHat6_64Bit, ...
Only required for bare metal servers.
-
#packages ⇒ Object?
The list of blue print packages to run on the server after its created.
-
#password ⇒ Object?
Password for the administrator / root user.
-
#primary_dns ⇒ Object?
Primary DNS used by the server.
-
#public_ip_ports ⇒ Object?
A list of ports to allow on the firewall to the servers public ip, if add_public_ip is set to True.
-
#public_ip_protocol ⇒ :TCP, ...
The protocol to use for the public ip if add_public_ip is set to True.
-
#secondary_dns ⇒ Object?
Secondary DNS used by the server.
-
#server_ids ⇒ Object?
Required for started, stopped, and absent states.
-
#source_server_password ⇒ Object?
The password for the source server if a clone is specified.
-
#state ⇒ :present, ...
The state to insure that the provided resources are in.
-
#storage_type ⇒ :standard, ...
The type of storage to attach to the server.
-
#template ⇒ String?
The template to use for server creation.
-
#ttl ⇒ Object?
The time to live for the server in seconds.
-
#type ⇒ :standard, ...
The type of server to create.
-
#wait ⇒ :yes, ...
Whether to wait for the provisioning tasks to finish before returning.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#add_public_ip ⇒ :yes, ...
15 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 15 attribute :add_public_ip |
#additional_disks ⇒ Object?
12 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 12 attribute :additional_disks |
#alert_policy_id ⇒ Object?
28 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 28 attribute :alert_policy_id |
#alert_policy_name ⇒ Object?
31 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 31 attribute :alert_policy_name |
#alias ⇒ Object?
19 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 19 attribute :alias |
#anti_affinity_policy_id ⇒ Object?
22 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 22 attribute :anti_affinity_policy_id |
#anti_affinity_policy_name ⇒ Object?
25 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 25 attribute :anti_affinity_policy_name |
#configuration_id ⇒ Object?
128 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 128 attribute :configuration_id |
#count ⇒ Integer?
34 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 34 attribute :count |
#count_group ⇒ String?
38 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 38 attribute :count_group |
#cpu ⇒ Integer?
42 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 42 attribute :cpu |
#cpu_autoscale_policy_id ⇒ Object?
46 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 46 attribute :cpu_autoscale_policy_id |
#custom_fields ⇒ Object?
49 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 49 attribute :custom_fields |
#description ⇒ Object?
52 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 52 attribute :description |
#exact_count ⇒ Integer?
55 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 55 attribute :exact_count |
#group ⇒ String?
59 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 59 attribute :group |
#ip_address ⇒ Object?
63 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 63 attribute :ip_address |
#location ⇒ Object?
66 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 66 attribute :location |
#managed_os ⇒ :yes, ...
69 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 69 attribute :managed_os |
#memory ⇒ Integer?
73 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 73 attribute :memory |
#name ⇒ String?
77 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 77 attribute :name |
#network_id ⇒ Object?
81 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 81 attribute :network_id |
#os_type ⇒ :redHat6_64Bit, ...
131 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 131 attribute :os_type |
#packages ⇒ Object?
84 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 84 attribute :packages |
#password ⇒ Object?
87 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 87 attribute :password |
#primary_dns ⇒ Object?
90 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 90 attribute :primary_dns |
#public_ip_ports ⇒ Object?
97 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 97 attribute :public_ip_ports |
#public_ip_protocol ⇒ :TCP, ...
93 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 93 attribute :public_ip_protocol |
#secondary_dns ⇒ Object?
100 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 100 attribute :secondary_dns |
#server_ids ⇒ Object?
103 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 103 attribute :server_ids |
#source_server_password ⇒ Object?
106 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 106 attribute :source_server_password |
#state ⇒ :present, ...
109 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 109 attribute :state |
#storage_type ⇒ :standard, ...
113 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 113 attribute :storage_type |
#template ⇒ String?
117 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 117 attribute :template |
#ttl ⇒ Object?
121 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 121 attribute :ttl |
#type ⇒ :standard, ...
124 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 124 attribute :type |
#wait ⇒ :yes, ...
135 |
# File 'lib/ansible/ruby/modules/generated/cloud/centurylink/clc_server.rb', line 135 attribute :wait |