Class: Ansible::Ruby::Modules::Gcp_compute_route
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Gcp_compute_route
- Defined in:
- lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb
Overview
Represents a Route resource. A route is a rule that specifies how certain packets should be handled by the virtual network. Routes are associated with virtual machines by tag, and the set of routes for a particular virtual machine is called its routing table. For each packet leaving a virtual machine, the system searches that virtual machine’s routing table for a single best matching route. Routes match packets by destination IP address, preferring smaller or more specific ranges over larger ones. If there is a tie, the system selects the route with the smallest priority value. If there is still a tie, it uses the layer three and four packet headers to select just one of the remaining matching routes. The packet is then forwarded as specified by the next_hop field of the winning route – either to another virtual machine destination, a virtual machine gateway or a Compute Engine-operated gateway. Packets that do not match any route in the sending virtual machine’s routing table will be dropped. A Route resource must have exactly one specification of either nextHopGateway, nextHopInstance, nextHopIp, or nextHopVpnTunnel.
Instance Method Summary collapse
-
#description ⇒ Object?
An optional description of this resource.
-
#dest_range ⇒ String
The destination range of outgoing packets that this route applies to.,Only IPv4 is supported.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
The network that this route applies to.
-
#next_hop_gateway ⇒ String?
URL to a gateway that should handle matching packets.,Currently, you can only specify the internet gateway, using a full or partial valid URL: * U(www.googleapis.com/compute/v1/projects/project/global/gateways/default-internet-gateway) * projects/project/global/gateways/default-internet-gateway * global/gateways/default-internet-gateway .
-
#next_hop_instance ⇒ Object?
URL to an instance that should handle matching packets.,You can specify this as a full or partial URL.
-
#next_hop_ip ⇒ Object?
Network IP address of an instance that should handle matching packets.
-
#next_hop_vpn_tunnel ⇒ Object?
URL to a VpnTunnel that should handle matching packets.
-
#priority ⇒ Object?
The priority of this route.
-
#state ⇒ :present, ...
Whether the given object should exist in GCP.
-
#tags ⇒ Array<String>, ...
A list of instance tags to which this route applies.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#description ⇒ Object?
23 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 23 attribute :description |
#dest_range ⇒ String
19 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 19 attribute :dest_range |
#name ⇒ String
26 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 26 attribute :name |
#network ⇒ String
30 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 30 attribute :network |
#next_hop_gateway ⇒ String?
41 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 41 attribute :next_hop_gateway |
#next_hop_instance ⇒ Object?
45 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 45 attribute :next_hop_instance |
#next_hop_ip ⇒ Object?
48 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 48 attribute :next_hop_ip |
#next_hop_vpn_tunnel ⇒ Object?
51 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 51 attribute :next_hop_vpn_tunnel |
#priority ⇒ Object?
34 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 34 attribute :priority |
#state ⇒ :present, ...
15 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 15 attribute :state |
#tags ⇒ Array<String>, ...
37 |
# File 'lib/ansible/ruby/modules/generated/cloud/google/gcp_compute_route.rb', line 37 attribute :tags |