Class: Ansible::Ruby::Modules::Junos_facts
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Junos_facts
- Defined in:
- lib/ansible/ruby/modules/generated/network/junos/junos_facts.rb
Overview
Collects fact information from a remote device running the Junos operating system. By default, the module will collect basic fact information from the device to be included with the hostvars. Additional fact information can be collected based on the configured set of arguments.
Instance Method Summary collapse
-
#config_format ⇒ :xml, ...
The I(config_format) argument specifies the format of the configuration when serializing output from the device.
-
#gather_subset ⇒ String?
When supplied, this argument will restrict the facts collected to a given subset.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#config_format ⇒ :xml, ...
16 |
# File 'lib/ansible/ruby/modules/generated/network/junos/junos_facts.rb', line 16 attribute :config_format |
#gather_subset ⇒ String?
12 |
# File 'lib/ansible/ruby/modules/generated/network/junos/junos_facts.rb', line 12 attribute :gather_subset |