Class: Ansible::Ruby::Modules::Netapp_e_alerts
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Netapp_e_alerts
- Defined in:
- lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb
Overview
Certain E-Series systems have the capability to send email notifications on potentially critical events. This module will allow the owner of the system to specify email recipients for these messages.
Instance Method Summary collapse
-
#contact ⇒ String?
Allows the owner to specify some free-form contact information to be included in the emails.,This is typically utilized to provide a contact phone number.
-
#log_path ⇒ Object?
Path to a file on the Ansible control node to be used for debug logging.
-
#recipients ⇒ Array<String>, ...
The email addresses that will receive the email notifications.,Required when I(state=enabled).
-
#sender ⇒ String?
This is the sender that the recipient will see.
-
#server ⇒ String?
A fully qualified domain name, IPv4 address, or IPv6 address of a mail server.,To use a fully qualified domain name, you must configure a DNS server on both controllers using M(netapp_e_mgmt_interface).
-
#state ⇒ :enabled, ...
Enable/disable the sending of email-based alerts.
-
#test ⇒ Symbol?
When a change is detected in the configuration, a test email will be sent.,This may take a few minutes to process.,Only applicable if I(state=enabled).
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, fix_inclusion, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#contact ⇒ String?
25 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 25 attribute :contact |
#log_path ⇒ Object?
37 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 37 attribute :log_path |
#recipients ⇒ Array<String>, ...
29 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 29 attribute :recipients |
#sender ⇒ String?
21 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 21 attribute :sender |
#server ⇒ String?
17 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 17 attribute :server |
#state ⇒ :enabled, ...
13 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 13 attribute :state |
#test ⇒ Symbol?
33 |
# File 'lib/ansible/ruby/modules/generated/storage/netapp/netapp_e_alerts.rb', line 33 attribute :test |