Class: Ansible::Ruby::Modules::Panos_query_rules
- Inherits:
-
Base
- Object
- Ansible::Ruby::Models::Base
- Base
- Ansible::Ruby::Modules::Panos_query_rules
- Defined in:
- lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb
Overview
-
Security policies allow you to enforce rules and take action, and can be as general or specific as needed. The policy rules are compared against the incoming traffic in sequence, and because the first rule that matches the traffic is applied, the more specific rules must precede the more general ones.
Instance Method Summary collapse
-
#api_key ⇒ String?
API key that can be used instead of I(username)/I(password) credentials.
-
#application ⇒ Object?
Name of the application or application group to be queried.
-
#destination_ip ⇒ String?
The destination IP address to be queried.
-
#destination_port ⇒ String?
The destination port to be queried.
-
#destination_zone ⇒ String?
Name of the destination security zone to be queried.
-
#devicegroup ⇒ Object?
The Panorama device group in which to conduct the query.
-
#ip_address ⇒ String
IP address (or hostname) of PAN-OS firewall or Panorama management console being queried.
-
#password ⇒ String
Password credentials to use for authentication.
-
#protocol ⇒ String?
The protocol used to be queried.
-
#source_ip ⇒ Object?
The source IP address to be queried.
-
#source_port ⇒ Object?
The source port to be queried.
-
#source_zone ⇒ String?
Name of the source security zone to be queried.
-
#tag_name ⇒ String?
Name of the rule tag to be queried.
-
#username ⇒ String?
Username credentials to use for authentication.
Methods inherited from Base
Methods inherited from Ansible::Ruby::Models::Base
attr_option, attr_options, attribute, #initialize, remove_existing_validations, #to_h, validates
Constructor Details
This class inherits a constructor from Ansible::Ruby::Models::Base
Instance Method Details
#api_key ⇒ String?
25 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 25 attribute :api_key |
#application ⇒ Object?
29 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 29 attribute :application |
#destination_ip ⇒ String?
46 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 46 attribute :destination_ip |
#destination_port ⇒ String?
50 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 50 attribute :destination_port |
#destination_zone ⇒ String?
42 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 42 attribute :destination_zone |
#devicegroup ⇒ Object?
62 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 62 attribute :devicegroup |
#ip_address ⇒ String
13 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 13 attribute :ip_address |
#password ⇒ String
21 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 21 attribute :password |
#protocol ⇒ String?
54 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 54 attribute :protocol |
#source_ip ⇒ Object?
36 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 36 attribute :source_ip |
#source_port ⇒ Object?
39 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 39 attribute :source_port |
#source_zone ⇒ String?
32 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 32 attribute :source_zone |
#tag_name ⇒ String?
58 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 58 attribute :tag_name |
#username ⇒ String?
17 |
# File 'lib/ansible/ruby/modules/generated/network/panos/panos_query_rules.rb', line 17 attribute :username |